Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=cloudprojectcontainerregistry.crossplane.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type FeaturesInitParameters
- type FeaturesObservation
- type FeaturesParameters
- type PlanInitParameters
- type PlanObservation
- type PlanParameters
- type ProjectContainerregistry
- func (in *ProjectContainerregistry) DeepCopy() *ProjectContainerregistry
- func (in *ProjectContainerregistry) DeepCopyInto(out *ProjectContainerregistry)
- func (in *ProjectContainerregistry) DeepCopyObject() runtime.Object
- func (mg *ProjectContainerregistry) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *ProjectContainerregistry) GetConnectionDetailsMapping() map[string]string
- func (mg *ProjectContainerregistry) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *ProjectContainerregistry) GetID() string
- func (tr *ProjectContainerregistry) GetInitParameters() (map[string]any, error)
- func (mg *ProjectContainerregistry) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *ProjectContainerregistry) GetObservation() (map[string]any, error)
- func (tr *ProjectContainerregistry) GetParameters() (map[string]any, error)
- func (mg *ProjectContainerregistry) GetProviderConfigReference() *xpv1.Reference
- func (mg *ProjectContainerregistry) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *ProjectContainerregistry) GetTerraformResourceType() string
- func (tr *ProjectContainerregistry) GetTerraformSchemaVersion() int
- func (mg *ProjectContainerregistry) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *ProjectContainerregistry) LateInitialize(attrs []byte) (bool, error)
- func (mg *ProjectContainerregistry) SetConditions(c ...xpv1.Condition)
- func (mg *ProjectContainerregistry) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *ProjectContainerregistry) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *ProjectContainerregistry) SetObservation(obs map[string]any) error
- func (tr *ProjectContainerregistry) SetParameters(params map[string]any) error
- func (mg *ProjectContainerregistry) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *ProjectContainerregistry) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *ProjectContainerregistry) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type ProjectContainerregistryInitParameters
- type ProjectContainerregistryList
- func (in *ProjectContainerregistryList) DeepCopy() *ProjectContainerregistryList
- func (in *ProjectContainerregistryList) DeepCopyInto(out *ProjectContainerregistryList)
- func (in *ProjectContainerregistryList) DeepCopyObject() runtime.Object
- func (l *ProjectContainerregistryList) GetItems() []resource.Managed
- type ProjectContainerregistryObservation
- type ProjectContainerregistryParameters
- type ProjectContainerregistrySpec
- type ProjectContainerregistryStatus
- type RegistryLimitsInitParameters
- type RegistryLimitsObservation
- type RegistryLimitsParameters
Constants ¶
const ( CRDGroup = "cloudprojectcontainerregistry.crossplane.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( ProjectContainerregistry_Kind = "ProjectContainerregistry" ProjectContainerregistry_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: ProjectContainerregistry_Kind}.String() ProjectContainerregistry_KindAPIVersion = ProjectContainerregistry_Kind + "." + CRDGroupVersion.String() ProjectContainerregistry_GroupVersionKind = CRDGroupVersion.WithKind(ProjectContainerregistry_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type FeaturesInitParameters ¶
type FeaturesInitParameters struct {
}
func (*FeaturesInitParameters) DeepCopy ¶
func (in *FeaturesInitParameters) DeepCopy() *FeaturesInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FeaturesInitParameters.
func (*FeaturesInitParameters) DeepCopyInto ¶
func (in *FeaturesInitParameters) DeepCopyInto(out *FeaturesInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type FeaturesObservation ¶
type FeaturesObservation struct {
Vulnerability *bool `json:"vulnerability,omitempty" tf:"vulnerability,omitempty"`
}
func (*FeaturesObservation) DeepCopy ¶
func (in *FeaturesObservation) DeepCopy() *FeaturesObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FeaturesObservation.
func (*FeaturesObservation) DeepCopyInto ¶
func (in *FeaturesObservation) DeepCopyInto(out *FeaturesObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type FeaturesParameters ¶
type FeaturesParameters struct {
}
func (*FeaturesParameters) DeepCopy ¶
func (in *FeaturesParameters) DeepCopy() *FeaturesParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FeaturesParameters.
func (*FeaturesParameters) DeepCopyInto ¶
func (in *FeaturesParameters) DeepCopyInto(out *FeaturesParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PlanInitParameters ¶
type PlanInitParameters struct {
}
func (*PlanInitParameters) DeepCopy ¶
func (in *PlanInitParameters) DeepCopy() *PlanInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PlanInitParameters.
func (*PlanInitParameters) DeepCopyInto ¶
func (in *PlanInitParameters) DeepCopyInto(out *PlanInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PlanObservation ¶
type PlanObservation struct {
Code *string `json:"code,omitempty" tf:"code,omitempty"`
CreatedAt *string `json:"createdAt,omitempty" tf:"created_at,omitempty"`
Features []FeaturesObservation `json:"features,omitempty" tf:"features,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
Name *string `json:"name,omitempty" tf:"name,omitempty"`
RegistryLimits []RegistryLimitsObservation `json:"registryLimits,omitempty" tf:"registry_limits,omitempty"`
UpdatedAt *string `json:"updatedAt,omitempty" tf:"updated_at,omitempty"`
}
func (*PlanObservation) DeepCopy ¶
func (in *PlanObservation) DeepCopy() *PlanObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PlanObservation.
func (*PlanObservation) DeepCopyInto ¶
func (in *PlanObservation) DeepCopyInto(out *PlanObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PlanParameters ¶
type PlanParameters struct {
}
func (*PlanParameters) DeepCopy ¶
func (in *PlanParameters) DeepCopy() *PlanParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PlanParameters.
func (*PlanParameters) DeepCopyInto ¶
func (in *PlanParameters) DeepCopyInto(out *PlanParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectContainerregistry ¶
type ProjectContainerregistry struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.name) || (has(self.initProvider) && has(self.initProvider.name))",message="spec.forProvider.name is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.region) || (has(self.initProvider) && has(self.initProvider.region))",message="spec.forProvider.region is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
Spec ProjectContainerregistrySpec `json:"spec"`
Status ProjectContainerregistryStatus `json:"status,omitempty"`
}
ProjectContainerregistry is the Schema for the ProjectContainerregistrys API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}
func (*ProjectContainerregistry) DeepCopy ¶
func (in *ProjectContainerregistry) DeepCopy() *ProjectContainerregistry
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectContainerregistry.
func (*ProjectContainerregistry) DeepCopyInto ¶
func (in *ProjectContainerregistry) DeepCopyInto(out *ProjectContainerregistry)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ProjectContainerregistry) DeepCopyObject ¶
func (in *ProjectContainerregistry) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ProjectContainerregistry) GetCondition ¶
func (mg *ProjectContainerregistry) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this ProjectContainerregistry.
func (*ProjectContainerregistry) GetConnectionDetailsMapping ¶
func (tr *ProjectContainerregistry) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this ProjectContainerregistry
func (*ProjectContainerregistry) GetDeletionPolicy ¶
func (mg *ProjectContainerregistry) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this ProjectContainerregistry.
func (*ProjectContainerregistry) GetID ¶
func (tr *ProjectContainerregistry) GetID() string
GetID returns ID of underlying Terraform resource of this ProjectContainerregistry
func (*ProjectContainerregistry) GetInitParameters ¶
func (tr *ProjectContainerregistry) GetInitParameters() (map[string]any, error)
GetInitParameters of this ProjectContainerregistry
func (*ProjectContainerregistry) GetManagementPolicies ¶
func (mg *ProjectContainerregistry) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this ProjectContainerregistry.
func (*ProjectContainerregistry) GetObservation ¶
func (tr *ProjectContainerregistry) GetObservation() (map[string]any, error)
GetObservation of this ProjectContainerregistry
func (*ProjectContainerregistry) GetParameters ¶
func (tr *ProjectContainerregistry) GetParameters() (map[string]any, error)
GetParameters of this ProjectContainerregistry
func (*ProjectContainerregistry) GetProviderConfigReference ¶
func (mg *ProjectContainerregistry) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this ProjectContainerregistry.
func (*ProjectContainerregistry) GetPublishConnectionDetailsTo ¶
func (mg *ProjectContainerregistry) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this ProjectContainerregistry.
func (*ProjectContainerregistry) GetTerraformResourceType ¶
func (mg *ProjectContainerregistry) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this ProjectContainerregistry
func (*ProjectContainerregistry) GetTerraformSchemaVersion ¶
func (tr *ProjectContainerregistry) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*ProjectContainerregistry) GetWriteConnectionSecretToReference ¶
func (mg *ProjectContainerregistry) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this ProjectContainerregistry.
func (*ProjectContainerregistry) LateInitialize ¶
func (tr *ProjectContainerregistry) LateInitialize(attrs []byte) (bool, error)
LateInitialize this ProjectContainerregistry using its observed tfState. returns True if there are any spec changes for the resource.
func (*ProjectContainerregistry) SetConditions ¶
func (mg *ProjectContainerregistry) SetConditions(c ...xpv1.Condition)
SetConditions of this ProjectContainerregistry.
func (*ProjectContainerregistry) SetDeletionPolicy ¶
func (mg *ProjectContainerregistry) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this ProjectContainerregistry.
func (*ProjectContainerregistry) SetManagementPolicies ¶
func (mg *ProjectContainerregistry) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this ProjectContainerregistry.
func (*ProjectContainerregistry) SetObservation ¶
func (tr *ProjectContainerregistry) SetObservation(obs map[string]any) error
SetObservation for this ProjectContainerregistry
func (*ProjectContainerregistry) SetParameters ¶
func (tr *ProjectContainerregistry) SetParameters(params map[string]any) error
SetParameters for this ProjectContainerregistry
func (*ProjectContainerregistry) SetProviderConfigReference ¶
func (mg *ProjectContainerregistry) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this ProjectContainerregistry.
func (*ProjectContainerregistry) SetPublishConnectionDetailsTo ¶
func (mg *ProjectContainerregistry) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this ProjectContainerregistry.
func (*ProjectContainerregistry) SetWriteConnectionSecretToReference ¶
func (mg *ProjectContainerregistry) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this ProjectContainerregistry.
type ProjectContainerregistryInitParameters ¶
type ProjectContainerregistryInitParameters struct {
// Registry name
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Plan ID of the registry.
PlanID *string `json:"planId,omitempty" tf:"plan_id,omitempty"`
// Region of the registry.
Region *string `json:"region,omitempty" tf:"region,omitempty"`
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
}
func (*ProjectContainerregistryInitParameters) DeepCopy ¶
func (in *ProjectContainerregistryInitParameters) DeepCopy() *ProjectContainerregistryInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectContainerregistryInitParameters.
func (*ProjectContainerregistryInitParameters) DeepCopyInto ¶
func (in *ProjectContainerregistryInitParameters) DeepCopyInto(out *ProjectContainerregistryInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectContainerregistryList ¶
type ProjectContainerregistryList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []ProjectContainerregistry `json:"items"`
}
ProjectContainerregistryList contains a list of ProjectContainerregistrys
func (*ProjectContainerregistryList) DeepCopy ¶
func (in *ProjectContainerregistryList) DeepCopy() *ProjectContainerregistryList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectContainerregistryList.
func (*ProjectContainerregistryList) DeepCopyInto ¶
func (in *ProjectContainerregistryList) DeepCopyInto(out *ProjectContainerregistryList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ProjectContainerregistryList) DeepCopyObject ¶
func (in *ProjectContainerregistryList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ProjectContainerregistryList) GetItems ¶
func (l *ProjectContainerregistryList) GetItems() []resource.Managed
GetItems of this ProjectContainerregistryList.
type ProjectContainerregistryObservation ¶
type ProjectContainerregistryObservation struct {
// Registry creation date
CreatedAt *string `json:"createdAt,omitempty" tf:"created_at,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// Registry name
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Plan of the registry
Plan []PlanObservation `json:"plan,omitempty" tf:"plan,omitempty"`
// Plan ID of the registry.
PlanID *string `json:"planId,omitempty" tf:"plan_id,omitempty"`
// Project ID of your registry
ProjectID *string `json:"projectId,omitempty" tf:"project_id,omitempty"`
// Region of the registry.
Region *string `json:"region,omitempty" tf:"region,omitempty"`
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Current size of the registry (bytes)
Size *float64 `json:"size,omitempty" tf:"size,omitempty"`
// Registry status
Status *string `json:"status,omitempty" tf:"status,omitempty"`
// Access url of the registry
URL *string `json:"url,omitempty" tf:"url,omitempty"`
// Registry last update date
UpdatedAt *string `json:"updatedAt,omitempty" tf:"updated_at,omitempty"`
// Version of your registry
Version *string `json:"version,omitempty" tf:"version,omitempty"`
}
func (*ProjectContainerregistryObservation) DeepCopy ¶
func (in *ProjectContainerregistryObservation) DeepCopy() *ProjectContainerregistryObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectContainerregistryObservation.
func (*ProjectContainerregistryObservation) DeepCopyInto ¶
func (in *ProjectContainerregistryObservation) DeepCopyInto(out *ProjectContainerregistryObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectContainerregistryParameters ¶
type ProjectContainerregistryParameters struct {
// Registry name
// +kubebuilder:validation:Optional
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Plan ID of the registry.
// +kubebuilder:validation:Optional
PlanID *string `json:"planId,omitempty" tf:"plan_id,omitempty"`
// Region of the registry.
// +kubebuilder:validation:Optional
Region *string `json:"region,omitempty" tf:"region,omitempty"`
// +kubebuilder:validation:Optional
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
}
func (*ProjectContainerregistryParameters) DeepCopy ¶
func (in *ProjectContainerregistryParameters) DeepCopy() *ProjectContainerregistryParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectContainerregistryParameters.
func (*ProjectContainerregistryParameters) DeepCopyInto ¶
func (in *ProjectContainerregistryParameters) DeepCopyInto(out *ProjectContainerregistryParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectContainerregistrySpec ¶
type ProjectContainerregistrySpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider ProjectContainerregistryParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider ProjectContainerregistryInitParameters `json:"initProvider,omitempty"`
}
ProjectContainerregistrySpec defines the desired state of ProjectContainerregistry
func (*ProjectContainerregistrySpec) DeepCopy ¶
func (in *ProjectContainerregistrySpec) DeepCopy() *ProjectContainerregistrySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectContainerregistrySpec.
func (*ProjectContainerregistrySpec) DeepCopyInto ¶
func (in *ProjectContainerregistrySpec) DeepCopyInto(out *ProjectContainerregistrySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectContainerregistryStatus ¶
type ProjectContainerregistryStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider ProjectContainerregistryObservation `json:"atProvider,omitempty"`
}
ProjectContainerregistryStatus defines the observed state of ProjectContainerregistry.
func (*ProjectContainerregistryStatus) DeepCopy ¶
func (in *ProjectContainerregistryStatus) DeepCopy() *ProjectContainerregistryStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectContainerregistryStatus.
func (*ProjectContainerregistryStatus) DeepCopyInto ¶
func (in *ProjectContainerregistryStatus) DeepCopyInto(out *ProjectContainerregistryStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RegistryLimitsInitParameters ¶
type RegistryLimitsInitParameters struct {
}
func (*RegistryLimitsInitParameters) DeepCopy ¶
func (in *RegistryLimitsInitParameters) DeepCopy() *RegistryLimitsInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RegistryLimitsInitParameters.
func (*RegistryLimitsInitParameters) DeepCopyInto ¶
func (in *RegistryLimitsInitParameters) DeepCopyInto(out *RegistryLimitsInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RegistryLimitsObservation ¶
type RegistryLimitsObservation struct {
ImageStorage *float64 `json:"imageStorage,omitempty" tf:"image_storage,omitempty"`
ParallelRequest *float64 `json:"parallelRequest,omitempty" tf:"parallel_request,omitempty"`
}
func (*RegistryLimitsObservation) DeepCopy ¶
func (in *RegistryLimitsObservation) DeepCopy() *RegistryLimitsObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RegistryLimitsObservation.
func (*RegistryLimitsObservation) DeepCopyInto ¶
func (in *RegistryLimitsObservation) DeepCopyInto(out *RegistryLimitsObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RegistryLimitsParameters ¶
type RegistryLimitsParameters struct {
}
func (*RegistryLimitsParameters) DeepCopy ¶
func (in *RegistryLimitsParameters) DeepCopy() *RegistryLimitsParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RegistryLimitsParameters.
func (*RegistryLimitsParameters) DeepCopyInto ¶
func (in *RegistryLimitsParameters) DeepCopyInto(out *RegistryLimitsParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.