Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=cloudprojectdatabase.crossplane.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type EndpointsInitParameters
- type EndpointsObservation
- type EndpointsParameters
- type NodesInitParameters
- type NodesObservation
- type NodesParameters
- type ProjectDatabase
- func (in *ProjectDatabase) DeepCopy() *ProjectDatabase
- func (in *ProjectDatabase) DeepCopyInto(out *ProjectDatabase)
- func (in *ProjectDatabase) DeepCopyObject() runtime.Object
- func (mg *ProjectDatabase) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *ProjectDatabase) GetConnectionDetailsMapping() map[string]string
- func (mg *ProjectDatabase) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *ProjectDatabase) GetID() string
- func (tr *ProjectDatabase) GetInitParameters() (map[string]any, error)
- func (mg *ProjectDatabase) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *ProjectDatabase) GetObservation() (map[string]any, error)
- func (tr *ProjectDatabase) GetParameters() (map[string]any, error)
- func (mg *ProjectDatabase) GetProviderConfigReference() *xpv1.Reference
- func (mg *ProjectDatabase) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *ProjectDatabase) GetTerraformResourceType() string
- func (tr *ProjectDatabase) GetTerraformSchemaVersion() int
- func (mg *ProjectDatabase) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *ProjectDatabase) LateInitialize(attrs []byte) (bool, error)
- func (mg *ProjectDatabase) SetConditions(c ...xpv1.Condition)
- func (mg *ProjectDatabase) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *ProjectDatabase) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *ProjectDatabase) SetObservation(obs map[string]any) error
- func (tr *ProjectDatabase) SetParameters(params map[string]any) error
- func (mg *ProjectDatabase) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *ProjectDatabase) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *ProjectDatabase) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type ProjectDatabaseInitParameters
- type ProjectDatabaseList
- type ProjectDatabaseObservation
- type ProjectDatabaseParameters
- type ProjectDatabaseSpec
- type ProjectDatabaseStatus
Constants ¶
const ( CRDGroup = "cloudprojectdatabase.crossplane.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( ProjectDatabase_Kind = "ProjectDatabase" ProjectDatabase_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: ProjectDatabase_Kind}.String() ProjectDatabase_KindAPIVersion = ProjectDatabase_Kind + "." + CRDGroupVersion.String() ProjectDatabase_GroupVersionKind = CRDGroupVersion.WithKind(ProjectDatabase_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type EndpointsInitParameters ¶
type EndpointsInitParameters struct {
}
func (*EndpointsInitParameters) DeepCopy ¶
func (in *EndpointsInitParameters) DeepCopy() *EndpointsInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EndpointsInitParameters.
func (*EndpointsInitParameters) DeepCopyInto ¶
func (in *EndpointsInitParameters) DeepCopyInto(out *EndpointsInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EndpointsObservation ¶
type EndpointsObservation struct {
Component *string `json:"component,omitempty" tf:"component,omitempty"`
Domain *string `json:"domain,omitempty" tf:"domain,omitempty"`
Path *string `json:"path,omitempty" tf:"path,omitempty"`
Port *float64 `json:"port,omitempty" tf:"port,omitempty"`
SSL *bool `json:"ssl,omitempty" tf:"ssl,omitempty"`
SSLMode *string `json:"sslMode,omitempty" tf:"ssl_mode,omitempty"`
Scheme *string `json:"scheme,omitempty" tf:"scheme,omitempty"`
URI *string `json:"uri,omitempty" tf:"uri,omitempty"`
}
func (*EndpointsObservation) DeepCopy ¶
func (in *EndpointsObservation) DeepCopy() *EndpointsObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EndpointsObservation.
func (*EndpointsObservation) DeepCopyInto ¶
func (in *EndpointsObservation) DeepCopyInto(out *EndpointsObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EndpointsParameters ¶
type EndpointsParameters struct {
}
func (*EndpointsParameters) DeepCopy ¶
func (in *EndpointsParameters) DeepCopy() *EndpointsParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EndpointsParameters.
func (*EndpointsParameters) DeepCopyInto ¶
func (in *EndpointsParameters) DeepCopyInto(out *EndpointsParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type NodesInitParameters ¶
type NodesInitParameters struct {
// Private network ID in which the node is. It's the regional openstackId of the private network.
NetworkID *string `json:"networkId,omitempty" tf:"network_id,omitempty"`
// Region of the node
Region *string `json:"region,omitempty" tf:"region,omitempty"`
// Private subnet ID in which the node is
SubnetID *string `json:"subnetId,omitempty" tf:"subnet_id,omitempty"`
}
func (*NodesInitParameters) DeepCopy ¶
func (in *NodesInitParameters) DeepCopy() *NodesInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NodesInitParameters.
func (*NodesInitParameters) DeepCopyInto ¶
func (in *NodesInitParameters) DeepCopyInto(out *NodesInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type NodesObservation ¶
type NodesObservation struct {
// Private network ID in which the node is. It's the regional openstackId of the private network.
NetworkID *string `json:"networkId,omitempty" tf:"network_id,omitempty"`
// Region of the node
Region *string `json:"region,omitempty" tf:"region,omitempty"`
// Private subnet ID in which the node is
SubnetID *string `json:"subnetId,omitempty" tf:"subnet_id,omitempty"`
}
func (*NodesObservation) DeepCopy ¶
func (in *NodesObservation) DeepCopy() *NodesObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NodesObservation.
func (*NodesObservation) DeepCopyInto ¶
func (in *NodesObservation) DeepCopyInto(out *NodesObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type NodesParameters ¶
type NodesParameters struct {
// Private network ID in which the node is. It's the regional openstackId of the private network.
// +kubebuilder:validation:Optional
NetworkID *string `json:"networkId,omitempty" tf:"network_id,omitempty"`
// Region of the node
// +kubebuilder:validation:Optional
Region *string `json:"region" tf:"region,omitempty"`
// Private subnet ID in which the node is
// +kubebuilder:validation:Optional
SubnetID *string `json:"subnetId,omitempty" tf:"subnet_id,omitempty"`
}
func (*NodesParameters) DeepCopy ¶
func (in *NodesParameters) DeepCopy() *NodesParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NodesParameters.
func (*NodesParameters) DeepCopyInto ¶
func (in *NodesParameters) DeepCopyInto(out *NodesParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectDatabase ¶
type ProjectDatabase struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.engine) || (has(self.initProvider) && has(self.initProvider.engine))",message="spec.forProvider.engine is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.flavor) || (has(self.initProvider) && has(self.initProvider.flavor))",message="spec.forProvider.flavor is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.nodes) || (has(self.initProvider) && has(self.initProvider.nodes))",message="spec.forProvider.nodes is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.plan) || (has(self.initProvider) && has(self.initProvider.plan))",message="spec.forProvider.plan is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.version) || (has(self.initProvider) && has(self.initProvider.version))",message="spec.forProvider.version is a required parameter"
Spec ProjectDatabaseSpec `json:"spec"`
Status ProjectDatabaseStatus `json:"status,omitempty"`
}
ProjectDatabase is the Schema for the ProjectDatabases API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}
func (*ProjectDatabase) DeepCopy ¶
func (in *ProjectDatabase) DeepCopy() *ProjectDatabase
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectDatabase.
func (*ProjectDatabase) DeepCopyInto ¶
func (in *ProjectDatabase) DeepCopyInto(out *ProjectDatabase)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ProjectDatabase) DeepCopyObject ¶
func (in *ProjectDatabase) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ProjectDatabase) GetCondition ¶
func (mg *ProjectDatabase) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this ProjectDatabase.
func (*ProjectDatabase) GetConnectionDetailsMapping ¶
func (tr *ProjectDatabase) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this ProjectDatabase
func (*ProjectDatabase) GetDeletionPolicy ¶
func (mg *ProjectDatabase) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this ProjectDatabase.
func (*ProjectDatabase) GetID ¶
func (tr *ProjectDatabase) GetID() string
GetID returns ID of underlying Terraform resource of this ProjectDatabase
func (*ProjectDatabase) GetInitParameters ¶
func (tr *ProjectDatabase) GetInitParameters() (map[string]any, error)
GetInitParameters of this ProjectDatabase
func (*ProjectDatabase) GetManagementPolicies ¶
func (mg *ProjectDatabase) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this ProjectDatabase.
func (*ProjectDatabase) GetObservation ¶
func (tr *ProjectDatabase) GetObservation() (map[string]any, error)
GetObservation of this ProjectDatabase
func (*ProjectDatabase) GetParameters ¶
func (tr *ProjectDatabase) GetParameters() (map[string]any, error)
GetParameters of this ProjectDatabase
func (*ProjectDatabase) GetProviderConfigReference ¶
func (mg *ProjectDatabase) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this ProjectDatabase.
func (*ProjectDatabase) GetPublishConnectionDetailsTo ¶
func (mg *ProjectDatabase) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this ProjectDatabase.
func (*ProjectDatabase) GetTerraformResourceType ¶
func (mg *ProjectDatabase) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this ProjectDatabase
func (*ProjectDatabase) GetTerraformSchemaVersion ¶
func (tr *ProjectDatabase) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*ProjectDatabase) GetWriteConnectionSecretToReference ¶
func (mg *ProjectDatabase) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this ProjectDatabase.
func (*ProjectDatabase) LateInitialize ¶
func (tr *ProjectDatabase) LateInitialize(attrs []byte) (bool, error)
LateInitialize this ProjectDatabase using its observed tfState. returns True if there are any spec changes for the resource.
func (*ProjectDatabase) SetConditions ¶
func (mg *ProjectDatabase) SetConditions(c ...xpv1.Condition)
SetConditions of this ProjectDatabase.
func (*ProjectDatabase) SetDeletionPolicy ¶
func (mg *ProjectDatabase) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this ProjectDatabase.
func (*ProjectDatabase) SetManagementPolicies ¶
func (mg *ProjectDatabase) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this ProjectDatabase.
func (*ProjectDatabase) SetObservation ¶
func (tr *ProjectDatabase) SetObservation(obs map[string]any) error
SetObservation for this ProjectDatabase
func (*ProjectDatabase) SetParameters ¶
func (tr *ProjectDatabase) SetParameters(params map[string]any) error
SetParameters for this ProjectDatabase
func (*ProjectDatabase) SetProviderConfigReference ¶
func (mg *ProjectDatabase) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this ProjectDatabase.
func (*ProjectDatabase) SetPublishConnectionDetailsTo ¶
func (mg *ProjectDatabase) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this ProjectDatabase.
func (*ProjectDatabase) SetWriteConnectionSecretToReference ¶
func (mg *ProjectDatabase) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this ProjectDatabase.
type ProjectDatabaseInitParameters ¶
type ProjectDatabaseInitParameters struct {
// Advanced configuration key / value
AdvancedConfiguration map[string]*string `json:"advancedConfiguration,omitempty" tf:"advanced_configuration,omitempty"`
// Description of the cluster
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// Disk size attributes of the cluster
DiskSize *float64 `json:"diskSize,omitempty" tf:"disk_size,omitempty"`
// Name of the engine of the service
Engine *string `json:"engine,omitempty" tf:"engine,omitempty"`
// The node flavor used for this cluster
Flavor *string `json:"flavor,omitempty" tf:"flavor,omitempty"`
// Defines whether the REST API is enabled on a Kafka cluster
KafkaRestAPI *bool `json:"kafkaRestApi,omitempty" tf:"kafka_rest_api,omitempty"`
// List of nodes composing the service
Nodes []NodesInitParameters `json:"nodes,omitempty" tf:"nodes,omitempty"`
// Defines whether the ACLs are enabled on an Opensearch cluster
OpensearchAclsEnabled *bool `json:"opensearchAclsEnabled,omitempty" tf:"opensearch_acls_enabled,omitempty"`
// Plan of the cluster
Plan *string `json:"plan,omitempty" tf:"plan,omitempty"`
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Version of the engine deployed on the cluster
Version *string `json:"version,omitempty" tf:"version,omitempty"`
}
func (*ProjectDatabaseInitParameters) DeepCopy ¶
func (in *ProjectDatabaseInitParameters) DeepCopy() *ProjectDatabaseInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectDatabaseInitParameters.
func (*ProjectDatabaseInitParameters) DeepCopyInto ¶
func (in *ProjectDatabaseInitParameters) DeepCopyInto(out *ProjectDatabaseInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectDatabaseList ¶
type ProjectDatabaseList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []ProjectDatabase `json:"items"`
}
ProjectDatabaseList contains a list of ProjectDatabases
func (*ProjectDatabaseList) DeepCopy ¶
func (in *ProjectDatabaseList) DeepCopy() *ProjectDatabaseList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectDatabaseList.
func (*ProjectDatabaseList) DeepCopyInto ¶
func (in *ProjectDatabaseList) DeepCopyInto(out *ProjectDatabaseList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ProjectDatabaseList) DeepCopyObject ¶
func (in *ProjectDatabaseList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ProjectDatabaseList) GetItems ¶
func (l *ProjectDatabaseList) GetItems() []resource.Managed
GetItems of this ProjectDatabaseList.
type ProjectDatabaseObservation ¶
type ProjectDatabaseObservation struct {
// Advanced configuration key / value
AdvancedConfiguration map[string]*string `json:"advancedConfiguration,omitempty" tf:"advanced_configuration,omitempty"`
// Time on which backups start every day
BackupTime *string `json:"backupTime,omitempty" tf:"backup_time,omitempty"`
// Date of the creation of the cluster
CreatedAt *string `json:"createdAt,omitempty" tf:"created_at,omitempty"`
// Description of the cluster
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// Disk size attributes of the cluster
DiskSize *float64 `json:"diskSize,omitempty" tf:"disk_size,omitempty"`
// Disk type attributes of the cluster
DiskType *string `json:"diskType,omitempty" tf:"disk_type,omitempty"`
// List of all endpoints of the service
Endpoints []EndpointsObservation `json:"endpoints,omitempty" tf:"endpoints,omitempty"`
// Name of the engine of the service
Engine *string `json:"engine,omitempty" tf:"engine,omitempty"`
// The node flavor used for this cluster
Flavor *string `json:"flavor,omitempty" tf:"flavor,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// Defines whether the REST API is enabled on a Kafka cluster
KafkaRestAPI *bool `json:"kafkaRestApi,omitempty" tf:"kafka_rest_api,omitempty"`
// Time on which maintenances can start every day
MaintenanceTime *string `json:"maintenanceTime,omitempty" tf:"maintenance_time,omitempty"`
// Type of network of the cluster
NetworkType *string `json:"networkType,omitempty" tf:"network_type,omitempty"`
// List of nodes composing the service
Nodes []NodesObservation `json:"nodes,omitempty" tf:"nodes,omitempty"`
// Defines whether the ACLs are enabled on an Opensearch cluster
OpensearchAclsEnabled *bool `json:"opensearchAclsEnabled,omitempty" tf:"opensearch_acls_enabled,omitempty"`
// Plan of the cluster
Plan *string `json:"plan,omitempty" tf:"plan,omitempty"`
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Current status of the cluster
Status *string `json:"status,omitempty" tf:"status,omitempty"`
// Version of the engine deployed on the cluster
Version *string `json:"version,omitempty" tf:"version,omitempty"`
}
func (*ProjectDatabaseObservation) DeepCopy ¶
func (in *ProjectDatabaseObservation) DeepCopy() *ProjectDatabaseObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectDatabaseObservation.
func (*ProjectDatabaseObservation) DeepCopyInto ¶
func (in *ProjectDatabaseObservation) DeepCopyInto(out *ProjectDatabaseObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectDatabaseParameters ¶
type ProjectDatabaseParameters struct {
// Advanced configuration key / value
// +kubebuilder:validation:Optional
AdvancedConfiguration map[string]*string `json:"advancedConfiguration,omitempty" tf:"advanced_configuration,omitempty"`
// Description of the cluster
// +kubebuilder:validation:Optional
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// Disk size attributes of the cluster
// +kubebuilder:validation:Optional
DiskSize *float64 `json:"diskSize,omitempty" tf:"disk_size,omitempty"`
// Name of the engine of the service
// +kubebuilder:validation:Optional
Engine *string `json:"engine,omitempty" tf:"engine,omitempty"`
// The node flavor used for this cluster
// +kubebuilder:validation:Optional
Flavor *string `json:"flavor,omitempty" tf:"flavor,omitempty"`
// Defines whether the REST API is enabled on a Kafka cluster
// +kubebuilder:validation:Optional
KafkaRestAPI *bool `json:"kafkaRestApi,omitempty" tf:"kafka_rest_api,omitempty"`
// List of nodes composing the service
// +kubebuilder:validation:Optional
Nodes []NodesParameters `json:"nodes,omitempty" tf:"nodes,omitempty"`
// Defines whether the ACLs are enabled on an Opensearch cluster
// +kubebuilder:validation:Optional
OpensearchAclsEnabled *bool `json:"opensearchAclsEnabled,omitempty" tf:"opensearch_acls_enabled,omitempty"`
// Plan of the cluster
// +kubebuilder:validation:Optional
Plan *string `json:"plan,omitempty" tf:"plan,omitempty"`
// +kubebuilder:validation:Optional
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Version of the engine deployed on the cluster
// +kubebuilder:validation:Optional
Version *string `json:"version,omitempty" tf:"version,omitempty"`
}
func (*ProjectDatabaseParameters) DeepCopy ¶
func (in *ProjectDatabaseParameters) DeepCopy() *ProjectDatabaseParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectDatabaseParameters.
func (*ProjectDatabaseParameters) DeepCopyInto ¶
func (in *ProjectDatabaseParameters) DeepCopyInto(out *ProjectDatabaseParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectDatabaseSpec ¶
type ProjectDatabaseSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider ProjectDatabaseParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider ProjectDatabaseInitParameters `json:"initProvider,omitempty"`
}
ProjectDatabaseSpec defines the desired state of ProjectDatabase
func (*ProjectDatabaseSpec) DeepCopy ¶
func (in *ProjectDatabaseSpec) DeepCopy() *ProjectDatabaseSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectDatabaseSpec.
func (*ProjectDatabaseSpec) DeepCopyInto ¶
func (in *ProjectDatabaseSpec) DeepCopyInto(out *ProjectDatabaseSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectDatabaseStatus ¶
type ProjectDatabaseStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider ProjectDatabaseObservation `json:"atProvider,omitempty"`
}
ProjectDatabaseStatus defines the observed state of ProjectDatabase.
func (*ProjectDatabaseStatus) DeepCopy ¶
func (in *ProjectDatabaseStatus) DeepCopy() *ProjectDatabaseStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectDatabaseStatus.
func (*ProjectDatabaseStatus) DeepCopyInto ¶
func (in *ProjectDatabaseStatus) DeepCopyInto(out *ProjectDatabaseStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.