Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=cloudprojectdatabaseiprestriction.crossplane.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type ProjectDatabaseIPRestriction
- func (in *ProjectDatabaseIPRestriction) DeepCopy() *ProjectDatabaseIPRestriction
- func (in *ProjectDatabaseIPRestriction) DeepCopyInto(out *ProjectDatabaseIPRestriction)
- func (in *ProjectDatabaseIPRestriction) DeepCopyObject() runtime.Object
- func (mg *ProjectDatabaseIPRestriction) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *ProjectDatabaseIPRestriction) GetConnectionDetailsMapping() map[string]string
- func (mg *ProjectDatabaseIPRestriction) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *ProjectDatabaseIPRestriction) GetID() string
- func (tr *ProjectDatabaseIPRestriction) GetInitParameters() (map[string]any, error)
- func (mg *ProjectDatabaseIPRestriction) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *ProjectDatabaseIPRestriction) GetObservation() (map[string]any, error)
- func (tr *ProjectDatabaseIPRestriction) GetParameters() (map[string]any, error)
- func (mg *ProjectDatabaseIPRestriction) GetProviderConfigReference() *xpv1.Reference
- func (mg *ProjectDatabaseIPRestriction) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *ProjectDatabaseIPRestriction) GetTerraformResourceType() string
- func (tr *ProjectDatabaseIPRestriction) GetTerraformSchemaVersion() int
- func (mg *ProjectDatabaseIPRestriction) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *ProjectDatabaseIPRestriction) LateInitialize(attrs []byte) (bool, error)
- func (mg *ProjectDatabaseIPRestriction) SetConditions(c ...xpv1.Condition)
- func (mg *ProjectDatabaseIPRestriction) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *ProjectDatabaseIPRestriction) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *ProjectDatabaseIPRestriction) SetObservation(obs map[string]any) error
- func (tr *ProjectDatabaseIPRestriction) SetParameters(params map[string]any) error
- func (mg *ProjectDatabaseIPRestriction) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *ProjectDatabaseIPRestriction) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *ProjectDatabaseIPRestriction) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type ProjectDatabaseIPRestrictionInitParameters
- type ProjectDatabaseIPRestrictionList
- func (in *ProjectDatabaseIPRestrictionList) DeepCopy() *ProjectDatabaseIPRestrictionList
- func (in *ProjectDatabaseIPRestrictionList) DeepCopyInto(out *ProjectDatabaseIPRestrictionList)
- func (in *ProjectDatabaseIPRestrictionList) DeepCopyObject() runtime.Object
- func (l *ProjectDatabaseIPRestrictionList) GetItems() []resource.Managed
- type ProjectDatabaseIPRestrictionObservation
- type ProjectDatabaseIPRestrictionParameters
- type ProjectDatabaseIPRestrictionSpec
- type ProjectDatabaseIPRestrictionStatus
Constants ¶
const ( CRDGroup = "cloudprojectdatabaseiprestriction.crossplane.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( ProjectDatabaseIPRestriction_Kind = "ProjectDatabaseIPRestriction" ProjectDatabaseIPRestriction_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: ProjectDatabaseIPRestriction_Kind}.String() ProjectDatabaseIPRestriction_KindAPIVersion = ProjectDatabaseIPRestriction_Kind + "." + CRDGroupVersion.String() ProjectDatabaseIPRestriction_GroupVersionKind = CRDGroupVersion.WithKind(ProjectDatabaseIPRestriction_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type ProjectDatabaseIPRestriction ¶
type ProjectDatabaseIPRestriction struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.clusterId) || (has(self.initProvider) && has(self.initProvider.clusterId))",message="spec.forProvider.clusterId is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.engine) || (has(self.initProvider) && has(self.initProvider.engine))",message="spec.forProvider.engine is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.ip) || (has(self.initProvider) && has(self.initProvider.ip))",message="spec.forProvider.ip is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
Spec ProjectDatabaseIPRestrictionSpec `json:"spec"`
Status ProjectDatabaseIPRestrictionStatus `json:"status,omitempty"`
}
ProjectDatabaseIPRestriction is the Schema for the ProjectDatabaseIPRestrictions API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}
func (*ProjectDatabaseIPRestriction) DeepCopy ¶
func (in *ProjectDatabaseIPRestriction) DeepCopy() *ProjectDatabaseIPRestriction
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectDatabaseIPRestriction.
func (*ProjectDatabaseIPRestriction) DeepCopyInto ¶
func (in *ProjectDatabaseIPRestriction) DeepCopyInto(out *ProjectDatabaseIPRestriction)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ProjectDatabaseIPRestriction) DeepCopyObject ¶
func (in *ProjectDatabaseIPRestriction) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ProjectDatabaseIPRestriction) GetCondition ¶
func (mg *ProjectDatabaseIPRestriction) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this ProjectDatabaseIPRestriction.
func (*ProjectDatabaseIPRestriction) GetConnectionDetailsMapping ¶
func (tr *ProjectDatabaseIPRestriction) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this ProjectDatabaseIPRestriction
func (*ProjectDatabaseIPRestriction) GetDeletionPolicy ¶
func (mg *ProjectDatabaseIPRestriction) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this ProjectDatabaseIPRestriction.
func (*ProjectDatabaseIPRestriction) GetID ¶
func (tr *ProjectDatabaseIPRestriction) GetID() string
GetID returns ID of underlying Terraform resource of this ProjectDatabaseIPRestriction
func (*ProjectDatabaseIPRestriction) GetInitParameters ¶
func (tr *ProjectDatabaseIPRestriction) GetInitParameters() (map[string]any, error)
GetInitParameters of this ProjectDatabaseIPRestriction
func (*ProjectDatabaseIPRestriction) GetManagementPolicies ¶
func (mg *ProjectDatabaseIPRestriction) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this ProjectDatabaseIPRestriction.
func (*ProjectDatabaseIPRestriction) GetObservation ¶
func (tr *ProjectDatabaseIPRestriction) GetObservation() (map[string]any, error)
GetObservation of this ProjectDatabaseIPRestriction
func (*ProjectDatabaseIPRestriction) GetParameters ¶
func (tr *ProjectDatabaseIPRestriction) GetParameters() (map[string]any, error)
GetParameters of this ProjectDatabaseIPRestriction
func (*ProjectDatabaseIPRestriction) GetProviderConfigReference ¶
func (mg *ProjectDatabaseIPRestriction) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this ProjectDatabaseIPRestriction.
func (*ProjectDatabaseIPRestriction) GetPublishConnectionDetailsTo ¶
func (mg *ProjectDatabaseIPRestriction) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this ProjectDatabaseIPRestriction.
func (*ProjectDatabaseIPRestriction) GetTerraformResourceType ¶
func (mg *ProjectDatabaseIPRestriction) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this ProjectDatabaseIPRestriction
func (*ProjectDatabaseIPRestriction) GetTerraformSchemaVersion ¶
func (tr *ProjectDatabaseIPRestriction) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*ProjectDatabaseIPRestriction) GetWriteConnectionSecretToReference ¶
func (mg *ProjectDatabaseIPRestriction) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this ProjectDatabaseIPRestriction.
func (*ProjectDatabaseIPRestriction) LateInitialize ¶
func (tr *ProjectDatabaseIPRestriction) LateInitialize(attrs []byte) (bool, error)
LateInitialize this ProjectDatabaseIPRestriction using its observed tfState. returns True if there are any spec changes for the resource.
func (*ProjectDatabaseIPRestriction) SetConditions ¶
func (mg *ProjectDatabaseIPRestriction) SetConditions(c ...xpv1.Condition)
SetConditions of this ProjectDatabaseIPRestriction.
func (*ProjectDatabaseIPRestriction) SetDeletionPolicy ¶
func (mg *ProjectDatabaseIPRestriction) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this ProjectDatabaseIPRestriction.
func (*ProjectDatabaseIPRestriction) SetManagementPolicies ¶
func (mg *ProjectDatabaseIPRestriction) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this ProjectDatabaseIPRestriction.
func (*ProjectDatabaseIPRestriction) SetObservation ¶
func (tr *ProjectDatabaseIPRestriction) SetObservation(obs map[string]any) error
SetObservation for this ProjectDatabaseIPRestriction
func (*ProjectDatabaseIPRestriction) SetParameters ¶
func (tr *ProjectDatabaseIPRestriction) SetParameters(params map[string]any) error
SetParameters for this ProjectDatabaseIPRestriction
func (*ProjectDatabaseIPRestriction) SetProviderConfigReference ¶
func (mg *ProjectDatabaseIPRestriction) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this ProjectDatabaseIPRestriction.
func (*ProjectDatabaseIPRestriction) SetPublishConnectionDetailsTo ¶
func (mg *ProjectDatabaseIPRestriction) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this ProjectDatabaseIPRestriction.
func (*ProjectDatabaseIPRestriction) SetWriteConnectionSecretToReference ¶
func (mg *ProjectDatabaseIPRestriction) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this ProjectDatabaseIPRestriction.
type ProjectDatabaseIPRestrictionInitParameters ¶
type ProjectDatabaseIPRestrictionInitParameters struct {
// Id of the database cluster
ClusterID *string `json:"clusterId,omitempty" tf:"cluster_id,omitempty"`
// Description of the IP restriction
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// Name of the engine of the service
Engine *string `json:"engine,omitempty" tf:"engine,omitempty"`
// Authorized IP
IP *string `json:"ip,omitempty" tf:"ip,omitempty"`
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
}
func (*ProjectDatabaseIPRestrictionInitParameters) DeepCopy ¶
func (in *ProjectDatabaseIPRestrictionInitParameters) DeepCopy() *ProjectDatabaseIPRestrictionInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectDatabaseIPRestrictionInitParameters.
func (*ProjectDatabaseIPRestrictionInitParameters) DeepCopyInto ¶
func (in *ProjectDatabaseIPRestrictionInitParameters) DeepCopyInto(out *ProjectDatabaseIPRestrictionInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectDatabaseIPRestrictionList ¶
type ProjectDatabaseIPRestrictionList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []ProjectDatabaseIPRestriction `json:"items"`
}
ProjectDatabaseIPRestrictionList contains a list of ProjectDatabaseIPRestrictions
func (*ProjectDatabaseIPRestrictionList) DeepCopy ¶
func (in *ProjectDatabaseIPRestrictionList) DeepCopy() *ProjectDatabaseIPRestrictionList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectDatabaseIPRestrictionList.
func (*ProjectDatabaseIPRestrictionList) DeepCopyInto ¶
func (in *ProjectDatabaseIPRestrictionList) DeepCopyInto(out *ProjectDatabaseIPRestrictionList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ProjectDatabaseIPRestrictionList) DeepCopyObject ¶
func (in *ProjectDatabaseIPRestrictionList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ProjectDatabaseIPRestrictionList) GetItems ¶
func (l *ProjectDatabaseIPRestrictionList) GetItems() []resource.Managed
GetItems of this ProjectDatabaseIPRestrictionList.
type ProjectDatabaseIPRestrictionObservation ¶
type ProjectDatabaseIPRestrictionObservation struct {
// Id of the database cluster
ClusterID *string `json:"clusterId,omitempty" tf:"cluster_id,omitempty"`
// Description of the IP restriction
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// Name of the engine of the service
Engine *string `json:"engine,omitempty" tf:"engine,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// Authorized IP
IP *string `json:"ip,omitempty" tf:"ip,omitempty"`
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Current status of the IP restriction
Status *string `json:"status,omitempty" tf:"status,omitempty"`
}
func (*ProjectDatabaseIPRestrictionObservation) DeepCopy ¶
func (in *ProjectDatabaseIPRestrictionObservation) DeepCopy() *ProjectDatabaseIPRestrictionObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectDatabaseIPRestrictionObservation.
func (*ProjectDatabaseIPRestrictionObservation) DeepCopyInto ¶
func (in *ProjectDatabaseIPRestrictionObservation) DeepCopyInto(out *ProjectDatabaseIPRestrictionObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectDatabaseIPRestrictionParameters ¶
type ProjectDatabaseIPRestrictionParameters struct {
// Id of the database cluster
// +kubebuilder:validation:Optional
ClusterID *string `json:"clusterId,omitempty" tf:"cluster_id,omitempty"`
// Description of the IP restriction
// +kubebuilder:validation:Optional
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// Name of the engine of the service
// +kubebuilder:validation:Optional
Engine *string `json:"engine,omitempty" tf:"engine,omitempty"`
// Authorized IP
// +kubebuilder:validation:Optional
IP *string `json:"ip,omitempty" tf:"ip,omitempty"`
// +kubebuilder:validation:Optional
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
}
func (*ProjectDatabaseIPRestrictionParameters) DeepCopy ¶
func (in *ProjectDatabaseIPRestrictionParameters) DeepCopy() *ProjectDatabaseIPRestrictionParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectDatabaseIPRestrictionParameters.
func (*ProjectDatabaseIPRestrictionParameters) DeepCopyInto ¶
func (in *ProjectDatabaseIPRestrictionParameters) DeepCopyInto(out *ProjectDatabaseIPRestrictionParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectDatabaseIPRestrictionSpec ¶
type ProjectDatabaseIPRestrictionSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider ProjectDatabaseIPRestrictionParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider ProjectDatabaseIPRestrictionInitParameters `json:"initProvider,omitempty"`
}
ProjectDatabaseIPRestrictionSpec defines the desired state of ProjectDatabaseIPRestriction
func (*ProjectDatabaseIPRestrictionSpec) DeepCopy ¶
func (in *ProjectDatabaseIPRestrictionSpec) DeepCopy() *ProjectDatabaseIPRestrictionSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectDatabaseIPRestrictionSpec.
func (*ProjectDatabaseIPRestrictionSpec) DeepCopyInto ¶
func (in *ProjectDatabaseIPRestrictionSpec) DeepCopyInto(out *ProjectDatabaseIPRestrictionSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectDatabaseIPRestrictionStatus ¶
type ProjectDatabaseIPRestrictionStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider ProjectDatabaseIPRestrictionObservation `json:"atProvider,omitempty"`
}
ProjectDatabaseIPRestrictionStatus defines the observed state of ProjectDatabaseIPRestriction.
func (*ProjectDatabaseIPRestrictionStatus) DeepCopy ¶
func (in *ProjectDatabaseIPRestrictionStatus) DeepCopy() *ProjectDatabaseIPRestrictionStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectDatabaseIPRestrictionStatus.
func (*ProjectDatabaseIPRestrictionStatus) DeepCopyInto ¶
func (in *ProjectDatabaseIPRestrictionStatus) DeepCopyInto(out *ProjectDatabaseIPRestrictionStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.