v1alpha1

package
v0.0.0-...-73c97c3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 17, 2024 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

+kubebuilder:object:generate=true +groupName=cloudprojectkube.crossplane.io +versionName=v1alpha1

Index

Constants

const (
	CRDGroup   = "cloudprojectkube.crossplane.io"
	CRDVersion = "v1alpha1"
)

Package type metadata.

Variables

var (
	// CRDGroupVersion is the API Group Version used to register the objects
	CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)
var (
	ProjectKube_Kind             = "ProjectKube"
	ProjectKube_GroupKind        = schema.GroupKind{Group: CRDGroup, Kind: ProjectKube_Kind}.String()
	ProjectKube_KindAPIVersion   = ProjectKube_Kind + "." + CRDGroupVersion.String()
	ProjectKube_GroupVersionKind = CRDGroupVersion.WithKind(ProjectKube_Kind)
)

Repository type metadata.

Functions

This section is empty.

Types

type AdmissionpluginsInitParameters

type AdmissionpluginsInitParameters struct {
	Disabled []*string `json:"disabled,omitempty" tf:"disabled,omitempty"`

	Enabled []*string `json:"enabled,omitempty" tf:"enabled,omitempty"`
}

func (*AdmissionpluginsInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AdmissionpluginsInitParameters.

func (*AdmissionpluginsInitParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type AdmissionpluginsObservation

type AdmissionpluginsObservation struct {
	Disabled []*string `json:"disabled,omitempty" tf:"disabled,omitempty"`

	Enabled []*string `json:"enabled,omitempty" tf:"enabled,omitempty"`
}

func (*AdmissionpluginsObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AdmissionpluginsObservation.

func (*AdmissionpluginsObservation) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type AdmissionpluginsParameters

type AdmissionpluginsParameters struct {

	// +kubebuilder:validation:Optional
	Disabled []*string `json:"disabled,omitempty" tf:"disabled,omitempty"`

	// +kubebuilder:validation:Optional
	Enabled []*string `json:"enabled,omitempty" tf:"enabled,omitempty"`
}

func (*AdmissionpluginsParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AdmissionpluginsParameters.

func (*AdmissionpluginsParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ApiserverInitParameters

type ApiserverInitParameters struct {
	Admissionplugins []AdmissionpluginsInitParameters `json:"admissionplugins,omitempty" tf:"admissionplugins,omitempty"`
}

func (*ApiserverInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApiserverInitParameters.

func (*ApiserverInitParameters) DeepCopyInto

func (in *ApiserverInitParameters) DeepCopyInto(out *ApiserverInitParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ApiserverObservation

type ApiserverObservation struct {
	Admissionplugins []AdmissionpluginsObservation `json:"admissionplugins,omitempty" tf:"admissionplugins,omitempty"`
}

func (*ApiserverObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApiserverObservation.

func (*ApiserverObservation) DeepCopyInto

func (in *ApiserverObservation) DeepCopyInto(out *ApiserverObservation)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ApiserverParameters

type ApiserverParameters struct {

	// +kubebuilder:validation:Optional
	Admissionplugins []AdmissionpluginsParameters `json:"admissionplugins,omitempty" tf:"admissionplugins,omitempty"`
}

func (*ApiserverParameters) DeepCopy

func (in *ApiserverParameters) DeepCopy() *ApiserverParameters

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApiserverParameters.

func (*ApiserverParameters) DeepCopyInto

func (in *ApiserverParameters) DeepCopyInto(out *ApiserverParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type CustomizationApiserverAdmissionpluginsInitParameters

type CustomizationApiserverAdmissionpluginsInitParameters struct {
	Disabled []*string `json:"disabled,omitempty" tf:"disabled,omitempty"`

	Enabled []*string `json:"enabled,omitempty" tf:"enabled,omitempty"`
}

func (*CustomizationApiserverAdmissionpluginsInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomizationApiserverAdmissionpluginsInitParameters.

func (*CustomizationApiserverAdmissionpluginsInitParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type CustomizationApiserverAdmissionpluginsObservation

type CustomizationApiserverAdmissionpluginsObservation struct {
	Disabled []*string `json:"disabled,omitempty" tf:"disabled,omitempty"`

	Enabled []*string `json:"enabled,omitempty" tf:"enabled,omitempty"`
}

func (*CustomizationApiserverAdmissionpluginsObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomizationApiserverAdmissionpluginsObservation.

func (*CustomizationApiserverAdmissionpluginsObservation) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type CustomizationApiserverAdmissionpluginsParameters

type CustomizationApiserverAdmissionpluginsParameters struct {

	// +kubebuilder:validation:Optional
	Disabled []*string `json:"disabled,omitempty" tf:"disabled,omitempty"`

	// +kubebuilder:validation:Optional
	Enabled []*string `json:"enabled,omitempty" tf:"enabled,omitempty"`
}

func (*CustomizationApiserverAdmissionpluginsParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomizationApiserverAdmissionpluginsParameters.

func (*CustomizationApiserverAdmissionpluginsParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type CustomizationApiserverInitParameters

type CustomizationApiserverInitParameters struct {
	Admissionplugins []CustomizationApiserverAdmissionpluginsInitParameters `json:"admissionplugins,omitempty" tf:"admissionplugins,omitempty"`
}

func (*CustomizationApiserverInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomizationApiserverInitParameters.

func (*CustomizationApiserverInitParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type CustomizationApiserverObservation

type CustomizationApiserverObservation struct {
	Admissionplugins []CustomizationApiserverAdmissionpluginsObservation `json:"admissionplugins,omitempty" tf:"admissionplugins,omitempty"`
}

func (*CustomizationApiserverObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomizationApiserverObservation.

func (*CustomizationApiserverObservation) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type CustomizationApiserverParameters

type CustomizationApiserverParameters struct {

	// +kubebuilder:validation:Optional
	Admissionplugins []CustomizationApiserverAdmissionpluginsParameters `json:"admissionplugins,omitempty" tf:"admissionplugins,omitempty"`
}

func (*CustomizationApiserverParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomizationApiserverParameters.

func (*CustomizationApiserverParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type CustomizationInitParameters

type CustomizationInitParameters struct {
	Apiserver []ApiserverInitParameters `json:"apiserver,omitempty" tf:"apiserver,omitempty"`
}

func (*CustomizationInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomizationInitParameters.

func (*CustomizationInitParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type CustomizationKubeProxyInitParameters

type CustomizationKubeProxyInitParameters struct {
	Iptables []IptablesInitParameters `json:"iptables,omitempty" tf:"iptables,omitempty"`

	Ipvs []IpvsInitParameters `json:"ipvs,omitempty" tf:"ipvs,omitempty"`
}

func (*CustomizationKubeProxyInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomizationKubeProxyInitParameters.

func (*CustomizationKubeProxyInitParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type CustomizationKubeProxyObservation

type CustomizationKubeProxyObservation struct {
	Iptables []IptablesObservation `json:"iptables,omitempty" tf:"iptables,omitempty"`

	Ipvs []IpvsObservation `json:"ipvs,omitempty" tf:"ipvs,omitempty"`
}

func (*CustomizationKubeProxyObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomizationKubeProxyObservation.

func (*CustomizationKubeProxyObservation) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type CustomizationKubeProxyParameters

type CustomizationKubeProxyParameters struct {

	// +kubebuilder:validation:Optional
	Iptables []IptablesParameters `json:"iptables,omitempty" tf:"iptables,omitempty"`

	// +kubebuilder:validation:Optional
	Ipvs []IpvsParameters `json:"ipvs,omitempty" tf:"ipvs,omitempty"`
}

func (*CustomizationKubeProxyParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomizationKubeProxyParameters.

func (*CustomizationKubeProxyParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type CustomizationObservation

type CustomizationObservation struct {
	Apiserver []ApiserverObservation `json:"apiserver,omitempty" tf:"apiserver,omitempty"`
}

func (*CustomizationObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomizationObservation.

func (*CustomizationObservation) DeepCopyInto

func (in *CustomizationObservation) DeepCopyInto(out *CustomizationObservation)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type CustomizationParameters

type CustomizationParameters struct {

	// +kubebuilder:validation:Optional
	Apiserver []ApiserverParameters `json:"apiserver,omitempty" tf:"apiserver,omitempty"`
}

func (*CustomizationParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomizationParameters.

func (*CustomizationParameters) DeepCopyInto

func (in *CustomizationParameters) DeepCopyInto(out *CustomizationParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type IptablesInitParameters

type IptablesInitParameters struct {
	MinSyncPeriod *string `json:"minSyncPeriod,omitempty" tf:"min_sync_period,omitempty"`

	SyncPeriod *string `json:"syncPeriod,omitempty" tf:"sync_period,omitempty"`
}

func (*IptablesInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IptablesInitParameters.

func (*IptablesInitParameters) DeepCopyInto

func (in *IptablesInitParameters) DeepCopyInto(out *IptablesInitParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type IptablesObservation

type IptablesObservation struct {
	MinSyncPeriod *string `json:"minSyncPeriod,omitempty" tf:"min_sync_period,omitempty"`

	SyncPeriod *string `json:"syncPeriod,omitempty" tf:"sync_period,omitempty"`
}

func (*IptablesObservation) DeepCopy

func (in *IptablesObservation) DeepCopy() *IptablesObservation

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IptablesObservation.

func (*IptablesObservation) DeepCopyInto

func (in *IptablesObservation) DeepCopyInto(out *IptablesObservation)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type IptablesParameters

type IptablesParameters struct {

	// +kubebuilder:validation:Optional
	MinSyncPeriod *string `json:"minSyncPeriod,omitempty" tf:"min_sync_period,omitempty"`

	// +kubebuilder:validation:Optional
	SyncPeriod *string `json:"syncPeriod,omitempty" tf:"sync_period,omitempty"`
}

func (*IptablesParameters) DeepCopy

func (in *IptablesParameters) DeepCopy() *IptablesParameters

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IptablesParameters.

func (*IptablesParameters) DeepCopyInto

func (in *IptablesParameters) DeepCopyInto(out *IptablesParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type IpvsInitParameters

type IpvsInitParameters struct {
	MinSyncPeriod *string `json:"minSyncPeriod,omitempty" tf:"min_sync_period,omitempty"`

	Scheduler *string `json:"scheduler,omitempty" tf:"scheduler,omitempty"`

	SyncPeriod *string `json:"syncPeriod,omitempty" tf:"sync_period,omitempty"`

	TCPFinTimeout *string `json:"tcpFinTimeout,omitempty" tf:"tcp_fin_timeout,omitempty"`

	TCPTimeout *string `json:"tcpTimeout,omitempty" tf:"tcp_timeout,omitempty"`

	UDPTimeout *string `json:"udpTimeout,omitempty" tf:"udp_timeout,omitempty"`
}

func (*IpvsInitParameters) DeepCopy

func (in *IpvsInitParameters) DeepCopy() *IpvsInitParameters

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IpvsInitParameters.

func (*IpvsInitParameters) DeepCopyInto

func (in *IpvsInitParameters) DeepCopyInto(out *IpvsInitParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type IpvsObservation

type IpvsObservation struct {
	MinSyncPeriod *string `json:"minSyncPeriod,omitempty" tf:"min_sync_period,omitempty"`

	Scheduler *string `json:"scheduler,omitempty" tf:"scheduler,omitempty"`

	SyncPeriod *string `json:"syncPeriod,omitempty" tf:"sync_period,omitempty"`

	TCPFinTimeout *string `json:"tcpFinTimeout,omitempty" tf:"tcp_fin_timeout,omitempty"`

	TCPTimeout *string `json:"tcpTimeout,omitempty" tf:"tcp_timeout,omitempty"`

	UDPTimeout *string `json:"udpTimeout,omitempty" tf:"udp_timeout,omitempty"`
}

func (*IpvsObservation) DeepCopy

func (in *IpvsObservation) DeepCopy() *IpvsObservation

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IpvsObservation.

func (*IpvsObservation) DeepCopyInto

func (in *IpvsObservation) DeepCopyInto(out *IpvsObservation)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type IpvsParameters

type IpvsParameters struct {

	// +kubebuilder:validation:Optional
	MinSyncPeriod *string `json:"minSyncPeriod,omitempty" tf:"min_sync_period,omitempty"`

	// +kubebuilder:validation:Optional
	Scheduler *string `json:"scheduler,omitempty" tf:"scheduler,omitempty"`

	// +kubebuilder:validation:Optional
	SyncPeriod *string `json:"syncPeriod,omitempty" tf:"sync_period,omitempty"`

	// +kubebuilder:validation:Optional
	TCPFinTimeout *string `json:"tcpFinTimeout,omitempty" tf:"tcp_fin_timeout,omitempty"`

	// +kubebuilder:validation:Optional
	TCPTimeout *string `json:"tcpTimeout,omitempty" tf:"tcp_timeout,omitempty"`

	// +kubebuilder:validation:Optional
	UDPTimeout *string `json:"udpTimeout,omitempty" tf:"udp_timeout,omitempty"`
}

func (*IpvsParameters) DeepCopy

func (in *IpvsParameters) DeepCopy() *IpvsParameters

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IpvsParameters.

func (*IpvsParameters) DeepCopyInto

func (in *IpvsParameters) DeepCopyInto(out *IpvsParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type KubeconfigAttributesInitParameters

type KubeconfigAttributesInitParameters struct {
}

func (*KubeconfigAttributesInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KubeconfigAttributesInitParameters.

func (*KubeconfigAttributesInitParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type KubeconfigAttributesObservation

type KubeconfigAttributesObservation struct {
	ClientCertificate *string `json:"clientCertificate,omitempty" tf:"client_certificate,omitempty"`

	ClientKey *string `json:"clientKey,omitempty" tf:"client_key,omitempty"`

	ClusterCACertificate *string `json:"clusterCaCertificate,omitempty" tf:"cluster_ca_certificate,omitempty"`

	Host *string `json:"host,omitempty" tf:"host,omitempty"`
}

func (*KubeconfigAttributesObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KubeconfigAttributesObservation.

func (*KubeconfigAttributesObservation) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type KubeconfigAttributesParameters

type KubeconfigAttributesParameters struct {
}

func (*KubeconfigAttributesParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KubeconfigAttributesParameters.

func (*KubeconfigAttributesParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type PrivateNetworkConfigurationInitParameters

type PrivateNetworkConfigurationInitParameters struct {

	// If defined, all egress traffic will be routed towards this IP address, which should belong to the private network. Empty string means disabled.
	DefaultVrackGateway *string `json:"defaultVrackGateway,omitempty" tf:"default_vrack_gateway,omitempty"`

	// Defines whether routing should default to using the nodes' private interface, instead of their public interface. Default is false.
	PrivateNetworkRoutingAsDefault *bool `json:"privateNetworkRoutingAsDefault,omitempty" tf:"private_network_routing_as_default,omitempty"`
}

func (*PrivateNetworkConfigurationInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivateNetworkConfigurationInitParameters.

func (*PrivateNetworkConfigurationInitParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type PrivateNetworkConfigurationObservation

type PrivateNetworkConfigurationObservation struct {

	// If defined, all egress traffic will be routed towards this IP address, which should belong to the private network. Empty string means disabled.
	DefaultVrackGateway *string `json:"defaultVrackGateway,omitempty" tf:"default_vrack_gateway,omitempty"`

	// Defines whether routing should default to using the nodes' private interface, instead of their public interface. Default is false.
	PrivateNetworkRoutingAsDefault *bool `json:"privateNetworkRoutingAsDefault,omitempty" tf:"private_network_routing_as_default,omitempty"`
}

func (*PrivateNetworkConfigurationObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivateNetworkConfigurationObservation.

func (*PrivateNetworkConfigurationObservation) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type PrivateNetworkConfigurationParameters

type PrivateNetworkConfigurationParameters struct {

	// If defined, all egress traffic will be routed towards this IP address, which should belong to the private network. Empty string means disabled.
	// +kubebuilder:validation:Optional
	DefaultVrackGateway *string `json:"defaultVrackGateway" tf:"default_vrack_gateway,omitempty"`

	// Defines whether routing should default to using the nodes' private interface, instead of their public interface. Default is false.
	// +kubebuilder:validation:Optional
	PrivateNetworkRoutingAsDefault *bool `json:"privateNetworkRoutingAsDefault" tf:"private_network_routing_as_default,omitempty"`
}

func (*PrivateNetworkConfigurationParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivateNetworkConfigurationParameters.

func (*PrivateNetworkConfigurationParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ProjectKube

type ProjectKube struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.region) || (has(self.initProvider) && has(self.initProvider.region))",message="spec.forProvider.region is a required parameter"
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
	Spec   ProjectKubeSpec   `json:"spec"`
	Status ProjectKubeStatus `json:"status,omitempty"`
}

ProjectKube is the Schema for the ProjectKubes API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}

func (*ProjectKube) DeepCopy

func (in *ProjectKube) DeepCopy() *ProjectKube

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKube.

func (*ProjectKube) DeepCopyInto

func (in *ProjectKube) DeepCopyInto(out *ProjectKube)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ProjectKube) DeepCopyObject

func (in *ProjectKube) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*ProjectKube) GetCondition

func (mg *ProjectKube) GetCondition(ct xpv1.ConditionType) xpv1.Condition

GetCondition of this ProjectKube.

func (*ProjectKube) GetConnectionDetailsMapping

func (tr *ProjectKube) GetConnectionDetailsMapping() map[string]string

GetConnectionDetailsMapping for this ProjectKube

func (*ProjectKube) GetDeletionPolicy

func (mg *ProjectKube) GetDeletionPolicy() xpv1.DeletionPolicy

GetDeletionPolicy of this ProjectKube.

func (*ProjectKube) GetID

func (tr *ProjectKube) GetID() string

GetID returns ID of underlying Terraform resource of this ProjectKube

func (*ProjectKube) GetInitParameters

func (tr *ProjectKube) GetInitParameters() (map[string]any, error)

GetInitParameters of this ProjectKube

func (*ProjectKube) GetManagementPolicies

func (mg *ProjectKube) GetManagementPolicies() xpv1.ManagementPolicies

GetManagementPolicies of this ProjectKube.

func (*ProjectKube) GetObservation

func (tr *ProjectKube) GetObservation() (map[string]any, error)

GetObservation of this ProjectKube

func (*ProjectKube) GetParameters

func (tr *ProjectKube) GetParameters() (map[string]any, error)

GetParameters of this ProjectKube

func (*ProjectKube) GetProviderConfigReference

func (mg *ProjectKube) GetProviderConfigReference() *xpv1.Reference

GetProviderConfigReference of this ProjectKube.

func (*ProjectKube) GetPublishConnectionDetailsTo

func (mg *ProjectKube) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo

GetPublishConnectionDetailsTo of this ProjectKube.

func (*ProjectKube) GetTerraformResourceType

func (mg *ProjectKube) GetTerraformResourceType() string

GetTerraformResourceType returns Terraform resource type for this ProjectKube

func (*ProjectKube) GetTerraformSchemaVersion

func (tr *ProjectKube) GetTerraformSchemaVersion() int

GetTerraformSchemaVersion returns the associated Terraform schema version

func (*ProjectKube) GetWriteConnectionSecretToReference

func (mg *ProjectKube) GetWriteConnectionSecretToReference() *xpv1.SecretReference

GetWriteConnectionSecretToReference of this ProjectKube.

func (*ProjectKube) LateInitialize

func (tr *ProjectKube) LateInitialize(attrs []byte) (bool, error)

LateInitialize this ProjectKube using its observed tfState. returns True if there are any spec changes for the resource.

func (*ProjectKube) SetConditions

func (mg *ProjectKube) SetConditions(c ...xpv1.Condition)

SetConditions of this ProjectKube.

func (*ProjectKube) SetDeletionPolicy

func (mg *ProjectKube) SetDeletionPolicy(r xpv1.DeletionPolicy)

SetDeletionPolicy of this ProjectKube.

func (*ProjectKube) SetManagementPolicies

func (mg *ProjectKube) SetManagementPolicies(r xpv1.ManagementPolicies)

SetManagementPolicies of this ProjectKube.

func (*ProjectKube) SetObservation

func (tr *ProjectKube) SetObservation(obs map[string]any) error

SetObservation for this ProjectKube

func (*ProjectKube) SetParameters

func (tr *ProjectKube) SetParameters(params map[string]any) error

SetParameters for this ProjectKube

func (*ProjectKube) SetProviderConfigReference

func (mg *ProjectKube) SetProviderConfigReference(r *xpv1.Reference)

SetProviderConfigReference of this ProjectKube.

func (*ProjectKube) SetPublishConnectionDetailsTo

func (mg *ProjectKube) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)

SetPublishConnectionDetailsTo of this ProjectKube.

func (*ProjectKube) SetWriteConnectionSecretToReference

func (mg *ProjectKube) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)

SetWriteConnectionSecretToReference of this ProjectKube.

type ProjectKubeInitParameters

type ProjectKubeInitParameters struct {
	Customization []CustomizationInitParameters `json:"customization,omitempty" tf:"customization,omitempty"`

	CustomizationApiserver []CustomizationApiserverInitParameters `json:"customizationApiserver,omitempty" tf:"customization_apiserver,omitempty"`

	CustomizationKubeProxy []CustomizationKubeProxyInitParameters `json:"customizationKubeProxy,omitempty" tf:"customization_kube_proxy,omitempty"`

	KubeProxyMode *string `json:"kubeProxyMode,omitempty" tf:"kube_proxy_mode,omitempty"`

	Name *string `json:"name,omitempty" tf:"name,omitempty"`

	PrivateNetworkConfiguration []PrivateNetworkConfigurationInitParameters `json:"privateNetworkConfiguration,omitempty" tf:"private_network_configuration,omitempty"`

	PrivateNetworkID *string `json:"privateNetworkId,omitempty" tf:"private_network_id,omitempty"`

	Region *string `json:"region,omitempty" tf:"region,omitempty"`

	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	UpdatePolicy *string `json:"updatePolicy,omitempty" tf:"update_policy,omitempty"`

	Version *string `json:"version,omitempty" tf:"version,omitempty"`
}

func (*ProjectKubeInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeInitParameters.

func (*ProjectKubeInitParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ProjectKubeList

type ProjectKubeList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []ProjectKube `json:"items"`
}

ProjectKubeList contains a list of ProjectKubes

func (*ProjectKubeList) DeepCopy

func (in *ProjectKubeList) DeepCopy() *ProjectKubeList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeList.

func (*ProjectKubeList) DeepCopyInto

func (in *ProjectKubeList) DeepCopyInto(out *ProjectKubeList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ProjectKubeList) DeepCopyObject

func (in *ProjectKubeList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*ProjectKubeList) GetItems

func (l *ProjectKubeList) GetItems() []resource.Managed

GetItems of this ProjectKubeList.

type ProjectKubeObservation

type ProjectKubeObservation struct {
	ControlPlaneIsUpToDate *bool `json:"controlPlaneIsUpToDate,omitempty" tf:"control_plane_is_up_to_date,omitempty"`

	Customization []CustomizationObservation `json:"customization,omitempty" tf:"customization,omitempty"`

	CustomizationApiserver []CustomizationApiserverObservation `json:"customizationApiserver,omitempty" tf:"customization_apiserver,omitempty"`

	CustomizationKubeProxy []CustomizationKubeProxyObservation `json:"customizationKubeProxy,omitempty" tf:"customization_kube_proxy,omitempty"`

	ID *string `json:"id,omitempty" tf:"id,omitempty"`

	IsUpToDate *bool `json:"isUpToDate,omitempty" tf:"is_up_to_date,omitempty"`

	KubeProxyMode *string `json:"kubeProxyMode,omitempty" tf:"kube_proxy_mode,omitempty"`

	Name *string `json:"name,omitempty" tf:"name,omitempty"`

	NextUpgradeVersions []*string `json:"nextUpgradeVersions,omitempty" tf:"next_upgrade_versions,omitempty"`

	NodesURL *string `json:"nodesUrl,omitempty" tf:"nodes_url,omitempty"`

	PrivateNetworkConfiguration []PrivateNetworkConfigurationObservation `json:"privateNetworkConfiguration,omitempty" tf:"private_network_configuration,omitempty"`

	PrivateNetworkID *string `json:"privateNetworkId,omitempty" tf:"private_network_id,omitempty"`

	Region *string `json:"region,omitempty" tf:"region,omitempty"`

	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	Status *string `json:"status,omitempty" tf:"status,omitempty"`

	URL *string `json:"url,omitempty" tf:"url,omitempty"`

	UpdatePolicy *string `json:"updatePolicy,omitempty" tf:"update_policy,omitempty"`

	Version *string `json:"version,omitempty" tf:"version,omitempty"`
}

func (*ProjectKubeObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeObservation.

func (*ProjectKubeObservation) DeepCopyInto

func (in *ProjectKubeObservation) DeepCopyInto(out *ProjectKubeObservation)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ProjectKubeParameters

type ProjectKubeParameters struct {

	// +kubebuilder:validation:Optional
	Customization []CustomizationParameters `json:"customization,omitempty" tf:"customization,omitempty"`

	// +kubebuilder:validation:Optional
	CustomizationApiserver []CustomizationApiserverParameters `json:"customizationApiserver,omitempty" tf:"customization_apiserver,omitempty"`

	// +kubebuilder:validation:Optional
	CustomizationKubeProxy []CustomizationKubeProxyParameters `json:"customizationKubeProxy,omitempty" tf:"customization_kube_proxy,omitempty"`

	// +kubebuilder:validation:Optional
	KubeProxyMode *string `json:"kubeProxyMode,omitempty" tf:"kube_proxy_mode,omitempty"`

	// +kubebuilder:validation:Optional
	Name *string `json:"name,omitempty" tf:"name,omitempty"`

	// +kubebuilder:validation:Optional
	PrivateNetworkConfiguration []PrivateNetworkConfigurationParameters `json:"privateNetworkConfiguration,omitempty" tf:"private_network_configuration,omitempty"`

	// +kubebuilder:validation:Optional
	PrivateNetworkID *string `json:"privateNetworkId,omitempty" tf:"private_network_id,omitempty"`

	// +kubebuilder:validation:Optional
	Region *string `json:"region,omitempty" tf:"region,omitempty"`

	// +kubebuilder:validation:Optional
	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	// +kubebuilder:validation:Optional
	UpdatePolicy *string `json:"updatePolicy,omitempty" tf:"update_policy,omitempty"`

	// +kubebuilder:validation:Optional
	Version *string `json:"version,omitempty" tf:"version,omitempty"`
}

func (*ProjectKubeParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeParameters.

func (*ProjectKubeParameters) DeepCopyInto

func (in *ProjectKubeParameters) DeepCopyInto(out *ProjectKubeParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ProjectKubeSpec

type ProjectKubeSpec struct {
	v1.ResourceSpec `json:",inline"`
	ForProvider     ProjectKubeParameters `json:"forProvider"`
	// THIS IS A BETA FIELD. It will be honored
	// unless the Management Policies feature flag is disabled.
	// InitProvider holds the same fields as ForProvider, with the exception
	// of Identifier and other resource reference fields. The fields that are
	// in InitProvider are merged into ForProvider when the resource is created.
	// The same fields are also added to the terraform ignore_changes hook, to
	// avoid updating them after creation. This is useful for fields that are
	// required on creation, but we do not desire to update them after creation,
	// for example because of an external controller is managing them, like an
	// autoscaler.
	InitProvider ProjectKubeInitParameters `json:"initProvider,omitempty"`
}

ProjectKubeSpec defines the desired state of ProjectKube

func (*ProjectKubeSpec) DeepCopy

func (in *ProjectKubeSpec) DeepCopy() *ProjectKubeSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeSpec.

func (*ProjectKubeSpec) DeepCopyInto

func (in *ProjectKubeSpec) DeepCopyInto(out *ProjectKubeSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ProjectKubeStatus

type ProjectKubeStatus struct {
	v1.ResourceStatus `json:",inline"`
	AtProvider        ProjectKubeObservation `json:"atProvider,omitempty"`
}

ProjectKubeStatus defines the observed state of ProjectKube.

func (*ProjectKubeStatus) DeepCopy

func (in *ProjectKubeStatus) DeepCopy() *ProjectKubeStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeStatus.

func (*ProjectKubeStatus) DeepCopyInto

func (in *ProjectKubeStatus) DeepCopyInto(out *ProjectKubeStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to