Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=cloudprojectkubenodepool.crossplane.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type MetadataInitParameters
- type MetadataObservation
- type MetadataParameters
- type ProjectKubeNodepool
- func (in *ProjectKubeNodepool) DeepCopy() *ProjectKubeNodepool
- func (in *ProjectKubeNodepool) DeepCopyInto(out *ProjectKubeNodepool)
- func (in *ProjectKubeNodepool) DeepCopyObject() runtime.Object
- func (mg *ProjectKubeNodepool) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *ProjectKubeNodepool) GetConnectionDetailsMapping() map[string]string
- func (mg *ProjectKubeNodepool) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *ProjectKubeNodepool) GetID() string
- func (tr *ProjectKubeNodepool) GetInitParameters() (map[string]any, error)
- func (mg *ProjectKubeNodepool) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *ProjectKubeNodepool) GetObservation() (map[string]any, error)
- func (tr *ProjectKubeNodepool) GetParameters() (map[string]any, error)
- func (mg *ProjectKubeNodepool) GetProviderConfigReference() *xpv1.Reference
- func (mg *ProjectKubeNodepool) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *ProjectKubeNodepool) GetTerraformResourceType() string
- func (tr *ProjectKubeNodepool) GetTerraformSchemaVersion() int
- func (mg *ProjectKubeNodepool) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *ProjectKubeNodepool) LateInitialize(attrs []byte) (bool, error)
- func (mg *ProjectKubeNodepool) SetConditions(c ...xpv1.Condition)
- func (mg *ProjectKubeNodepool) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *ProjectKubeNodepool) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *ProjectKubeNodepool) SetObservation(obs map[string]any) error
- func (tr *ProjectKubeNodepool) SetParameters(params map[string]any) error
- func (mg *ProjectKubeNodepool) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *ProjectKubeNodepool) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *ProjectKubeNodepool) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type ProjectKubeNodepoolInitParameters
- type ProjectKubeNodepoolList
- type ProjectKubeNodepoolObservation
- type ProjectKubeNodepoolParameters
- type ProjectKubeNodepoolSpec
- type ProjectKubeNodepoolStatus
- type SpecInitParameters
- type SpecObservation
- type SpecParameters
- type TemplateInitParameters
- type TemplateObservation
- type TemplateParameters
Constants ¶
const ( CRDGroup = "cloudprojectkubenodepool.crossplane.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( ProjectKubeNodepool_Kind = "ProjectKubeNodepool" ProjectKubeNodepool_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: ProjectKubeNodepool_Kind}.String() ProjectKubeNodepool_KindAPIVersion = ProjectKubeNodepool_Kind + "." + CRDGroupVersion.String() ProjectKubeNodepool_GroupVersionKind = CRDGroupVersion.WithKind(ProjectKubeNodepool_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type MetadataInitParameters ¶
type MetadataInitParameters struct {
// annotations
Annotations map[string]*string `json:"annotations,omitempty" tf:"annotations,omitempty"`
// finalizers
Finalizers []*string `json:"finalizers,omitempty" tf:"finalizers,omitempty"`
// labels
Labels map[string]*string `json:"labels,omitempty" tf:"labels,omitempty"`
}
func (*MetadataInitParameters) DeepCopy ¶
func (in *MetadataInitParameters) DeepCopy() *MetadataInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MetadataInitParameters.
func (*MetadataInitParameters) DeepCopyInto ¶
func (in *MetadataInitParameters) DeepCopyInto(out *MetadataInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MetadataObservation ¶
type MetadataObservation struct {
// annotations
Annotations map[string]*string `json:"annotations,omitempty" tf:"annotations,omitempty"`
// finalizers
Finalizers []*string `json:"finalizers,omitempty" tf:"finalizers,omitempty"`
// labels
Labels map[string]*string `json:"labels,omitempty" tf:"labels,omitempty"`
}
func (*MetadataObservation) DeepCopy ¶
func (in *MetadataObservation) DeepCopy() *MetadataObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MetadataObservation.
func (*MetadataObservation) DeepCopyInto ¶
func (in *MetadataObservation) DeepCopyInto(out *MetadataObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MetadataParameters ¶
type MetadataParameters struct {
// annotations
// +kubebuilder:validation:Optional
Annotations map[string]*string `json:"annotations" tf:"annotations,omitempty"`
// finalizers
// +kubebuilder:validation:Optional
Finalizers []*string `json:"finalizers" tf:"finalizers,omitempty"`
// labels
// +kubebuilder:validation:Optional
Labels map[string]*string `json:"labels" tf:"labels,omitempty"`
}
func (*MetadataParameters) DeepCopy ¶
func (in *MetadataParameters) DeepCopy() *MetadataParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MetadataParameters.
func (*MetadataParameters) DeepCopyInto ¶
func (in *MetadataParameters) DeepCopyInto(out *MetadataParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectKubeNodepool ¶
type ProjectKubeNodepool struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.flavorName) || (has(self.initProvider) && has(self.initProvider.flavorName))",message="spec.forProvider.flavorName is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.kubeId) || (has(self.initProvider) && has(self.initProvider.kubeId))",message="spec.forProvider.kubeId is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
Spec ProjectKubeNodepoolSpec `json:"spec"`
Status ProjectKubeNodepoolStatus `json:"status,omitempty"`
}
ProjectKubeNodepool is the Schema for the ProjectKubeNodepools API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}
func (*ProjectKubeNodepool) DeepCopy ¶
func (in *ProjectKubeNodepool) DeepCopy() *ProjectKubeNodepool
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeNodepool.
func (*ProjectKubeNodepool) DeepCopyInto ¶
func (in *ProjectKubeNodepool) DeepCopyInto(out *ProjectKubeNodepool)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ProjectKubeNodepool) DeepCopyObject ¶
func (in *ProjectKubeNodepool) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ProjectKubeNodepool) GetCondition ¶
func (mg *ProjectKubeNodepool) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this ProjectKubeNodepool.
func (*ProjectKubeNodepool) GetConnectionDetailsMapping ¶
func (tr *ProjectKubeNodepool) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this ProjectKubeNodepool
func (*ProjectKubeNodepool) GetDeletionPolicy ¶
func (mg *ProjectKubeNodepool) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this ProjectKubeNodepool.
func (*ProjectKubeNodepool) GetID ¶
func (tr *ProjectKubeNodepool) GetID() string
GetID returns ID of underlying Terraform resource of this ProjectKubeNodepool
func (*ProjectKubeNodepool) GetInitParameters ¶
func (tr *ProjectKubeNodepool) GetInitParameters() (map[string]any, error)
GetInitParameters of this ProjectKubeNodepool
func (*ProjectKubeNodepool) GetManagementPolicies ¶
func (mg *ProjectKubeNodepool) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this ProjectKubeNodepool.
func (*ProjectKubeNodepool) GetObservation ¶
func (tr *ProjectKubeNodepool) GetObservation() (map[string]any, error)
GetObservation of this ProjectKubeNodepool
func (*ProjectKubeNodepool) GetParameters ¶
func (tr *ProjectKubeNodepool) GetParameters() (map[string]any, error)
GetParameters of this ProjectKubeNodepool
func (*ProjectKubeNodepool) GetProviderConfigReference ¶
func (mg *ProjectKubeNodepool) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this ProjectKubeNodepool.
func (*ProjectKubeNodepool) GetPublishConnectionDetailsTo ¶
func (mg *ProjectKubeNodepool) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this ProjectKubeNodepool.
func (*ProjectKubeNodepool) GetTerraformResourceType ¶
func (mg *ProjectKubeNodepool) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this ProjectKubeNodepool
func (*ProjectKubeNodepool) GetTerraformSchemaVersion ¶
func (tr *ProjectKubeNodepool) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*ProjectKubeNodepool) GetWriteConnectionSecretToReference ¶
func (mg *ProjectKubeNodepool) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this ProjectKubeNodepool.
func (*ProjectKubeNodepool) LateInitialize ¶
func (tr *ProjectKubeNodepool) LateInitialize(attrs []byte) (bool, error)
LateInitialize this ProjectKubeNodepool using its observed tfState. returns True if there are any spec changes for the resource.
func (*ProjectKubeNodepool) SetConditions ¶
func (mg *ProjectKubeNodepool) SetConditions(c ...xpv1.Condition)
SetConditions of this ProjectKubeNodepool.
func (*ProjectKubeNodepool) SetDeletionPolicy ¶
func (mg *ProjectKubeNodepool) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this ProjectKubeNodepool.
func (*ProjectKubeNodepool) SetManagementPolicies ¶
func (mg *ProjectKubeNodepool) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this ProjectKubeNodepool.
func (*ProjectKubeNodepool) SetObservation ¶
func (tr *ProjectKubeNodepool) SetObservation(obs map[string]any) error
SetObservation for this ProjectKubeNodepool
func (*ProjectKubeNodepool) SetParameters ¶
func (tr *ProjectKubeNodepool) SetParameters(params map[string]any) error
SetParameters for this ProjectKubeNodepool
func (*ProjectKubeNodepool) SetProviderConfigReference ¶
func (mg *ProjectKubeNodepool) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this ProjectKubeNodepool.
func (*ProjectKubeNodepool) SetPublishConnectionDetailsTo ¶
func (mg *ProjectKubeNodepool) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this ProjectKubeNodepool.
func (*ProjectKubeNodepool) SetWriteConnectionSecretToReference ¶
func (mg *ProjectKubeNodepool) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this ProjectKubeNodepool.
type ProjectKubeNodepoolInitParameters ¶
type ProjectKubeNodepoolInitParameters struct {
// Enable anti affinity groups for nodes in the pool
AntiAffinity *bool `json:"antiAffinity,omitempty" tf:"anti_affinity,omitempty"`
// Enable auto-scaling for the pool
Autoscale *bool `json:"autoscale,omitempty" tf:"autoscale,omitempty"`
// Number of nodes you desire in the pool
DesiredNodes *float64 `json:"desiredNodes,omitempty" tf:"desired_nodes,omitempty"`
// Flavor name
FlavorName *string `json:"flavorName,omitempty" tf:"flavor_name,omitempty"`
// Kube ID
KubeID *string `json:"kubeId,omitempty" tf:"kube_id,omitempty"`
// Number of nodes you desire in the pool
MaxNodes *float64 `json:"maxNodes,omitempty" tf:"max_nodes,omitempty"`
// Number of nodes you desire in the pool
MinNodes *float64 `json:"minNodes,omitempty" tf:"min_nodes,omitempty"`
// Enable monthly billing on all nodes in the pool
MonthlyBilled *bool `json:"monthlyBilled,omitempty" tf:"monthly_billed,omitempty"`
// NodePool resource name
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Service name
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Node pool template
Template []TemplateInitParameters `json:"template,omitempty" tf:"template,omitempty"`
}
func (*ProjectKubeNodepoolInitParameters) DeepCopy ¶
func (in *ProjectKubeNodepoolInitParameters) DeepCopy() *ProjectKubeNodepoolInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeNodepoolInitParameters.
func (*ProjectKubeNodepoolInitParameters) DeepCopyInto ¶
func (in *ProjectKubeNodepoolInitParameters) DeepCopyInto(out *ProjectKubeNodepoolInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectKubeNodepoolList ¶
type ProjectKubeNodepoolList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []ProjectKubeNodepool `json:"items"`
}
ProjectKubeNodepoolList contains a list of ProjectKubeNodepools
func (*ProjectKubeNodepoolList) DeepCopy ¶
func (in *ProjectKubeNodepoolList) DeepCopy() *ProjectKubeNodepoolList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeNodepoolList.
func (*ProjectKubeNodepoolList) DeepCopyInto ¶
func (in *ProjectKubeNodepoolList) DeepCopyInto(out *ProjectKubeNodepoolList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ProjectKubeNodepoolList) DeepCopyObject ¶
func (in *ProjectKubeNodepoolList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ProjectKubeNodepoolList) GetItems ¶
func (l *ProjectKubeNodepoolList) GetItems() []resource.Managed
GetItems of this ProjectKubeNodepoolList.
type ProjectKubeNodepoolObservation ¶
type ProjectKubeNodepoolObservation struct {
// Enable anti affinity groups for nodes in the pool
AntiAffinity *bool `json:"antiAffinity,omitempty" tf:"anti_affinity,omitempty"`
// Enable auto-scaling for the pool
Autoscale *bool `json:"autoscale,omitempty" tf:"autoscale,omitempty"`
// Number of nodes which are actually ready in the pool
AvailableNodes *float64 `json:"availableNodes,omitempty" tf:"available_nodes,omitempty"`
// Creation date
CreatedAt *string `json:"createdAt,omitempty" tf:"created_at,omitempty"`
// Number of nodes present in the pool
CurrentNodes *float64 `json:"currentNodes,omitempty" tf:"current_nodes,omitempty"`
// Number of nodes you desire in the pool
DesiredNodes *float64 `json:"desiredNodes,omitempty" tf:"desired_nodes,omitempty"`
// Flavor name
Flavor *string `json:"flavor,omitempty" tf:"flavor,omitempty"`
// Flavor name
FlavorName *string `json:"flavorName,omitempty" tf:"flavor_name,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// Kube ID
KubeID *string `json:"kubeId,omitempty" tf:"kube_id,omitempty"`
// Number of nodes you desire in the pool
MaxNodes *float64 `json:"maxNodes,omitempty" tf:"max_nodes,omitempty"`
// Number of nodes you desire in the pool
MinNodes *float64 `json:"minNodes,omitempty" tf:"min_nodes,omitempty"`
// Enable monthly billing on all nodes in the pool
MonthlyBilled *bool `json:"monthlyBilled,omitempty" tf:"monthly_billed,omitempty"`
// NodePool resource name
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Project id
ProjectID *string `json:"projectId,omitempty" tf:"project_id,omitempty"`
// Service name
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Status describing the state between number of nodes wanted and available ones
SizeStatus *string `json:"sizeStatus,omitempty" tf:"size_status,omitempty"`
// Current status
Status *string `json:"status,omitempty" tf:"status,omitempty"`
// Node pool template
Template []TemplateObservation `json:"template,omitempty" tf:"template,omitempty"`
// Number of nodes with latest version installed in the pool
UpToDateNodes *float64 `json:"upToDateNodes,omitempty" tf:"up_to_date_nodes,omitempty"`
// Last update date
UpdatedAt *string `json:"updatedAt,omitempty" tf:"updated_at,omitempty"`
}
func (*ProjectKubeNodepoolObservation) DeepCopy ¶
func (in *ProjectKubeNodepoolObservation) DeepCopy() *ProjectKubeNodepoolObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeNodepoolObservation.
func (*ProjectKubeNodepoolObservation) DeepCopyInto ¶
func (in *ProjectKubeNodepoolObservation) DeepCopyInto(out *ProjectKubeNodepoolObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectKubeNodepoolParameters ¶
type ProjectKubeNodepoolParameters struct {
// Enable anti affinity groups for nodes in the pool
// +kubebuilder:validation:Optional
AntiAffinity *bool `json:"antiAffinity,omitempty" tf:"anti_affinity,omitempty"`
// Enable auto-scaling for the pool
// +kubebuilder:validation:Optional
Autoscale *bool `json:"autoscale,omitempty" tf:"autoscale,omitempty"`
// Number of nodes you desire in the pool
// +kubebuilder:validation:Optional
DesiredNodes *float64 `json:"desiredNodes,omitempty" tf:"desired_nodes,omitempty"`
// Flavor name
// +kubebuilder:validation:Optional
FlavorName *string `json:"flavorName,omitempty" tf:"flavor_name,omitempty"`
// Kube ID
// +kubebuilder:validation:Optional
KubeID *string `json:"kubeId,omitempty" tf:"kube_id,omitempty"`
// Number of nodes you desire in the pool
// +kubebuilder:validation:Optional
MaxNodes *float64 `json:"maxNodes,omitempty" tf:"max_nodes,omitempty"`
// Number of nodes you desire in the pool
// +kubebuilder:validation:Optional
MinNodes *float64 `json:"minNodes,omitempty" tf:"min_nodes,omitempty"`
// Enable monthly billing on all nodes in the pool
// +kubebuilder:validation:Optional
MonthlyBilled *bool `json:"monthlyBilled,omitempty" tf:"monthly_billed,omitempty"`
// NodePool resource name
// +kubebuilder:validation:Optional
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Service name
// +kubebuilder:validation:Optional
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Node pool template
// +kubebuilder:validation:Optional
Template []TemplateParameters `json:"template,omitempty" tf:"template,omitempty"`
}
func (*ProjectKubeNodepoolParameters) DeepCopy ¶
func (in *ProjectKubeNodepoolParameters) DeepCopy() *ProjectKubeNodepoolParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeNodepoolParameters.
func (*ProjectKubeNodepoolParameters) DeepCopyInto ¶
func (in *ProjectKubeNodepoolParameters) DeepCopyInto(out *ProjectKubeNodepoolParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectKubeNodepoolSpec ¶
type ProjectKubeNodepoolSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider ProjectKubeNodepoolParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider ProjectKubeNodepoolInitParameters `json:"initProvider,omitempty"`
}
ProjectKubeNodepoolSpec defines the desired state of ProjectKubeNodepool
func (*ProjectKubeNodepoolSpec) DeepCopy ¶
func (in *ProjectKubeNodepoolSpec) DeepCopy() *ProjectKubeNodepoolSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeNodepoolSpec.
func (*ProjectKubeNodepoolSpec) DeepCopyInto ¶
func (in *ProjectKubeNodepoolSpec) DeepCopyInto(out *ProjectKubeNodepoolSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectKubeNodepoolStatus ¶
type ProjectKubeNodepoolStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider ProjectKubeNodepoolObservation `json:"atProvider,omitempty"`
}
ProjectKubeNodepoolStatus defines the observed state of ProjectKubeNodepool.
func (*ProjectKubeNodepoolStatus) DeepCopy ¶
func (in *ProjectKubeNodepoolStatus) DeepCopy() *ProjectKubeNodepoolStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeNodepoolStatus.
func (*ProjectKubeNodepoolStatus) DeepCopyInto ¶
func (in *ProjectKubeNodepoolStatus) DeepCopyInto(out *ProjectKubeNodepoolStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SpecInitParameters ¶
type SpecInitParameters struct {
// taints
Taints []map[string]*string `json:"taints,omitempty" tf:"taints,omitempty"`
// unschedulable
Unschedulable *bool `json:"unschedulable,omitempty" tf:"unschedulable,omitempty"`
}
func (*SpecInitParameters) DeepCopy ¶
func (in *SpecInitParameters) DeepCopy() *SpecInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SpecInitParameters.
func (*SpecInitParameters) DeepCopyInto ¶
func (in *SpecInitParameters) DeepCopyInto(out *SpecInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SpecObservation ¶
type SpecObservation struct {
// taints
Taints []map[string]*string `json:"taints,omitempty" tf:"taints,omitempty"`
// unschedulable
Unschedulable *bool `json:"unschedulable,omitempty" tf:"unschedulable,omitempty"`
}
func (*SpecObservation) DeepCopy ¶
func (in *SpecObservation) DeepCopy() *SpecObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SpecObservation.
func (*SpecObservation) DeepCopyInto ¶
func (in *SpecObservation) DeepCopyInto(out *SpecObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SpecParameters ¶
type SpecParameters struct {
// taints
// +kubebuilder:validation:Optional
Taints []map[string]*string `json:"taints" tf:"taints,omitempty"`
// unschedulable
// +kubebuilder:validation:Optional
Unschedulable *bool `json:"unschedulable" tf:"unschedulable,omitempty"`
}
func (*SpecParameters) DeepCopy ¶
func (in *SpecParameters) DeepCopy() *SpecParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SpecParameters.
func (*SpecParameters) DeepCopyInto ¶
func (in *SpecParameters) DeepCopyInto(out *SpecParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TemplateInitParameters ¶
type TemplateInitParameters struct {
// metadata
Metadata []MetadataInitParameters `json:"metadata,omitempty" tf:"metadata,omitempty"`
// spec
Spec []SpecInitParameters `json:"spec,omitempty" tf:"spec,omitempty"`
}
func (*TemplateInitParameters) DeepCopy ¶
func (in *TemplateInitParameters) DeepCopy() *TemplateInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TemplateInitParameters.
func (*TemplateInitParameters) DeepCopyInto ¶
func (in *TemplateInitParameters) DeepCopyInto(out *TemplateInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TemplateObservation ¶
type TemplateObservation struct {
// metadata
Metadata []MetadataObservation `json:"metadata,omitempty" tf:"metadata,omitempty"`
// spec
Spec []SpecObservation `json:"spec,omitempty" tf:"spec,omitempty"`
}
func (*TemplateObservation) DeepCopy ¶
func (in *TemplateObservation) DeepCopy() *TemplateObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TemplateObservation.
func (*TemplateObservation) DeepCopyInto ¶
func (in *TemplateObservation) DeepCopyInto(out *TemplateObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TemplateParameters ¶
type TemplateParameters struct {
// metadata
// +kubebuilder:validation:Optional
Metadata []MetadataParameters `json:"metadata" tf:"metadata,omitempty"`
// spec
// +kubebuilder:validation:Optional
Spec []SpecParameters `json:"spec" tf:"spec,omitempty"`
}
func (*TemplateParameters) DeepCopy ¶
func (in *TemplateParameters) DeepCopy() *TemplateParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TemplateParameters.
func (*TemplateParameters) DeepCopyInto ¶
func (in *TemplateParameters) DeepCopyInto(out *TemplateParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.