Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=cloudprojectkubeoidc.crossplane.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type ProjectKubeOidc
- func (in *ProjectKubeOidc) DeepCopy() *ProjectKubeOidc
- func (in *ProjectKubeOidc) DeepCopyInto(out *ProjectKubeOidc)
- func (in *ProjectKubeOidc) DeepCopyObject() runtime.Object
- func (mg *ProjectKubeOidc) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *ProjectKubeOidc) GetConnectionDetailsMapping() map[string]string
- func (mg *ProjectKubeOidc) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *ProjectKubeOidc) GetID() string
- func (tr *ProjectKubeOidc) GetInitParameters() (map[string]any, error)
- func (mg *ProjectKubeOidc) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *ProjectKubeOidc) GetObservation() (map[string]any, error)
- func (tr *ProjectKubeOidc) GetParameters() (map[string]any, error)
- func (mg *ProjectKubeOidc) GetProviderConfigReference() *xpv1.Reference
- func (mg *ProjectKubeOidc) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *ProjectKubeOidc) GetTerraformResourceType() string
- func (tr *ProjectKubeOidc) GetTerraformSchemaVersion() int
- func (mg *ProjectKubeOidc) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *ProjectKubeOidc) LateInitialize(attrs []byte) (bool, error)
- func (mg *ProjectKubeOidc) SetConditions(c ...xpv1.Condition)
- func (mg *ProjectKubeOidc) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *ProjectKubeOidc) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *ProjectKubeOidc) SetObservation(obs map[string]any) error
- func (tr *ProjectKubeOidc) SetParameters(params map[string]any) error
- func (mg *ProjectKubeOidc) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *ProjectKubeOidc) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *ProjectKubeOidc) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type ProjectKubeOidcInitParameters
- type ProjectKubeOidcList
- type ProjectKubeOidcObservation
- type ProjectKubeOidcParameters
- type ProjectKubeOidcSpec
- type ProjectKubeOidcStatus
Constants ¶
const ( CRDGroup = "cloudprojectkubeoidc.crossplane.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( ProjectKubeOidc_Kind = "ProjectKubeOidc" ProjectKubeOidc_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: ProjectKubeOidc_Kind}.String() ProjectKubeOidc_KindAPIVersion = ProjectKubeOidc_Kind + "." + CRDGroupVersion.String() ProjectKubeOidc_GroupVersionKind = CRDGroupVersion.WithKind(ProjectKubeOidc_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type ProjectKubeOidc ¶
type ProjectKubeOidc struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.clientId) || (has(self.initProvider) && has(self.initProvider.clientId))",message="spec.forProvider.clientId is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.issuerUrl) || (has(self.initProvider) && has(self.initProvider.issuerUrl))",message="spec.forProvider.issuerUrl is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.kubeId) || (has(self.initProvider) && has(self.initProvider.kubeId))",message="spec.forProvider.kubeId is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
Spec ProjectKubeOidcSpec `json:"spec"`
Status ProjectKubeOidcStatus `json:"status,omitempty"`
}
ProjectKubeOidc is the Schema for the ProjectKubeOidcs API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}
func (*ProjectKubeOidc) DeepCopy ¶
func (in *ProjectKubeOidc) DeepCopy() *ProjectKubeOidc
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeOidc.
func (*ProjectKubeOidc) DeepCopyInto ¶
func (in *ProjectKubeOidc) DeepCopyInto(out *ProjectKubeOidc)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ProjectKubeOidc) DeepCopyObject ¶
func (in *ProjectKubeOidc) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ProjectKubeOidc) GetCondition ¶
func (mg *ProjectKubeOidc) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this ProjectKubeOidc.
func (*ProjectKubeOidc) GetConnectionDetailsMapping ¶
func (tr *ProjectKubeOidc) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this ProjectKubeOidc
func (*ProjectKubeOidc) GetDeletionPolicy ¶
func (mg *ProjectKubeOidc) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this ProjectKubeOidc.
func (*ProjectKubeOidc) GetID ¶
func (tr *ProjectKubeOidc) GetID() string
GetID returns ID of underlying Terraform resource of this ProjectKubeOidc
func (*ProjectKubeOidc) GetInitParameters ¶
func (tr *ProjectKubeOidc) GetInitParameters() (map[string]any, error)
GetInitParameters of this ProjectKubeOidc
func (*ProjectKubeOidc) GetManagementPolicies ¶
func (mg *ProjectKubeOidc) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this ProjectKubeOidc.
func (*ProjectKubeOidc) GetObservation ¶
func (tr *ProjectKubeOidc) GetObservation() (map[string]any, error)
GetObservation of this ProjectKubeOidc
func (*ProjectKubeOidc) GetParameters ¶
func (tr *ProjectKubeOidc) GetParameters() (map[string]any, error)
GetParameters of this ProjectKubeOidc
func (*ProjectKubeOidc) GetProviderConfigReference ¶
func (mg *ProjectKubeOidc) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this ProjectKubeOidc.
func (*ProjectKubeOidc) GetPublishConnectionDetailsTo ¶
func (mg *ProjectKubeOidc) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this ProjectKubeOidc.
func (*ProjectKubeOidc) GetTerraformResourceType ¶
func (mg *ProjectKubeOidc) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this ProjectKubeOidc
func (*ProjectKubeOidc) GetTerraformSchemaVersion ¶
func (tr *ProjectKubeOidc) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*ProjectKubeOidc) GetWriteConnectionSecretToReference ¶
func (mg *ProjectKubeOidc) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this ProjectKubeOidc.
func (*ProjectKubeOidc) LateInitialize ¶
func (tr *ProjectKubeOidc) LateInitialize(attrs []byte) (bool, error)
LateInitialize this ProjectKubeOidc using its observed tfState. returns True if there are any spec changes for the resource.
func (*ProjectKubeOidc) SetConditions ¶
func (mg *ProjectKubeOidc) SetConditions(c ...xpv1.Condition)
SetConditions of this ProjectKubeOidc.
func (*ProjectKubeOidc) SetDeletionPolicy ¶
func (mg *ProjectKubeOidc) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this ProjectKubeOidc.
func (*ProjectKubeOidc) SetManagementPolicies ¶
func (mg *ProjectKubeOidc) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this ProjectKubeOidc.
func (*ProjectKubeOidc) SetObservation ¶
func (tr *ProjectKubeOidc) SetObservation(obs map[string]any) error
SetObservation for this ProjectKubeOidc
func (*ProjectKubeOidc) SetParameters ¶
func (tr *ProjectKubeOidc) SetParameters(params map[string]any) error
SetParameters for this ProjectKubeOidc
func (*ProjectKubeOidc) SetProviderConfigReference ¶
func (mg *ProjectKubeOidc) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this ProjectKubeOidc.
func (*ProjectKubeOidc) SetPublishConnectionDetailsTo ¶
func (mg *ProjectKubeOidc) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this ProjectKubeOidc.
func (*ProjectKubeOidc) SetWriteConnectionSecretToReference ¶
func (mg *ProjectKubeOidc) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this ProjectKubeOidc.
type ProjectKubeOidcInitParameters ¶
type ProjectKubeOidcInitParameters struct {
ClientID *string `json:"clientId,omitempty" tf:"client_id,omitempty"`
IssuerURL *string `json:"issuerUrl,omitempty" tf:"issuer_url,omitempty"`
KubeID *string `json:"kubeId,omitempty" tf:"kube_id,omitempty"`
OidcCAContent *string `json:"oidcCaContent,omitempty" tf:"oidc_ca_content,omitempty"`
OidcGroupsClaim []*string `json:"oidcGroupsClaim,omitempty" tf:"oidc_groups_claim,omitempty"`
OidcGroupsPrefix *string `json:"oidcGroupsPrefix,omitempty" tf:"oidc_groups_prefix,omitempty"`
OidcRequiredClaim []*string `json:"oidcRequiredClaim,omitempty" tf:"oidc_required_claim,omitempty"`
OidcSigningAlgs []*string `json:"oidcSigningAlgs,omitempty" tf:"oidc_signing_algs,omitempty"`
OidcUsernameClaim *string `json:"oidcUsernameClaim,omitempty" tf:"oidc_username_claim,omitempty"`
OidcUsernamePrefix *string `json:"oidcUsernamePrefix,omitempty" tf:"oidc_username_prefix,omitempty"`
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
}
func (*ProjectKubeOidcInitParameters) DeepCopy ¶
func (in *ProjectKubeOidcInitParameters) DeepCopy() *ProjectKubeOidcInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeOidcInitParameters.
func (*ProjectKubeOidcInitParameters) DeepCopyInto ¶
func (in *ProjectKubeOidcInitParameters) DeepCopyInto(out *ProjectKubeOidcInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectKubeOidcList ¶
type ProjectKubeOidcList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []ProjectKubeOidc `json:"items"`
}
ProjectKubeOidcList contains a list of ProjectKubeOidcs
func (*ProjectKubeOidcList) DeepCopy ¶
func (in *ProjectKubeOidcList) DeepCopy() *ProjectKubeOidcList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeOidcList.
func (*ProjectKubeOidcList) DeepCopyInto ¶
func (in *ProjectKubeOidcList) DeepCopyInto(out *ProjectKubeOidcList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ProjectKubeOidcList) DeepCopyObject ¶
func (in *ProjectKubeOidcList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ProjectKubeOidcList) GetItems ¶
func (l *ProjectKubeOidcList) GetItems() []resource.Managed
GetItems of this ProjectKubeOidcList.
type ProjectKubeOidcObservation ¶
type ProjectKubeOidcObservation struct {
ClientID *string `json:"clientId,omitempty" tf:"client_id,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
IssuerURL *string `json:"issuerUrl,omitempty" tf:"issuer_url,omitempty"`
KubeID *string `json:"kubeId,omitempty" tf:"kube_id,omitempty"`
OidcCAContent *string `json:"oidcCaContent,omitempty" tf:"oidc_ca_content,omitempty"`
OidcGroupsClaim []*string `json:"oidcGroupsClaim,omitempty" tf:"oidc_groups_claim,omitempty"`
OidcGroupsPrefix *string `json:"oidcGroupsPrefix,omitempty" tf:"oidc_groups_prefix,omitempty"`
OidcRequiredClaim []*string `json:"oidcRequiredClaim,omitempty" tf:"oidc_required_claim,omitempty"`
OidcSigningAlgs []*string `json:"oidcSigningAlgs,omitempty" tf:"oidc_signing_algs,omitempty"`
OidcUsernameClaim *string `json:"oidcUsernameClaim,omitempty" tf:"oidc_username_claim,omitempty"`
OidcUsernamePrefix *string `json:"oidcUsernamePrefix,omitempty" tf:"oidc_username_prefix,omitempty"`
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
}
func (*ProjectKubeOidcObservation) DeepCopy ¶
func (in *ProjectKubeOidcObservation) DeepCopy() *ProjectKubeOidcObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeOidcObservation.
func (*ProjectKubeOidcObservation) DeepCopyInto ¶
func (in *ProjectKubeOidcObservation) DeepCopyInto(out *ProjectKubeOidcObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectKubeOidcParameters ¶
type ProjectKubeOidcParameters struct {
// +kubebuilder:validation:Optional
ClientID *string `json:"clientId,omitempty" tf:"client_id,omitempty"`
// +kubebuilder:validation:Optional
IssuerURL *string `json:"issuerUrl,omitempty" tf:"issuer_url,omitempty"`
// +kubebuilder:validation:Optional
KubeID *string `json:"kubeId,omitempty" tf:"kube_id,omitempty"`
// +kubebuilder:validation:Optional
OidcCAContent *string `json:"oidcCaContent,omitempty" tf:"oidc_ca_content,omitempty"`
// +kubebuilder:validation:Optional
OidcGroupsClaim []*string `json:"oidcGroupsClaim,omitempty" tf:"oidc_groups_claim,omitempty"`
// +kubebuilder:validation:Optional
OidcGroupsPrefix *string `json:"oidcGroupsPrefix,omitempty" tf:"oidc_groups_prefix,omitempty"`
// +kubebuilder:validation:Optional
OidcRequiredClaim []*string `json:"oidcRequiredClaim,omitempty" tf:"oidc_required_claim,omitempty"`
// +kubebuilder:validation:Optional
OidcSigningAlgs []*string `json:"oidcSigningAlgs,omitempty" tf:"oidc_signing_algs,omitempty"`
// +kubebuilder:validation:Optional
OidcUsernameClaim *string `json:"oidcUsernameClaim,omitempty" tf:"oidc_username_claim,omitempty"`
// +kubebuilder:validation:Optional
OidcUsernamePrefix *string `json:"oidcUsernamePrefix,omitempty" tf:"oidc_username_prefix,omitempty"`
// +kubebuilder:validation:Optional
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
}
func (*ProjectKubeOidcParameters) DeepCopy ¶
func (in *ProjectKubeOidcParameters) DeepCopy() *ProjectKubeOidcParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeOidcParameters.
func (*ProjectKubeOidcParameters) DeepCopyInto ¶
func (in *ProjectKubeOidcParameters) DeepCopyInto(out *ProjectKubeOidcParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectKubeOidcSpec ¶
type ProjectKubeOidcSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider ProjectKubeOidcParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider ProjectKubeOidcInitParameters `json:"initProvider,omitempty"`
}
ProjectKubeOidcSpec defines the desired state of ProjectKubeOidc
func (*ProjectKubeOidcSpec) DeepCopy ¶
func (in *ProjectKubeOidcSpec) DeepCopy() *ProjectKubeOidcSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeOidcSpec.
func (*ProjectKubeOidcSpec) DeepCopyInto ¶
func (in *ProjectKubeOidcSpec) DeepCopyInto(out *ProjectKubeOidcSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectKubeOidcStatus ¶
type ProjectKubeOidcStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider ProjectKubeOidcObservation `json:"atProvider,omitempty"`
}
ProjectKubeOidcStatus defines the observed state of ProjectKubeOidc.
func (*ProjectKubeOidcStatus) DeepCopy ¶
func (in *ProjectKubeOidcStatus) DeepCopy() *ProjectKubeOidcStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectKubeOidcStatus.
func (*ProjectKubeOidcStatus) DeepCopyInto ¶
func (in *ProjectKubeOidcStatus) DeepCopyInto(out *ProjectKubeOidcStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.