Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=cloudprojectuser.crossplane.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type ProjectUser
- func (in *ProjectUser) DeepCopy() *ProjectUser
- func (in *ProjectUser) DeepCopyInto(out *ProjectUser)
- func (in *ProjectUser) DeepCopyObject() runtime.Object
- func (mg *ProjectUser) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *ProjectUser) GetConnectionDetailsMapping() map[string]string
- func (mg *ProjectUser) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *ProjectUser) GetID() string
- func (tr *ProjectUser) GetInitParameters() (map[string]any, error)
- func (mg *ProjectUser) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *ProjectUser) GetObservation() (map[string]any, error)
- func (tr *ProjectUser) GetParameters() (map[string]any, error)
- func (mg *ProjectUser) GetProviderConfigReference() *xpv1.Reference
- func (mg *ProjectUser) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *ProjectUser) GetTerraformResourceType() string
- func (tr *ProjectUser) GetTerraformSchemaVersion() int
- func (mg *ProjectUser) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *ProjectUser) LateInitialize(attrs []byte) (bool, error)
- func (mg *ProjectUser) SetConditions(c ...xpv1.Condition)
- func (mg *ProjectUser) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *ProjectUser) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *ProjectUser) SetObservation(obs map[string]any) error
- func (tr *ProjectUser) SetParameters(params map[string]any) error
- func (mg *ProjectUser) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *ProjectUser) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *ProjectUser) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type ProjectUserInitParameters
- type ProjectUserList
- type ProjectUserObservation
- type ProjectUserParameters
- type ProjectUserSpec
- type ProjectUserStatus
- type RolesInitParameters
- type RolesObservation
- type RolesParameters
Constants ¶
const ( CRDGroup = "cloudprojectuser.crossplane.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( ProjectUser_Kind = "ProjectUser" ProjectUser_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: ProjectUser_Kind}.String() ProjectUser_KindAPIVersion = ProjectUser_Kind + "." + CRDGroupVersion.String() ProjectUser_GroupVersionKind = CRDGroupVersion.WithKind(ProjectUser_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type ProjectUser ¶
type ProjectUser struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
Spec ProjectUserSpec `json:"spec"`
Status ProjectUserStatus `json:"status,omitempty"`
}
ProjectUser is the Schema for the ProjectUsers API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}
func (*ProjectUser) DeepCopy ¶
func (in *ProjectUser) DeepCopy() *ProjectUser
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectUser.
func (*ProjectUser) DeepCopyInto ¶
func (in *ProjectUser) DeepCopyInto(out *ProjectUser)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ProjectUser) DeepCopyObject ¶
func (in *ProjectUser) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ProjectUser) GetCondition ¶
func (mg *ProjectUser) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this ProjectUser.
func (*ProjectUser) GetConnectionDetailsMapping ¶
func (tr *ProjectUser) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this ProjectUser
func (*ProjectUser) GetDeletionPolicy ¶
func (mg *ProjectUser) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this ProjectUser.
func (*ProjectUser) GetID ¶
func (tr *ProjectUser) GetID() string
GetID returns ID of underlying Terraform resource of this ProjectUser
func (*ProjectUser) GetInitParameters ¶
func (tr *ProjectUser) GetInitParameters() (map[string]any, error)
GetInitParameters of this ProjectUser
func (*ProjectUser) GetManagementPolicies ¶
func (mg *ProjectUser) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this ProjectUser.
func (*ProjectUser) GetObservation ¶
func (tr *ProjectUser) GetObservation() (map[string]any, error)
GetObservation of this ProjectUser
func (*ProjectUser) GetParameters ¶
func (tr *ProjectUser) GetParameters() (map[string]any, error)
GetParameters of this ProjectUser
func (*ProjectUser) GetProviderConfigReference ¶
func (mg *ProjectUser) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this ProjectUser.
func (*ProjectUser) GetPublishConnectionDetailsTo ¶
func (mg *ProjectUser) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this ProjectUser.
func (*ProjectUser) GetTerraformResourceType ¶
func (mg *ProjectUser) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this ProjectUser
func (*ProjectUser) GetTerraformSchemaVersion ¶
func (tr *ProjectUser) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*ProjectUser) GetWriteConnectionSecretToReference ¶
func (mg *ProjectUser) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this ProjectUser.
func (*ProjectUser) LateInitialize ¶
func (tr *ProjectUser) LateInitialize(attrs []byte) (bool, error)
LateInitialize this ProjectUser using its observed tfState. returns True if there are any spec changes for the resource.
func (*ProjectUser) SetConditions ¶
func (mg *ProjectUser) SetConditions(c ...xpv1.Condition)
SetConditions of this ProjectUser.
func (*ProjectUser) SetDeletionPolicy ¶
func (mg *ProjectUser) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this ProjectUser.
func (*ProjectUser) SetManagementPolicies ¶
func (mg *ProjectUser) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this ProjectUser.
func (*ProjectUser) SetObservation ¶
func (tr *ProjectUser) SetObservation(obs map[string]any) error
SetObservation for this ProjectUser
func (*ProjectUser) SetParameters ¶
func (tr *ProjectUser) SetParameters(params map[string]any) error
SetParameters for this ProjectUser
func (*ProjectUser) SetProviderConfigReference ¶
func (mg *ProjectUser) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this ProjectUser.
func (*ProjectUser) SetPublishConnectionDetailsTo ¶
func (mg *ProjectUser) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this ProjectUser.
func (*ProjectUser) SetWriteConnectionSecretToReference ¶
func (mg *ProjectUser) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this ProjectUser.
type ProjectUserInitParameters ¶
type ProjectUserInitParameters struct {
Description *string `json:"description,omitempty" tf:"description,omitempty"`
OpenstackRc map[string]*string `json:"openstackRc,omitempty" tf:"openstack_rc,omitempty"`
RoleName *string `json:"roleName,omitempty" tf:"role_name,omitempty"`
RoleNames []*string `json:"roleNames,omitempty" tf:"role_names,omitempty"`
// Service name of the resource representing the id of the cloud project.
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
}
func (*ProjectUserInitParameters) DeepCopy ¶
func (in *ProjectUserInitParameters) DeepCopy() *ProjectUserInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectUserInitParameters.
func (*ProjectUserInitParameters) DeepCopyInto ¶
func (in *ProjectUserInitParameters) DeepCopyInto(out *ProjectUserInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectUserList ¶
type ProjectUserList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []ProjectUser `json:"items"`
}
ProjectUserList contains a list of ProjectUsers
func (*ProjectUserList) DeepCopy ¶
func (in *ProjectUserList) DeepCopy() *ProjectUserList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectUserList.
func (*ProjectUserList) DeepCopyInto ¶
func (in *ProjectUserList) DeepCopyInto(out *ProjectUserList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ProjectUserList) DeepCopyObject ¶
func (in *ProjectUserList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ProjectUserList) GetItems ¶
func (l *ProjectUserList) GetItems() []resource.Managed
GetItems of this ProjectUserList.
type ProjectUserObservation ¶
type ProjectUserObservation struct {
CreationDate *string `json:"creationDate,omitempty" tf:"creation_date,omitempty"`
Description *string `json:"description,omitempty" tf:"description,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
OpenstackRc map[string]*string `json:"openstackRc,omitempty" tf:"openstack_rc,omitempty"`
RoleName *string `json:"roleName,omitempty" tf:"role_name,omitempty"`
RoleNames []*string `json:"roleNames,omitempty" tf:"role_names,omitempty"`
Roles []RolesObservation `json:"roles,omitempty" tf:"roles,omitempty"`
// Service name of the resource representing the id of the cloud project.
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
Status *string `json:"status,omitempty" tf:"status,omitempty"`
Username *string `json:"username,omitempty" tf:"username,omitempty"`
}
func (*ProjectUserObservation) DeepCopy ¶
func (in *ProjectUserObservation) DeepCopy() *ProjectUserObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectUserObservation.
func (*ProjectUserObservation) DeepCopyInto ¶
func (in *ProjectUserObservation) DeepCopyInto(out *ProjectUserObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectUserParameters ¶
type ProjectUserParameters struct {
// +kubebuilder:validation:Optional
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// +kubebuilder:validation:Optional
OpenstackRc map[string]*string `json:"openstackRc,omitempty" tf:"openstack_rc,omitempty"`
// +kubebuilder:validation:Optional
RoleName *string `json:"roleName,omitempty" tf:"role_name,omitempty"`
// +kubebuilder:validation:Optional
RoleNames []*string `json:"roleNames,omitempty" tf:"role_names,omitempty"`
// Service name of the resource representing the id of the cloud project.
// +kubebuilder:validation:Optional
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
}
func (*ProjectUserParameters) DeepCopy ¶
func (in *ProjectUserParameters) DeepCopy() *ProjectUserParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectUserParameters.
func (*ProjectUserParameters) DeepCopyInto ¶
func (in *ProjectUserParameters) DeepCopyInto(out *ProjectUserParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectUserSpec ¶
type ProjectUserSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider ProjectUserParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider ProjectUserInitParameters `json:"initProvider,omitempty"`
}
ProjectUserSpec defines the desired state of ProjectUser
func (*ProjectUserSpec) DeepCopy ¶
func (in *ProjectUserSpec) DeepCopy() *ProjectUserSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectUserSpec.
func (*ProjectUserSpec) DeepCopyInto ¶
func (in *ProjectUserSpec) DeepCopyInto(out *ProjectUserSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProjectUserStatus ¶
type ProjectUserStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider ProjectUserObservation `json:"atProvider,omitempty"`
}
ProjectUserStatus defines the observed state of ProjectUser.
func (*ProjectUserStatus) DeepCopy ¶
func (in *ProjectUserStatus) DeepCopy() *ProjectUserStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectUserStatus.
func (*ProjectUserStatus) DeepCopyInto ¶
func (in *ProjectUserStatus) DeepCopyInto(out *ProjectUserStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RolesInitParameters ¶
type RolesInitParameters struct {
}
func (*RolesInitParameters) DeepCopy ¶
func (in *RolesInitParameters) DeepCopy() *RolesInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RolesInitParameters.
func (*RolesInitParameters) DeepCopyInto ¶
func (in *RolesInitParameters) DeepCopyInto(out *RolesInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RolesObservation ¶
type RolesObservation struct {
Description *string `json:"description,omitempty" tf:"description,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
Name *string `json:"name,omitempty" tf:"name,omitempty"`
Permissions []*string `json:"permissions,omitempty" tf:"permissions,omitempty"`
}
func (*RolesObservation) DeepCopy ¶
func (in *RolesObservation) DeepCopy() *RolesObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RolesObservation.
func (*RolesObservation) DeepCopyInto ¶
func (in *RolesObservation) DeepCopyInto(out *RolesObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RolesParameters ¶
type RolesParameters struct {
}
func (*RolesParameters) DeepCopy ¶
func (in *RolesParameters) DeepCopy() *RolesParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RolesParameters.
func (*RolesParameters) DeepCopyInto ¶
func (in *RolesParameters) DeepCopyInto(out *RolesParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.