v1alpha1

package
v0.0.0-...-73c97c3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 17, 2024 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

+kubebuilder:object:generate=true +groupName=cloudprojectusers3credential.crossplane.io +versionName=v1alpha1

Index

Constants

const (
	CRDGroup   = "cloudprojectusers3credential.crossplane.io"
	CRDVersion = "v1alpha1"
)

Package type metadata.

Variables

var (
	// CRDGroupVersion is the API Group Version used to register the objects
	CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)
var (
	ProjectUserS3Credential_Kind             = "ProjectUserS3Credential"
	ProjectUserS3Credential_GroupKind        = schema.GroupKind{Group: CRDGroup, Kind: ProjectUserS3Credential_Kind}.String()
	ProjectUserS3Credential_KindAPIVersion   = ProjectUserS3Credential_Kind + "." + CRDGroupVersion.String()
	ProjectUserS3Credential_GroupVersionKind = CRDGroupVersion.WithKind(ProjectUserS3Credential_Kind)
)

Repository type metadata.

Functions

This section is empty.

Types

type ProjectUserS3Credential

type ProjectUserS3Credential struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.userId) || (has(self.initProvider) && has(self.initProvider.userId))",message="spec.forProvider.userId is a required parameter"
	Spec   ProjectUserS3CredentialSpec   `json:"spec"`
	Status ProjectUserS3CredentialStatus `json:"status,omitempty"`
}

ProjectUserS3Credential is the Schema for the ProjectUserS3Credentials API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}

func (*ProjectUserS3Credential) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectUserS3Credential.

func (*ProjectUserS3Credential) DeepCopyInto

func (in *ProjectUserS3Credential) DeepCopyInto(out *ProjectUserS3Credential)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ProjectUserS3Credential) DeepCopyObject

func (in *ProjectUserS3Credential) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*ProjectUserS3Credential) GetCondition

GetCondition of this ProjectUserS3Credential.

func (*ProjectUserS3Credential) GetConnectionDetailsMapping

func (tr *ProjectUserS3Credential) GetConnectionDetailsMapping() map[string]string

GetConnectionDetailsMapping for this ProjectUserS3Credential

func (*ProjectUserS3Credential) GetDeletionPolicy

func (mg *ProjectUserS3Credential) GetDeletionPolicy() xpv1.DeletionPolicy

GetDeletionPolicy of this ProjectUserS3Credential.

func (*ProjectUserS3Credential) GetID

func (tr *ProjectUserS3Credential) GetID() string

GetID returns ID of underlying Terraform resource of this ProjectUserS3Credential

func (*ProjectUserS3Credential) GetInitParameters

func (tr *ProjectUserS3Credential) GetInitParameters() (map[string]any, error)

GetInitParameters of this ProjectUserS3Credential

func (*ProjectUserS3Credential) GetManagementPolicies

func (mg *ProjectUserS3Credential) GetManagementPolicies() xpv1.ManagementPolicies

GetManagementPolicies of this ProjectUserS3Credential.

func (*ProjectUserS3Credential) GetObservation

func (tr *ProjectUserS3Credential) GetObservation() (map[string]any, error)

GetObservation of this ProjectUserS3Credential

func (*ProjectUserS3Credential) GetParameters

func (tr *ProjectUserS3Credential) GetParameters() (map[string]any, error)

GetParameters of this ProjectUserS3Credential

func (*ProjectUserS3Credential) GetProviderConfigReference

func (mg *ProjectUserS3Credential) GetProviderConfigReference() *xpv1.Reference

GetProviderConfigReference of this ProjectUserS3Credential.

func (*ProjectUserS3Credential) GetPublishConnectionDetailsTo

func (mg *ProjectUserS3Credential) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo

GetPublishConnectionDetailsTo of this ProjectUserS3Credential.

func (*ProjectUserS3Credential) GetTerraformResourceType

func (mg *ProjectUserS3Credential) GetTerraformResourceType() string

GetTerraformResourceType returns Terraform resource type for this ProjectUserS3Credential

func (*ProjectUserS3Credential) GetTerraformSchemaVersion

func (tr *ProjectUserS3Credential) GetTerraformSchemaVersion() int

GetTerraformSchemaVersion returns the associated Terraform schema version

func (*ProjectUserS3Credential) GetWriteConnectionSecretToReference

func (mg *ProjectUserS3Credential) GetWriteConnectionSecretToReference() *xpv1.SecretReference

GetWriteConnectionSecretToReference of this ProjectUserS3Credential.

func (*ProjectUserS3Credential) LateInitialize

func (tr *ProjectUserS3Credential) LateInitialize(attrs []byte) (bool, error)

LateInitialize this ProjectUserS3Credential using its observed tfState. returns True if there are any spec changes for the resource.

func (*ProjectUserS3Credential) SetConditions

func (mg *ProjectUserS3Credential) SetConditions(c ...xpv1.Condition)

SetConditions of this ProjectUserS3Credential.

func (*ProjectUserS3Credential) SetDeletionPolicy

func (mg *ProjectUserS3Credential) SetDeletionPolicy(r xpv1.DeletionPolicy)

SetDeletionPolicy of this ProjectUserS3Credential.

func (*ProjectUserS3Credential) SetManagementPolicies

func (mg *ProjectUserS3Credential) SetManagementPolicies(r xpv1.ManagementPolicies)

SetManagementPolicies of this ProjectUserS3Credential.

func (*ProjectUserS3Credential) SetObservation

func (tr *ProjectUserS3Credential) SetObservation(obs map[string]any) error

SetObservation for this ProjectUserS3Credential

func (*ProjectUserS3Credential) SetParameters

func (tr *ProjectUserS3Credential) SetParameters(params map[string]any) error

SetParameters for this ProjectUserS3Credential

func (*ProjectUserS3Credential) SetProviderConfigReference

func (mg *ProjectUserS3Credential) SetProviderConfigReference(r *xpv1.Reference)

SetProviderConfigReference of this ProjectUserS3Credential.

func (*ProjectUserS3Credential) SetPublishConnectionDetailsTo

func (mg *ProjectUserS3Credential) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)

SetPublishConnectionDetailsTo of this ProjectUserS3Credential.

func (*ProjectUserS3Credential) SetWriteConnectionSecretToReference

func (mg *ProjectUserS3Credential) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)

SetWriteConnectionSecretToReference of this ProjectUserS3Credential.

type ProjectUserS3CredentialInitParameters

type ProjectUserS3CredentialInitParameters struct {

	// Service name of the resource representing the ID of the cloud project.
	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	// The user ID
	UserID *string `json:"userId,omitempty" tf:"user_id,omitempty"`
}

func (*ProjectUserS3CredentialInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectUserS3CredentialInitParameters.

func (*ProjectUserS3CredentialInitParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ProjectUserS3CredentialList

type ProjectUserS3CredentialList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []ProjectUserS3Credential `json:"items"`
}

ProjectUserS3CredentialList contains a list of ProjectUserS3Credentials

func (*ProjectUserS3CredentialList) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectUserS3CredentialList.

func (*ProjectUserS3CredentialList) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ProjectUserS3CredentialList) DeepCopyObject

func (in *ProjectUserS3CredentialList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*ProjectUserS3CredentialList) GetItems

GetItems of this ProjectUserS3CredentialList.

type ProjectUserS3CredentialObservation

type ProjectUserS3CredentialObservation struct {
	AccessKeyID *string `json:"accessKeyId,omitempty" tf:"access_key_id,omitempty"`

	ID *string `json:"id,omitempty" tf:"id,omitempty"`

	InternalUserID *string `json:"internalUserId,omitempty" tf:"internal_user_id,omitempty"`

	// Service name of the resource representing the ID of the cloud project.
	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	// The user ID
	UserID *string `json:"userId,omitempty" tf:"user_id,omitempty"`
}

func (*ProjectUserS3CredentialObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectUserS3CredentialObservation.

func (*ProjectUserS3CredentialObservation) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ProjectUserS3CredentialParameters

type ProjectUserS3CredentialParameters struct {

	// Service name of the resource representing the ID of the cloud project.
	// +kubebuilder:validation:Optional
	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	// The user ID
	// +kubebuilder:validation:Optional
	UserID *string `json:"userId,omitempty" tf:"user_id,omitempty"`
}

func (*ProjectUserS3CredentialParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectUserS3CredentialParameters.

func (*ProjectUserS3CredentialParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ProjectUserS3CredentialSpec

type ProjectUserS3CredentialSpec struct {
	v1.ResourceSpec `json:",inline"`
	ForProvider     ProjectUserS3CredentialParameters `json:"forProvider"`
	// THIS IS A BETA FIELD. It will be honored
	// unless the Management Policies feature flag is disabled.
	// InitProvider holds the same fields as ForProvider, with the exception
	// of Identifier and other resource reference fields. The fields that are
	// in InitProvider are merged into ForProvider when the resource is created.
	// The same fields are also added to the terraform ignore_changes hook, to
	// avoid updating them after creation. This is useful for fields that are
	// required on creation, but we do not desire to update them after creation,
	// for example because of an external controller is managing them, like an
	// autoscaler.
	InitProvider ProjectUserS3CredentialInitParameters `json:"initProvider,omitempty"`
}

ProjectUserS3CredentialSpec defines the desired state of ProjectUserS3Credential

func (*ProjectUserS3CredentialSpec) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectUserS3CredentialSpec.

func (*ProjectUserS3CredentialSpec) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ProjectUserS3CredentialStatus

type ProjectUserS3CredentialStatus struct {
	v1.ResourceStatus `json:",inline"`
	AtProvider        ProjectUserS3CredentialObservation `json:"atProvider,omitempty"`
}

ProjectUserS3CredentialStatus defines the observed state of ProjectUserS3Credential.

func (*ProjectUserS3CredentialStatus) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProjectUserS3CredentialStatus.

func (*ProjectUserS3CredentialStatus) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to