Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=dbaaslogsinput.crossplane.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type ConfigurationInitParameters
- type ConfigurationObservation
- type ConfigurationParameters
- type FlowggerInitParameters
- type FlowggerObservation
- type FlowggerParameters
- type LogsInput
- func (in *LogsInput) DeepCopy() *LogsInput
- func (in *LogsInput) DeepCopyInto(out *LogsInput)
- func (in *LogsInput) DeepCopyObject() runtime.Object
- func (mg *LogsInput) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *LogsInput) GetConnectionDetailsMapping() map[string]string
- func (mg *LogsInput) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *LogsInput) GetID() string
- func (tr *LogsInput) GetInitParameters() (map[string]any, error)
- func (mg *LogsInput) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *LogsInput) GetObservation() (map[string]any, error)
- func (tr *LogsInput) GetParameters() (map[string]any, error)
- func (mg *LogsInput) GetProviderConfigReference() *xpv1.Reference
- func (mg *LogsInput) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *LogsInput) GetTerraformResourceType() string
- func (tr *LogsInput) GetTerraformSchemaVersion() int
- func (mg *LogsInput) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *LogsInput) LateInitialize(attrs []byte) (bool, error)
- func (mg *LogsInput) SetConditions(c ...xpv1.Condition)
- func (mg *LogsInput) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *LogsInput) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *LogsInput) SetObservation(obs map[string]any) error
- func (tr *LogsInput) SetParameters(params map[string]any) error
- func (mg *LogsInput) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *LogsInput) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *LogsInput) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type LogsInputInitParameters
- type LogsInputList
- type LogsInputObservation
- type LogsInputParameters
- type LogsInputSpec
- type LogsInputStatus
- type LogstashInitParameters
- type LogstashObservation
- type LogstashParameters
Constants ¶
const ( CRDGroup = "dbaaslogsinput.crossplane.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( LogsInput_Kind = "LogsInput" LogsInput_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: LogsInput_Kind}.String() LogsInput_KindAPIVersion = LogsInput_Kind + "." + CRDGroupVersion.String() LogsInput_GroupVersionKind = CRDGroupVersion.WithKind(LogsInput_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type ConfigurationInitParameters ¶
type ConfigurationInitParameters struct {
// Flowgger configuration
Flowgger []FlowggerInitParameters `json:"flowgger,omitempty" tf:"flowgger,omitempty"`
// Logstash configuration
Logstash []LogstashInitParameters `json:"logstash,omitempty" tf:"logstash,omitempty"`
}
func (*ConfigurationInitParameters) DeepCopy ¶
func (in *ConfigurationInitParameters) DeepCopy() *ConfigurationInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConfigurationInitParameters.
func (*ConfigurationInitParameters) DeepCopyInto ¶
func (in *ConfigurationInitParameters) DeepCopyInto(out *ConfigurationInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ConfigurationObservation ¶
type ConfigurationObservation struct {
// Flowgger configuration
Flowgger []FlowggerObservation `json:"flowgger,omitempty" tf:"flowgger,omitempty"`
// Logstash configuration
Logstash []LogstashObservation `json:"logstash,omitempty" tf:"logstash,omitempty"`
}
func (*ConfigurationObservation) DeepCopy ¶
func (in *ConfigurationObservation) DeepCopy() *ConfigurationObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConfigurationObservation.
func (*ConfigurationObservation) DeepCopyInto ¶
func (in *ConfigurationObservation) DeepCopyInto(out *ConfigurationObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ConfigurationParameters ¶
type ConfigurationParameters struct {
// Flowgger configuration
// +kubebuilder:validation:Optional
Flowgger []FlowggerParameters `json:"flowgger,omitempty" tf:"flowgger,omitempty"`
// Logstash configuration
// +kubebuilder:validation:Optional
Logstash []LogstashParameters `json:"logstash,omitempty" tf:"logstash,omitempty"`
}
func (*ConfigurationParameters) DeepCopy ¶
func (in *ConfigurationParameters) DeepCopy() *ConfigurationParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConfigurationParameters.
func (*ConfigurationParameters) DeepCopyInto ¶
func (in *ConfigurationParameters) DeepCopyInto(out *ConfigurationParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type FlowggerInitParameters ¶
type FlowggerInitParameters struct {
// Type of format to decode
LogFormat *string `json:"logFormat,omitempty" tf:"log_format,omitempty"`
// Indicates how messages are delimited
LogFraming *string `json:"logFraming,omitempty" tf:"log_framing,omitempty"`
}
func (*FlowggerInitParameters) DeepCopy ¶
func (in *FlowggerInitParameters) DeepCopy() *FlowggerInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FlowggerInitParameters.
func (*FlowggerInitParameters) DeepCopyInto ¶
func (in *FlowggerInitParameters) DeepCopyInto(out *FlowggerInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type FlowggerObservation ¶
type FlowggerObservation struct {
// Type of format to decode
LogFormat *string `json:"logFormat,omitempty" tf:"log_format,omitempty"`
// Indicates how messages are delimited
LogFraming *string `json:"logFraming,omitempty" tf:"log_framing,omitempty"`
}
func (*FlowggerObservation) DeepCopy ¶
func (in *FlowggerObservation) DeepCopy() *FlowggerObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FlowggerObservation.
func (*FlowggerObservation) DeepCopyInto ¶
func (in *FlowggerObservation) DeepCopyInto(out *FlowggerObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type FlowggerParameters ¶
type FlowggerParameters struct {
// Type of format to decode
// +kubebuilder:validation:Optional
LogFormat *string `json:"logFormat" tf:"log_format,omitempty"`
// Indicates how messages are delimited
// +kubebuilder:validation:Optional
LogFraming *string `json:"logFraming" tf:"log_framing,omitempty"`
}
func (*FlowggerParameters) DeepCopy ¶
func (in *FlowggerParameters) DeepCopy() *FlowggerParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FlowggerParameters.
func (*FlowggerParameters) DeepCopyInto ¶
func (in *FlowggerParameters) DeepCopyInto(out *FlowggerParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LogsInput ¶
type LogsInput struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.configuration) || (has(self.initProvider) && has(self.initProvider.configuration))",message="spec.forProvider.configuration is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.description) || (has(self.initProvider) && has(self.initProvider.description))",message="spec.forProvider.description is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.engineId) || (has(self.initProvider) && has(self.initProvider.engineId))",message="spec.forProvider.engineId is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.streamId) || (has(self.initProvider) && has(self.initProvider.streamId))",message="spec.forProvider.streamId is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.title) || (has(self.initProvider) && has(self.initProvider.title))",message="spec.forProvider.title is a required parameter"
Spec LogsInputSpec `json:"spec"`
Status LogsInputStatus `json:"status,omitempty"`
}
LogsInput is the Schema for the LogsInputs API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}
func (*LogsInput) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LogsInput.
func (*LogsInput) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LogsInput) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*LogsInput) GetCondition ¶
func (mg *LogsInput) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this LogsInput.
func (*LogsInput) GetConnectionDetailsMapping ¶
GetConnectionDetailsMapping for this LogsInput
func (*LogsInput) GetDeletionPolicy ¶
func (mg *LogsInput) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this LogsInput.
func (*LogsInput) GetInitParameters ¶
GetInitParameters of this LogsInput
func (*LogsInput) GetManagementPolicies ¶
func (mg *LogsInput) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this LogsInput.
func (*LogsInput) GetObservation ¶
GetObservation of this LogsInput
func (*LogsInput) GetParameters ¶
GetParameters of this LogsInput
func (*LogsInput) GetProviderConfigReference ¶
GetProviderConfigReference of this LogsInput.
func (*LogsInput) GetPublishConnectionDetailsTo ¶
func (mg *LogsInput) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this LogsInput.
func (*LogsInput) GetTerraformResourceType ¶
GetTerraformResourceType returns Terraform resource type for this LogsInput
func (*LogsInput) GetTerraformSchemaVersion ¶
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*LogsInput) GetWriteConnectionSecretToReference ¶
func (mg *LogsInput) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this LogsInput.
func (*LogsInput) LateInitialize ¶
LateInitialize this LogsInput using its observed tfState. returns True if there are any spec changes for the resource.
func (*LogsInput) SetConditions ¶
SetConditions of this LogsInput.
func (*LogsInput) SetDeletionPolicy ¶
func (mg *LogsInput) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this LogsInput.
func (*LogsInput) SetManagementPolicies ¶
func (mg *LogsInput) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this LogsInput.
func (*LogsInput) SetObservation ¶
SetObservation for this LogsInput
func (*LogsInput) SetParameters ¶
SetParameters for this LogsInput
func (*LogsInput) SetProviderConfigReference ¶
SetProviderConfigReference of this LogsInput.
func (*LogsInput) SetPublishConnectionDetailsTo ¶
func (mg *LogsInput) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this LogsInput.
func (*LogsInput) SetWriteConnectionSecretToReference ¶
func (mg *LogsInput) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this LogsInput.
type LogsInputInitParameters ¶
type LogsInputInitParameters struct {
// IP blocks
AllowedNetworks []*string `json:"allowedNetworks,omitempty" tf:"allowed_networks,omitempty"`
// Input configuration
Configuration []ConfigurationInitParameters `json:"configuration,omitempty" tf:"configuration,omitempty"`
// Input description
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// Input engine ID
EngineID *string `json:"engineId,omitempty" tf:"engine_id,omitempty"`
// Port
ExposedPort *string `json:"exposedPort,omitempty" tf:"exposed_port,omitempty"`
// Number of instance running
NbInstance *float64 `json:"nbInstance,omitempty" tf:"nb_instance,omitempty"`
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Associated Graylog stream
StreamID *string `json:"streamId,omitempty" tf:"stream_id,omitempty"`
// Input title
Title *string `json:"title,omitempty" tf:"title,omitempty"`
}
func (*LogsInputInitParameters) DeepCopy ¶
func (in *LogsInputInitParameters) DeepCopy() *LogsInputInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LogsInputInitParameters.
func (*LogsInputInitParameters) DeepCopyInto ¶
func (in *LogsInputInitParameters) DeepCopyInto(out *LogsInputInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LogsInputList ¶
type LogsInputList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []LogsInput `json:"items"`
}
LogsInputList contains a list of LogsInputs
func (*LogsInputList) DeepCopy ¶
func (in *LogsInputList) DeepCopy() *LogsInputList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LogsInputList.
func (*LogsInputList) DeepCopyInto ¶
func (in *LogsInputList) DeepCopyInto(out *LogsInputList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LogsInputList) DeepCopyObject ¶
func (in *LogsInputList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*LogsInputList) GetItems ¶
func (l *LogsInputList) GetItems() []resource.Managed
GetItems of this LogsInputList.
type LogsInputObservation ¶
type LogsInputObservation struct {
// IP blocks
AllowedNetworks []*string `json:"allowedNetworks,omitempty" tf:"allowed_networks,omitempty"`
// Input configuration
Configuration []ConfigurationObservation `json:"configuration,omitempty" tf:"configuration,omitempty"`
// Input creation
CreatedAt *string `json:"createdAt,omitempty" tf:"created_at,omitempty"`
// Input description
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// Input engine ID
EngineID *string `json:"engineId,omitempty" tf:"engine_id,omitempty"`
// Port
ExposedPort *string `json:"exposedPort,omitempty" tf:"exposed_port,omitempty"`
// Hostname
Hostname *string `json:"hostname,omitempty" tf:"hostname,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// Input ID
InputID *string `json:"inputId,omitempty" tf:"input_id,omitempty"`
// Indicate if input need to be restarted
IsRestartRequired *bool `json:"isRestartRequired,omitempty" tf:"is_restart_required,omitempty"`
// Number of instance running
NbInstance *float64 `json:"nbInstance,omitempty" tf:"nb_instance,omitempty"`
// Input IP address
PublicAddress *string `json:"publicAddress,omitempty" tf:"public_address,omitempty"`
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// init: configuration required, pending: ready to start, running: available
Status *string `json:"status,omitempty" tf:"status,omitempty"`
// Associated Graylog stream
StreamID *string `json:"streamId,omitempty" tf:"stream_id,omitempty"`
// Input title
Title *string `json:"title,omitempty" tf:"title,omitempty"`
// Input last update
UpdatedAt *string `json:"updatedAt,omitempty" tf:"updated_at,omitempty"`
}
func (*LogsInputObservation) DeepCopy ¶
func (in *LogsInputObservation) DeepCopy() *LogsInputObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LogsInputObservation.
func (*LogsInputObservation) DeepCopyInto ¶
func (in *LogsInputObservation) DeepCopyInto(out *LogsInputObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LogsInputParameters ¶
type LogsInputParameters struct {
// IP blocks
// +kubebuilder:validation:Optional
AllowedNetworks []*string `json:"allowedNetworks,omitempty" tf:"allowed_networks,omitempty"`
// Input configuration
// +kubebuilder:validation:Optional
Configuration []ConfigurationParameters `json:"configuration,omitempty" tf:"configuration,omitempty"`
// Input description
// +kubebuilder:validation:Optional
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// Input engine ID
// +kubebuilder:validation:Optional
EngineID *string `json:"engineId,omitempty" tf:"engine_id,omitempty"`
// Port
// +kubebuilder:validation:Optional
ExposedPort *string `json:"exposedPort,omitempty" tf:"exposed_port,omitempty"`
// Number of instance running
// +kubebuilder:validation:Optional
NbInstance *float64 `json:"nbInstance,omitempty" tf:"nb_instance,omitempty"`
// +kubebuilder:validation:Optional
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Associated Graylog stream
// +kubebuilder:validation:Optional
StreamID *string `json:"streamId,omitempty" tf:"stream_id,omitempty"`
// Input title
// +kubebuilder:validation:Optional
Title *string `json:"title,omitempty" tf:"title,omitempty"`
}
func (*LogsInputParameters) DeepCopy ¶
func (in *LogsInputParameters) DeepCopy() *LogsInputParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LogsInputParameters.
func (*LogsInputParameters) DeepCopyInto ¶
func (in *LogsInputParameters) DeepCopyInto(out *LogsInputParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LogsInputSpec ¶
type LogsInputSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider LogsInputParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider LogsInputInitParameters `json:"initProvider,omitempty"`
}
LogsInputSpec defines the desired state of LogsInput
func (*LogsInputSpec) DeepCopy ¶
func (in *LogsInputSpec) DeepCopy() *LogsInputSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LogsInputSpec.
func (*LogsInputSpec) DeepCopyInto ¶
func (in *LogsInputSpec) DeepCopyInto(out *LogsInputSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LogsInputStatus ¶
type LogsInputStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider LogsInputObservation `json:"atProvider,omitempty"`
}
LogsInputStatus defines the observed state of LogsInput.
func (*LogsInputStatus) DeepCopy ¶
func (in *LogsInputStatus) DeepCopy() *LogsInputStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LogsInputStatus.
func (*LogsInputStatus) DeepCopyInto ¶
func (in *LogsInputStatus) DeepCopyInto(out *LogsInputStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LogstashInitParameters ¶
type LogstashInitParameters struct {
// The filter section of logstash.conf
FilterSection *string `json:"filterSection,omitempty" tf:"filter_section,omitempty"`
// The filter section of logstash.conf
InputSection *string `json:"inputSection,omitempty" tf:"input_section,omitempty"`
// The list of customs Grok patterns
PatternSection *string `json:"patternSection,omitempty" tf:"pattern_section,omitempty"`
}
func (*LogstashInitParameters) DeepCopy ¶
func (in *LogstashInitParameters) DeepCopy() *LogstashInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LogstashInitParameters.
func (*LogstashInitParameters) DeepCopyInto ¶
func (in *LogstashInitParameters) DeepCopyInto(out *LogstashInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LogstashObservation ¶
type LogstashObservation struct {
// The filter section of logstash.conf
FilterSection *string `json:"filterSection,omitempty" tf:"filter_section,omitempty"`
// The filter section of logstash.conf
InputSection *string `json:"inputSection,omitempty" tf:"input_section,omitempty"`
// The list of customs Grok patterns
PatternSection *string `json:"patternSection,omitempty" tf:"pattern_section,omitempty"`
}
func (*LogstashObservation) DeepCopy ¶
func (in *LogstashObservation) DeepCopy() *LogstashObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LogstashObservation.
func (*LogstashObservation) DeepCopyInto ¶
func (in *LogstashObservation) DeepCopyInto(out *LogstashObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LogstashParameters ¶
type LogstashParameters struct {
// The filter section of logstash.conf
// +kubebuilder:validation:Optional
FilterSection *string `json:"filterSection,omitempty" tf:"filter_section,omitempty"`
// The filter section of logstash.conf
// +kubebuilder:validation:Optional
InputSection *string `json:"inputSection" tf:"input_section,omitempty"`
// The list of customs Grok patterns
// +kubebuilder:validation:Optional
PatternSection *string `json:"patternSection,omitempty" tf:"pattern_section,omitempty"`
}
func (*LogstashParameters) DeepCopy ¶
func (in *LogstashParameters) DeepCopy() *LogstashParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LogstashParameters.
func (*LogstashParameters) DeepCopyInto ¶
func (in *LogstashParameters) DeepCopyInto(out *LogstashParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.