v1alpha1

package
v0.0.0-...-73c97c3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 17, 2024 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

+kubebuilder:object:generate=true +groupName=dedicatednashapartition.crossplane.io +versionName=v1alpha1

Index

Constants

const (
	CRDGroup   = "dedicatednashapartition.crossplane.io"
	CRDVersion = "v1alpha1"
)

Package type metadata.

Variables

var (
	// CRDGroupVersion is the API Group Version used to register the objects
	CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)
var (
	NashaPartition_Kind             = "NashaPartition"
	NashaPartition_GroupKind        = schema.GroupKind{Group: CRDGroup, Kind: NashaPartition_Kind}.String()
	NashaPartition_KindAPIVersion   = NashaPartition_Kind + "." + CRDGroupVersion.String()
	NashaPartition_GroupVersionKind = CRDGroupVersion.WithKind(NashaPartition_Kind)
)

Repository type metadata.

Functions

This section is empty.

Types

type NashaPartition

type NashaPartition struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.protocol) || (has(self.initProvider) && has(self.initProvider.protocol))",message="spec.forProvider.protocol is a required parameter"
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.size) || (has(self.initProvider) && has(self.initProvider.size))",message="spec.forProvider.size is a required parameter"
	Spec   NashaPartitionSpec   `json:"spec"`
	Status NashaPartitionStatus `json:"status,omitempty"`
}

NashaPartition is the Schema for the NashaPartitions API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}

func (*NashaPartition) DeepCopy

func (in *NashaPartition) DeepCopy() *NashaPartition

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NashaPartition.

func (*NashaPartition) DeepCopyInto

func (in *NashaPartition) DeepCopyInto(out *NashaPartition)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*NashaPartition) DeepCopyObject

func (in *NashaPartition) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*NashaPartition) GetCondition

func (mg *NashaPartition) GetCondition(ct xpv1.ConditionType) xpv1.Condition

GetCondition of this NashaPartition.

func (*NashaPartition) GetConnectionDetailsMapping

func (tr *NashaPartition) GetConnectionDetailsMapping() map[string]string

GetConnectionDetailsMapping for this NashaPartition

func (*NashaPartition) GetDeletionPolicy

func (mg *NashaPartition) GetDeletionPolicy() xpv1.DeletionPolicy

GetDeletionPolicy of this NashaPartition.

func (*NashaPartition) GetID

func (tr *NashaPartition) GetID() string

GetID returns ID of underlying Terraform resource of this NashaPartition

func (*NashaPartition) GetInitParameters

func (tr *NashaPartition) GetInitParameters() (map[string]any, error)

GetInitParameters of this NashaPartition

func (*NashaPartition) GetManagementPolicies

func (mg *NashaPartition) GetManagementPolicies() xpv1.ManagementPolicies

GetManagementPolicies of this NashaPartition.

func (*NashaPartition) GetObservation

func (tr *NashaPartition) GetObservation() (map[string]any, error)

GetObservation of this NashaPartition

func (*NashaPartition) GetParameters

func (tr *NashaPartition) GetParameters() (map[string]any, error)

GetParameters of this NashaPartition

func (*NashaPartition) GetProviderConfigReference

func (mg *NashaPartition) GetProviderConfigReference() *xpv1.Reference

GetProviderConfigReference of this NashaPartition.

func (*NashaPartition) GetPublishConnectionDetailsTo

func (mg *NashaPartition) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo

GetPublishConnectionDetailsTo of this NashaPartition.

func (*NashaPartition) GetTerraformResourceType

func (mg *NashaPartition) GetTerraformResourceType() string

GetTerraformResourceType returns Terraform resource type for this NashaPartition

func (*NashaPartition) GetTerraformSchemaVersion

func (tr *NashaPartition) GetTerraformSchemaVersion() int

GetTerraformSchemaVersion returns the associated Terraform schema version

func (*NashaPartition) GetWriteConnectionSecretToReference

func (mg *NashaPartition) GetWriteConnectionSecretToReference() *xpv1.SecretReference

GetWriteConnectionSecretToReference of this NashaPartition.

func (*NashaPartition) LateInitialize

func (tr *NashaPartition) LateInitialize(attrs []byte) (bool, error)

LateInitialize this NashaPartition using its observed tfState. returns True if there are any spec changes for the resource.

func (*NashaPartition) SetConditions

func (mg *NashaPartition) SetConditions(c ...xpv1.Condition)

SetConditions of this NashaPartition.

func (*NashaPartition) SetDeletionPolicy

func (mg *NashaPartition) SetDeletionPolicy(r xpv1.DeletionPolicy)

SetDeletionPolicy of this NashaPartition.

func (*NashaPartition) SetManagementPolicies

func (mg *NashaPartition) SetManagementPolicies(r xpv1.ManagementPolicies)

SetManagementPolicies of this NashaPartition.

func (*NashaPartition) SetObservation

func (tr *NashaPartition) SetObservation(obs map[string]any) error

SetObservation for this NashaPartition

func (*NashaPartition) SetParameters

func (tr *NashaPartition) SetParameters(params map[string]any) error

SetParameters for this NashaPartition

func (*NashaPartition) SetProviderConfigReference

func (mg *NashaPartition) SetProviderConfigReference(r *xpv1.Reference)

SetProviderConfigReference of this NashaPartition.

func (*NashaPartition) SetPublishConnectionDetailsTo

func (mg *NashaPartition) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)

SetPublishConnectionDetailsTo of this NashaPartition.

func (*NashaPartition) SetWriteConnectionSecretToReference

func (mg *NashaPartition) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)

SetWriteConnectionSecretToReference of this NashaPartition.

type NashaPartitionInitParameters

type NashaPartitionInitParameters struct {
	Description *string `json:"description,omitempty" tf:"description,omitempty"`

	Protocol *string `json:"protocol,omitempty" tf:"protocol,omitempty"`

	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	Size *float64 `json:"size,omitempty" tf:"size,omitempty"`
}

func (*NashaPartitionInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NashaPartitionInitParameters.

func (*NashaPartitionInitParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type NashaPartitionList

type NashaPartitionList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []NashaPartition `json:"items"`
}

NashaPartitionList contains a list of NashaPartitions

func (*NashaPartitionList) DeepCopy

func (in *NashaPartitionList) DeepCopy() *NashaPartitionList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NashaPartitionList.

func (*NashaPartitionList) DeepCopyInto

func (in *NashaPartitionList) DeepCopyInto(out *NashaPartitionList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*NashaPartitionList) DeepCopyObject

func (in *NashaPartitionList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*NashaPartitionList) GetItems

func (l *NashaPartitionList) GetItems() []resource.Managed

GetItems of this NashaPartitionList.

type NashaPartitionObservation

type NashaPartitionObservation struct {
	Capacity *float64 `json:"capacity,omitempty" tf:"capacity,omitempty"`

	Description *string `json:"description,omitempty" tf:"description,omitempty"`

	ID *string `json:"id,omitempty" tf:"id,omitempty"`

	Protocol *string `json:"protocol,omitempty" tf:"protocol,omitempty"`

	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	Size *float64 `json:"size,omitempty" tf:"size,omitempty"`

	UsedBySnapshots *float64 `json:"usedBySnapshots,omitempty" tf:"used_by_snapshots,omitempty"`
}

func (*NashaPartitionObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NashaPartitionObservation.

func (*NashaPartitionObservation) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type NashaPartitionParameters

type NashaPartitionParameters struct {

	// +kubebuilder:validation:Optional
	Description *string `json:"description,omitempty" tf:"description,omitempty"`

	// +kubebuilder:validation:Optional
	Protocol *string `json:"protocol,omitempty" tf:"protocol,omitempty"`

	// +kubebuilder:validation:Optional
	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	// +kubebuilder:validation:Optional
	Size *float64 `json:"size,omitempty" tf:"size,omitempty"`
}

func (*NashaPartitionParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NashaPartitionParameters.

func (*NashaPartitionParameters) DeepCopyInto

func (in *NashaPartitionParameters) DeepCopyInto(out *NashaPartitionParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type NashaPartitionSpec

type NashaPartitionSpec struct {
	v1.ResourceSpec `json:",inline"`
	ForProvider     NashaPartitionParameters `json:"forProvider"`
	// THIS IS A BETA FIELD. It will be honored
	// unless the Management Policies feature flag is disabled.
	// InitProvider holds the same fields as ForProvider, with the exception
	// of Identifier and other resource reference fields. The fields that are
	// in InitProvider are merged into ForProvider when the resource is created.
	// The same fields are also added to the terraform ignore_changes hook, to
	// avoid updating them after creation. This is useful for fields that are
	// required on creation, but we do not desire to update them after creation,
	// for example because of an external controller is managing them, like an
	// autoscaler.
	InitProvider NashaPartitionInitParameters `json:"initProvider,omitempty"`
}

NashaPartitionSpec defines the desired state of NashaPartition

func (*NashaPartitionSpec) DeepCopy

func (in *NashaPartitionSpec) DeepCopy() *NashaPartitionSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NashaPartitionSpec.

func (*NashaPartitionSpec) DeepCopyInto

func (in *NashaPartitionSpec) DeepCopyInto(out *NashaPartitionSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type NashaPartitionStatus

type NashaPartitionStatus struct {
	v1.ResourceStatus `json:",inline"`
	AtProvider        NashaPartitionObservation `json:"atProvider,omitempty"`
}

NashaPartitionStatus defines the observed state of NashaPartition.

func (*NashaPartitionStatus) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NashaPartitionStatus.

func (*NashaPartitionStatus) DeepCopyInto

func (in *NashaPartitionStatus) DeepCopyInto(out *NashaPartitionStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to