v1alpha1

package
v0.0.0-...-73c97c3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 17, 2024 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

+kubebuilder:object:generate=true +groupName=dedicatedserverupdate.crossplane.io +versionName=v1alpha1

Index

Constants

const (
	CRDGroup   = "dedicatedserverupdate.crossplane.io"
	CRDVersion = "v1alpha1"
)

Package type metadata.

Variables

var (
	// CRDGroupVersion is the API Group Version used to register the objects
	CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)
var (
	ServerUpdate_Kind             = "ServerUpdate"
	ServerUpdate_GroupKind        = schema.GroupKind{Group: CRDGroup, Kind: ServerUpdate_Kind}.String()
	ServerUpdate_KindAPIVersion   = ServerUpdate_Kind + "." + CRDGroupVersion.String()
	ServerUpdate_GroupVersionKind = CRDGroupVersion.WithKind(ServerUpdate_Kind)
)

Repository type metadata.

Functions

This section is empty.

Types

type ServerUpdate

type ServerUpdate struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
	Spec   ServerUpdateSpec   `json:"spec"`
	Status ServerUpdateStatus `json:"status,omitempty"`
}

ServerUpdate is the Schema for the ServerUpdates API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}

func (*ServerUpdate) DeepCopy

func (in *ServerUpdate) DeepCopy() *ServerUpdate

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServerUpdate.

func (*ServerUpdate) DeepCopyInto

func (in *ServerUpdate) DeepCopyInto(out *ServerUpdate)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ServerUpdate) DeepCopyObject

func (in *ServerUpdate) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*ServerUpdate) GetCondition

func (mg *ServerUpdate) GetCondition(ct xpv1.ConditionType) xpv1.Condition

GetCondition of this ServerUpdate.

func (*ServerUpdate) GetConnectionDetailsMapping

func (tr *ServerUpdate) GetConnectionDetailsMapping() map[string]string

GetConnectionDetailsMapping for this ServerUpdate

func (*ServerUpdate) GetDeletionPolicy

func (mg *ServerUpdate) GetDeletionPolicy() xpv1.DeletionPolicy

GetDeletionPolicy of this ServerUpdate.

func (*ServerUpdate) GetID

func (tr *ServerUpdate) GetID() string

GetID returns ID of underlying Terraform resource of this ServerUpdate

func (*ServerUpdate) GetInitParameters

func (tr *ServerUpdate) GetInitParameters() (map[string]any, error)

GetInitParameters of this ServerUpdate

func (*ServerUpdate) GetManagementPolicies

func (mg *ServerUpdate) GetManagementPolicies() xpv1.ManagementPolicies

GetManagementPolicies of this ServerUpdate.

func (*ServerUpdate) GetObservation

func (tr *ServerUpdate) GetObservation() (map[string]any, error)

GetObservation of this ServerUpdate

func (*ServerUpdate) GetParameters

func (tr *ServerUpdate) GetParameters() (map[string]any, error)

GetParameters of this ServerUpdate

func (*ServerUpdate) GetProviderConfigReference

func (mg *ServerUpdate) GetProviderConfigReference() *xpv1.Reference

GetProviderConfigReference of this ServerUpdate.

func (*ServerUpdate) GetPublishConnectionDetailsTo

func (mg *ServerUpdate) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo

GetPublishConnectionDetailsTo of this ServerUpdate.

func (*ServerUpdate) GetTerraformResourceType

func (mg *ServerUpdate) GetTerraformResourceType() string

GetTerraformResourceType returns Terraform resource type for this ServerUpdate

func (*ServerUpdate) GetTerraformSchemaVersion

func (tr *ServerUpdate) GetTerraformSchemaVersion() int

GetTerraformSchemaVersion returns the associated Terraform schema version

func (*ServerUpdate) GetWriteConnectionSecretToReference

func (mg *ServerUpdate) GetWriteConnectionSecretToReference() *xpv1.SecretReference

GetWriteConnectionSecretToReference of this ServerUpdate.

func (*ServerUpdate) LateInitialize

func (tr *ServerUpdate) LateInitialize(attrs []byte) (bool, error)

LateInitialize this ServerUpdate using its observed tfState. returns True if there are any spec changes for the resource.

func (*ServerUpdate) SetConditions

func (mg *ServerUpdate) SetConditions(c ...xpv1.Condition)

SetConditions of this ServerUpdate.

func (*ServerUpdate) SetDeletionPolicy

func (mg *ServerUpdate) SetDeletionPolicy(r xpv1.DeletionPolicy)

SetDeletionPolicy of this ServerUpdate.

func (*ServerUpdate) SetManagementPolicies

func (mg *ServerUpdate) SetManagementPolicies(r xpv1.ManagementPolicies)

SetManagementPolicies of this ServerUpdate.

func (*ServerUpdate) SetObservation

func (tr *ServerUpdate) SetObservation(obs map[string]any) error

SetObservation for this ServerUpdate

func (*ServerUpdate) SetParameters

func (tr *ServerUpdate) SetParameters(params map[string]any) error

SetParameters for this ServerUpdate

func (*ServerUpdate) SetProviderConfigReference

func (mg *ServerUpdate) SetProviderConfigReference(r *xpv1.Reference)

SetProviderConfigReference of this ServerUpdate.

func (*ServerUpdate) SetPublishConnectionDetailsTo

func (mg *ServerUpdate) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)

SetPublishConnectionDetailsTo of this ServerUpdate.

func (*ServerUpdate) SetWriteConnectionSecretToReference

func (mg *ServerUpdate) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)

SetWriteConnectionSecretToReference of this ServerUpdate.

type ServerUpdateInitParameters

type ServerUpdateInitParameters struct {

	// The boot id of your dedicated server.
	BootID *float64 `json:"bootId,omitempty" tf:"boot_id,omitempty"`

	// Icmp monitoring state
	Monitoring *bool `json:"monitoring,omitempty" tf:"monitoring,omitempty"`

	// The internal name of your dedicated server.
	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	// error, hacked, hackedBlocked, ok
	State *string `json:"state,omitempty" tf:"state,omitempty"`
}

func (*ServerUpdateInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServerUpdateInitParameters.

func (*ServerUpdateInitParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ServerUpdateList

type ServerUpdateList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []ServerUpdate `json:"items"`
}

ServerUpdateList contains a list of ServerUpdates

func (*ServerUpdateList) DeepCopy

func (in *ServerUpdateList) DeepCopy() *ServerUpdateList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServerUpdateList.

func (*ServerUpdateList) DeepCopyInto

func (in *ServerUpdateList) DeepCopyInto(out *ServerUpdateList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ServerUpdateList) DeepCopyObject

func (in *ServerUpdateList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*ServerUpdateList) GetItems

func (l *ServerUpdateList) GetItems() []resource.Managed

GetItems of this ServerUpdateList.

type ServerUpdateObservation

type ServerUpdateObservation struct {

	// The boot id of your dedicated server.
	BootID *float64 `json:"bootId,omitempty" tf:"boot_id,omitempty"`

	ID *string `json:"id,omitempty" tf:"id,omitempty"`

	// Icmp monitoring state
	Monitoring *bool `json:"monitoring,omitempty" tf:"monitoring,omitempty"`

	// The internal name of your dedicated server.
	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	// error, hacked, hackedBlocked, ok
	State *string `json:"state,omitempty" tf:"state,omitempty"`
}

func (*ServerUpdateObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServerUpdateObservation.

func (*ServerUpdateObservation) DeepCopyInto

func (in *ServerUpdateObservation) DeepCopyInto(out *ServerUpdateObservation)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ServerUpdateParameters

type ServerUpdateParameters struct {

	// The boot id of your dedicated server.
	// +kubebuilder:validation:Optional
	BootID *float64 `json:"bootId,omitempty" tf:"boot_id,omitempty"`

	// Icmp monitoring state
	// +kubebuilder:validation:Optional
	Monitoring *bool `json:"monitoring,omitempty" tf:"monitoring,omitempty"`

	// The internal name of your dedicated server.
	// +kubebuilder:validation:Optional
	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	// error, hacked, hackedBlocked, ok
	// +kubebuilder:validation:Optional
	State *string `json:"state,omitempty" tf:"state,omitempty"`
}

func (*ServerUpdateParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServerUpdateParameters.

func (*ServerUpdateParameters) DeepCopyInto

func (in *ServerUpdateParameters) DeepCopyInto(out *ServerUpdateParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ServerUpdateSpec

type ServerUpdateSpec struct {
	v1.ResourceSpec `json:",inline"`
	ForProvider     ServerUpdateParameters `json:"forProvider"`
	// THIS IS A BETA FIELD. It will be honored
	// unless the Management Policies feature flag is disabled.
	// InitProvider holds the same fields as ForProvider, with the exception
	// of Identifier and other resource reference fields. The fields that are
	// in InitProvider are merged into ForProvider when the resource is created.
	// The same fields are also added to the terraform ignore_changes hook, to
	// avoid updating them after creation. This is useful for fields that are
	// required on creation, but we do not desire to update them after creation,
	// for example because of an external controller is managing them, like an
	// autoscaler.
	InitProvider ServerUpdateInitParameters `json:"initProvider,omitempty"`
}

ServerUpdateSpec defines the desired state of ServerUpdate

func (*ServerUpdateSpec) DeepCopy

func (in *ServerUpdateSpec) DeepCopy() *ServerUpdateSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServerUpdateSpec.

func (*ServerUpdateSpec) DeepCopyInto

func (in *ServerUpdateSpec) DeepCopyInto(out *ServerUpdateSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ServerUpdateStatus

type ServerUpdateStatus struct {
	v1.ResourceStatus `json:",inline"`
	AtProvider        ServerUpdateObservation `json:"atProvider,omitempty"`
}

ServerUpdateStatus defines the observed state of ServerUpdate.

func (*ServerUpdateStatus) DeepCopy

func (in *ServerUpdateStatus) DeepCopy() *ServerUpdateStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServerUpdateStatus.

func (*ServerUpdateStatus) DeepCopyInto

func (in *ServerUpdateStatus) DeepCopyInto(out *ServerUpdateStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to