v1alpha1

package
v0.0.0-...-73c97c3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 17, 2024 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

+kubebuilder:object:generate=true +groupName=hostingprivatedatabasedatabase.crossplane.io +versionName=v1alpha1

Index

Constants

const (
	CRDGroup   = "hostingprivatedatabasedatabase.crossplane.io"
	CRDVersion = "v1alpha1"
)

Package type metadata.

Variables

var (
	// CRDGroupVersion is the API Group Version used to register the objects
	CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)
var (
	PrivatedatabaseDatabase_Kind             = "PrivatedatabaseDatabase"
	PrivatedatabaseDatabase_GroupKind        = schema.GroupKind{Group: CRDGroup, Kind: PrivatedatabaseDatabase_Kind}.String()
	PrivatedatabaseDatabase_KindAPIVersion   = PrivatedatabaseDatabase_Kind + "." + CRDGroupVersion.String()
	PrivatedatabaseDatabase_GroupVersionKind = CRDGroupVersion.WithKind(PrivatedatabaseDatabase_Kind)
)

Repository type metadata.

Functions

This section is empty.

Types

type PrivatedatabaseDatabase

type PrivatedatabaseDatabase struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
	Spec   PrivatedatabaseDatabaseSpec   `json:"spec"`
	Status PrivatedatabaseDatabaseStatus `json:"status,omitempty"`
}

PrivatedatabaseDatabase is the Schema for the PrivatedatabaseDatabases API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}

func (*PrivatedatabaseDatabase) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseDatabase.

func (*PrivatedatabaseDatabase) DeepCopyInto

func (in *PrivatedatabaseDatabase) DeepCopyInto(out *PrivatedatabaseDatabase)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*PrivatedatabaseDatabase) DeepCopyObject

func (in *PrivatedatabaseDatabase) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*PrivatedatabaseDatabase) GetCondition

GetCondition of this PrivatedatabaseDatabase.

func (*PrivatedatabaseDatabase) GetConnectionDetailsMapping

func (tr *PrivatedatabaseDatabase) GetConnectionDetailsMapping() map[string]string

GetConnectionDetailsMapping for this PrivatedatabaseDatabase

func (*PrivatedatabaseDatabase) GetDeletionPolicy

func (mg *PrivatedatabaseDatabase) GetDeletionPolicy() xpv1.DeletionPolicy

GetDeletionPolicy of this PrivatedatabaseDatabase.

func (*PrivatedatabaseDatabase) GetID

func (tr *PrivatedatabaseDatabase) GetID() string

GetID returns ID of underlying Terraform resource of this PrivatedatabaseDatabase

func (*PrivatedatabaseDatabase) GetInitParameters

func (tr *PrivatedatabaseDatabase) GetInitParameters() (map[string]any, error)

GetInitParameters of this PrivatedatabaseDatabase

func (*PrivatedatabaseDatabase) GetManagementPolicies

func (mg *PrivatedatabaseDatabase) GetManagementPolicies() xpv1.ManagementPolicies

GetManagementPolicies of this PrivatedatabaseDatabase.

func (*PrivatedatabaseDatabase) GetObservation

func (tr *PrivatedatabaseDatabase) GetObservation() (map[string]any, error)

GetObservation of this PrivatedatabaseDatabase

func (*PrivatedatabaseDatabase) GetParameters

func (tr *PrivatedatabaseDatabase) GetParameters() (map[string]any, error)

GetParameters of this PrivatedatabaseDatabase

func (*PrivatedatabaseDatabase) GetProviderConfigReference

func (mg *PrivatedatabaseDatabase) GetProviderConfigReference() *xpv1.Reference

GetProviderConfigReference of this PrivatedatabaseDatabase.

func (*PrivatedatabaseDatabase) GetPublishConnectionDetailsTo

func (mg *PrivatedatabaseDatabase) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo

GetPublishConnectionDetailsTo of this PrivatedatabaseDatabase.

func (*PrivatedatabaseDatabase) GetTerraformResourceType

func (mg *PrivatedatabaseDatabase) GetTerraformResourceType() string

GetTerraformResourceType returns Terraform resource type for this PrivatedatabaseDatabase

func (*PrivatedatabaseDatabase) GetTerraformSchemaVersion

func (tr *PrivatedatabaseDatabase) GetTerraformSchemaVersion() int

GetTerraformSchemaVersion returns the associated Terraform schema version

func (*PrivatedatabaseDatabase) GetWriteConnectionSecretToReference

func (mg *PrivatedatabaseDatabase) GetWriteConnectionSecretToReference() *xpv1.SecretReference

GetWriteConnectionSecretToReference of this PrivatedatabaseDatabase.

func (*PrivatedatabaseDatabase) LateInitialize

func (tr *PrivatedatabaseDatabase) LateInitialize(attrs []byte) (bool, error)

LateInitialize this PrivatedatabaseDatabase using its observed tfState. returns True if there are any spec changes for the resource.

func (*PrivatedatabaseDatabase) SetConditions

func (mg *PrivatedatabaseDatabase) SetConditions(c ...xpv1.Condition)

SetConditions of this PrivatedatabaseDatabase.

func (*PrivatedatabaseDatabase) SetDeletionPolicy

func (mg *PrivatedatabaseDatabase) SetDeletionPolicy(r xpv1.DeletionPolicy)

SetDeletionPolicy of this PrivatedatabaseDatabase.

func (*PrivatedatabaseDatabase) SetManagementPolicies

func (mg *PrivatedatabaseDatabase) SetManagementPolicies(r xpv1.ManagementPolicies)

SetManagementPolicies of this PrivatedatabaseDatabase.

func (*PrivatedatabaseDatabase) SetObservation

func (tr *PrivatedatabaseDatabase) SetObservation(obs map[string]any) error

SetObservation for this PrivatedatabaseDatabase

func (*PrivatedatabaseDatabase) SetParameters

func (tr *PrivatedatabaseDatabase) SetParameters(params map[string]any) error

SetParameters for this PrivatedatabaseDatabase

func (*PrivatedatabaseDatabase) SetProviderConfigReference

func (mg *PrivatedatabaseDatabase) SetProviderConfigReference(r *xpv1.Reference)

SetProviderConfigReference of this PrivatedatabaseDatabase.

func (*PrivatedatabaseDatabase) SetPublishConnectionDetailsTo

func (mg *PrivatedatabaseDatabase) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)

SetPublishConnectionDetailsTo of this PrivatedatabaseDatabase.

func (*PrivatedatabaseDatabase) SetWriteConnectionSecretToReference

func (mg *PrivatedatabaseDatabase) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)

SetWriteConnectionSecretToReference of this PrivatedatabaseDatabase.

type PrivatedatabaseDatabaseInitParameters

type PrivatedatabaseDatabaseInitParameters struct {

	// The internal name of your private database
	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
}

func (*PrivatedatabaseDatabaseInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseDatabaseInitParameters.

func (*PrivatedatabaseDatabaseInitParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type PrivatedatabaseDatabaseList

type PrivatedatabaseDatabaseList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []PrivatedatabaseDatabase `json:"items"`
}

PrivatedatabaseDatabaseList contains a list of PrivatedatabaseDatabases

func (*PrivatedatabaseDatabaseList) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseDatabaseList.

func (*PrivatedatabaseDatabaseList) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*PrivatedatabaseDatabaseList) DeepCopyObject

func (in *PrivatedatabaseDatabaseList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*PrivatedatabaseDatabaseList) GetItems

GetItems of this PrivatedatabaseDatabaseList.

type PrivatedatabaseDatabaseObservation

type PrivatedatabaseDatabaseObservation struct {
	ID *string `json:"id,omitempty" tf:"id,omitempty"`

	// The internal name of your private database
	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
}

func (*PrivatedatabaseDatabaseObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseDatabaseObservation.

func (*PrivatedatabaseDatabaseObservation) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type PrivatedatabaseDatabaseParameters

type PrivatedatabaseDatabaseParameters struct {

	// The internal name of your private database
	// +kubebuilder:validation:Optional
	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
}

func (*PrivatedatabaseDatabaseParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseDatabaseParameters.

func (*PrivatedatabaseDatabaseParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type PrivatedatabaseDatabaseSpec

type PrivatedatabaseDatabaseSpec struct {
	v1.ResourceSpec `json:",inline"`
	ForProvider     PrivatedatabaseDatabaseParameters `json:"forProvider"`
	// THIS IS A BETA FIELD. It will be honored
	// unless the Management Policies feature flag is disabled.
	// InitProvider holds the same fields as ForProvider, with the exception
	// of Identifier and other resource reference fields. The fields that are
	// in InitProvider are merged into ForProvider when the resource is created.
	// The same fields are also added to the terraform ignore_changes hook, to
	// avoid updating them after creation. This is useful for fields that are
	// required on creation, but we do not desire to update them after creation,
	// for example because of an external controller is managing them, like an
	// autoscaler.
	InitProvider PrivatedatabaseDatabaseInitParameters `json:"initProvider,omitempty"`
}

PrivatedatabaseDatabaseSpec defines the desired state of PrivatedatabaseDatabase

func (*PrivatedatabaseDatabaseSpec) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseDatabaseSpec.

func (*PrivatedatabaseDatabaseSpec) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type PrivatedatabaseDatabaseStatus

type PrivatedatabaseDatabaseStatus struct {
	v1.ResourceStatus `json:",inline"`
	AtProvider        PrivatedatabaseDatabaseObservation `json:"atProvider,omitempty"`
}

PrivatedatabaseDatabaseStatus defines the observed state of PrivatedatabaseDatabase.

func (*PrivatedatabaseDatabaseStatus) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseDatabaseStatus.

func (*PrivatedatabaseDatabaseStatus) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to