Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=hostingprivatedatabaseusergrant.crossplane.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type PrivatedatabaseUserGrant
- func (in *PrivatedatabaseUserGrant) DeepCopy() *PrivatedatabaseUserGrant
- func (in *PrivatedatabaseUserGrant) DeepCopyInto(out *PrivatedatabaseUserGrant)
- func (in *PrivatedatabaseUserGrant) DeepCopyObject() runtime.Object
- func (mg *PrivatedatabaseUserGrant) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *PrivatedatabaseUserGrant) GetConnectionDetailsMapping() map[string]string
- func (mg *PrivatedatabaseUserGrant) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *PrivatedatabaseUserGrant) GetID() string
- func (tr *PrivatedatabaseUserGrant) GetInitParameters() (map[string]any, error)
- func (mg *PrivatedatabaseUserGrant) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *PrivatedatabaseUserGrant) GetObservation() (map[string]any, error)
- func (tr *PrivatedatabaseUserGrant) GetParameters() (map[string]any, error)
- func (mg *PrivatedatabaseUserGrant) GetProviderConfigReference() *xpv1.Reference
- func (mg *PrivatedatabaseUserGrant) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *PrivatedatabaseUserGrant) GetTerraformResourceType() string
- func (tr *PrivatedatabaseUserGrant) GetTerraformSchemaVersion() int
- func (mg *PrivatedatabaseUserGrant) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *PrivatedatabaseUserGrant) LateInitialize(attrs []byte) (bool, error)
- func (mg *PrivatedatabaseUserGrant) SetConditions(c ...xpv1.Condition)
- func (mg *PrivatedatabaseUserGrant) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *PrivatedatabaseUserGrant) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *PrivatedatabaseUserGrant) SetObservation(obs map[string]any) error
- func (tr *PrivatedatabaseUserGrant) SetParameters(params map[string]any) error
- func (mg *PrivatedatabaseUserGrant) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *PrivatedatabaseUserGrant) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *PrivatedatabaseUserGrant) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type PrivatedatabaseUserGrantInitParameters
- type PrivatedatabaseUserGrantList
- func (in *PrivatedatabaseUserGrantList) DeepCopy() *PrivatedatabaseUserGrantList
- func (in *PrivatedatabaseUserGrantList) DeepCopyInto(out *PrivatedatabaseUserGrantList)
- func (in *PrivatedatabaseUserGrantList) DeepCopyObject() runtime.Object
- func (l *PrivatedatabaseUserGrantList) GetItems() []resource.Managed
- type PrivatedatabaseUserGrantObservation
- type PrivatedatabaseUserGrantParameters
- type PrivatedatabaseUserGrantSpec
- type PrivatedatabaseUserGrantStatus
Constants ¶
const ( CRDGroup = "hostingprivatedatabaseusergrant.crossplane.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( PrivatedatabaseUserGrant_Kind = "PrivatedatabaseUserGrant" PrivatedatabaseUserGrant_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: PrivatedatabaseUserGrant_Kind}.String() PrivatedatabaseUserGrant_KindAPIVersion = PrivatedatabaseUserGrant_Kind + "." + CRDGroupVersion.String() PrivatedatabaseUserGrant_GroupVersionKind = CRDGroupVersion.WithKind(PrivatedatabaseUserGrant_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type PrivatedatabaseUserGrant ¶
type PrivatedatabaseUserGrant struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.databaseName) || (has(self.initProvider) && has(self.initProvider.databaseName))",message="spec.forProvider.databaseName is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.grant) || (has(self.initProvider) && has(self.initProvider.grant))",message="spec.forProvider.grant is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.userName) || (has(self.initProvider) && has(self.initProvider.userName))",message="spec.forProvider.userName is a required parameter"
Spec PrivatedatabaseUserGrantSpec `json:"spec"`
Status PrivatedatabaseUserGrantStatus `json:"status,omitempty"`
}
PrivatedatabaseUserGrant is the Schema for the PrivatedatabaseUserGrants API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}
func (*PrivatedatabaseUserGrant) DeepCopy ¶
func (in *PrivatedatabaseUserGrant) DeepCopy() *PrivatedatabaseUserGrant
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseUserGrant.
func (*PrivatedatabaseUserGrant) DeepCopyInto ¶
func (in *PrivatedatabaseUserGrant) DeepCopyInto(out *PrivatedatabaseUserGrant)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PrivatedatabaseUserGrant) DeepCopyObject ¶
func (in *PrivatedatabaseUserGrant) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*PrivatedatabaseUserGrant) GetCondition ¶
func (mg *PrivatedatabaseUserGrant) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this PrivatedatabaseUserGrant.
func (*PrivatedatabaseUserGrant) GetConnectionDetailsMapping ¶
func (tr *PrivatedatabaseUserGrant) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this PrivatedatabaseUserGrant
func (*PrivatedatabaseUserGrant) GetDeletionPolicy ¶
func (mg *PrivatedatabaseUserGrant) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this PrivatedatabaseUserGrant.
func (*PrivatedatabaseUserGrant) GetID ¶
func (tr *PrivatedatabaseUserGrant) GetID() string
GetID returns ID of underlying Terraform resource of this PrivatedatabaseUserGrant
func (*PrivatedatabaseUserGrant) GetInitParameters ¶
func (tr *PrivatedatabaseUserGrant) GetInitParameters() (map[string]any, error)
GetInitParameters of this PrivatedatabaseUserGrant
func (*PrivatedatabaseUserGrant) GetManagementPolicies ¶
func (mg *PrivatedatabaseUserGrant) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this PrivatedatabaseUserGrant.
func (*PrivatedatabaseUserGrant) GetObservation ¶
func (tr *PrivatedatabaseUserGrant) GetObservation() (map[string]any, error)
GetObservation of this PrivatedatabaseUserGrant
func (*PrivatedatabaseUserGrant) GetParameters ¶
func (tr *PrivatedatabaseUserGrant) GetParameters() (map[string]any, error)
GetParameters of this PrivatedatabaseUserGrant
func (*PrivatedatabaseUserGrant) GetProviderConfigReference ¶
func (mg *PrivatedatabaseUserGrant) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this PrivatedatabaseUserGrant.
func (*PrivatedatabaseUserGrant) GetPublishConnectionDetailsTo ¶
func (mg *PrivatedatabaseUserGrant) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this PrivatedatabaseUserGrant.
func (*PrivatedatabaseUserGrant) GetTerraformResourceType ¶
func (mg *PrivatedatabaseUserGrant) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this PrivatedatabaseUserGrant
func (*PrivatedatabaseUserGrant) GetTerraformSchemaVersion ¶
func (tr *PrivatedatabaseUserGrant) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*PrivatedatabaseUserGrant) GetWriteConnectionSecretToReference ¶
func (mg *PrivatedatabaseUserGrant) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this PrivatedatabaseUserGrant.
func (*PrivatedatabaseUserGrant) LateInitialize ¶
func (tr *PrivatedatabaseUserGrant) LateInitialize(attrs []byte) (bool, error)
LateInitialize this PrivatedatabaseUserGrant using its observed tfState. returns True if there are any spec changes for the resource.
func (*PrivatedatabaseUserGrant) SetConditions ¶
func (mg *PrivatedatabaseUserGrant) SetConditions(c ...xpv1.Condition)
SetConditions of this PrivatedatabaseUserGrant.
func (*PrivatedatabaseUserGrant) SetDeletionPolicy ¶
func (mg *PrivatedatabaseUserGrant) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this PrivatedatabaseUserGrant.
func (*PrivatedatabaseUserGrant) SetManagementPolicies ¶
func (mg *PrivatedatabaseUserGrant) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this PrivatedatabaseUserGrant.
func (*PrivatedatabaseUserGrant) SetObservation ¶
func (tr *PrivatedatabaseUserGrant) SetObservation(obs map[string]any) error
SetObservation for this PrivatedatabaseUserGrant
func (*PrivatedatabaseUserGrant) SetParameters ¶
func (tr *PrivatedatabaseUserGrant) SetParameters(params map[string]any) error
SetParameters for this PrivatedatabaseUserGrant
func (*PrivatedatabaseUserGrant) SetProviderConfigReference ¶
func (mg *PrivatedatabaseUserGrant) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this PrivatedatabaseUserGrant.
func (*PrivatedatabaseUserGrant) SetPublishConnectionDetailsTo ¶
func (mg *PrivatedatabaseUserGrant) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this PrivatedatabaseUserGrant.
func (*PrivatedatabaseUserGrant) SetWriteConnectionSecretToReference ¶
func (mg *PrivatedatabaseUserGrant) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this PrivatedatabaseUserGrant.
type PrivatedatabaseUserGrantInitParameters ¶
type PrivatedatabaseUserGrantInitParameters struct {
// Database name where add grant
DatabaseName *string `json:"databaseName,omitempty" tf:"database_name,omitempty"`
// Database name where add grant
Grant *string `json:"grant,omitempty" tf:"grant,omitempty"`
// The internal name of your private database
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// User name used to connect on your databases
UserName *string `json:"userName,omitempty" tf:"user_name,omitempty"`
}
func (*PrivatedatabaseUserGrantInitParameters) DeepCopy ¶
func (in *PrivatedatabaseUserGrantInitParameters) DeepCopy() *PrivatedatabaseUserGrantInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseUserGrantInitParameters.
func (*PrivatedatabaseUserGrantInitParameters) DeepCopyInto ¶
func (in *PrivatedatabaseUserGrantInitParameters) DeepCopyInto(out *PrivatedatabaseUserGrantInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrivatedatabaseUserGrantList ¶
type PrivatedatabaseUserGrantList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []PrivatedatabaseUserGrant `json:"items"`
}
PrivatedatabaseUserGrantList contains a list of PrivatedatabaseUserGrants
func (*PrivatedatabaseUserGrantList) DeepCopy ¶
func (in *PrivatedatabaseUserGrantList) DeepCopy() *PrivatedatabaseUserGrantList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseUserGrantList.
func (*PrivatedatabaseUserGrantList) DeepCopyInto ¶
func (in *PrivatedatabaseUserGrantList) DeepCopyInto(out *PrivatedatabaseUserGrantList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PrivatedatabaseUserGrantList) DeepCopyObject ¶
func (in *PrivatedatabaseUserGrantList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*PrivatedatabaseUserGrantList) GetItems ¶
func (l *PrivatedatabaseUserGrantList) GetItems() []resource.Managed
GetItems of this PrivatedatabaseUserGrantList.
type PrivatedatabaseUserGrantObservation ¶
type PrivatedatabaseUserGrantObservation struct {
// Database name where add grant
DatabaseName *string `json:"databaseName,omitempty" tf:"database_name,omitempty"`
// Database name where add grant
Grant *string `json:"grant,omitempty" tf:"grant,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// The internal name of your private database
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// User name used to connect on your databases
UserName *string `json:"userName,omitempty" tf:"user_name,omitempty"`
}
func (*PrivatedatabaseUserGrantObservation) DeepCopy ¶
func (in *PrivatedatabaseUserGrantObservation) DeepCopy() *PrivatedatabaseUserGrantObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseUserGrantObservation.
func (*PrivatedatabaseUserGrantObservation) DeepCopyInto ¶
func (in *PrivatedatabaseUserGrantObservation) DeepCopyInto(out *PrivatedatabaseUserGrantObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrivatedatabaseUserGrantParameters ¶
type PrivatedatabaseUserGrantParameters struct {
// Database name where add grant
// +kubebuilder:validation:Optional
DatabaseName *string `json:"databaseName,omitempty" tf:"database_name,omitempty"`
// Database name where add grant
// +kubebuilder:validation:Optional
Grant *string `json:"grant,omitempty" tf:"grant,omitempty"`
// The internal name of your private database
// +kubebuilder:validation:Optional
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// User name used to connect on your databases
// +kubebuilder:validation:Optional
UserName *string `json:"userName,omitempty" tf:"user_name,omitempty"`
}
func (*PrivatedatabaseUserGrantParameters) DeepCopy ¶
func (in *PrivatedatabaseUserGrantParameters) DeepCopy() *PrivatedatabaseUserGrantParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseUserGrantParameters.
func (*PrivatedatabaseUserGrantParameters) DeepCopyInto ¶
func (in *PrivatedatabaseUserGrantParameters) DeepCopyInto(out *PrivatedatabaseUserGrantParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrivatedatabaseUserGrantSpec ¶
type PrivatedatabaseUserGrantSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider PrivatedatabaseUserGrantParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider PrivatedatabaseUserGrantInitParameters `json:"initProvider,omitempty"`
}
PrivatedatabaseUserGrantSpec defines the desired state of PrivatedatabaseUserGrant
func (*PrivatedatabaseUserGrantSpec) DeepCopy ¶
func (in *PrivatedatabaseUserGrantSpec) DeepCopy() *PrivatedatabaseUserGrantSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseUserGrantSpec.
func (*PrivatedatabaseUserGrantSpec) DeepCopyInto ¶
func (in *PrivatedatabaseUserGrantSpec) DeepCopyInto(out *PrivatedatabaseUserGrantSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrivatedatabaseUserGrantStatus ¶
type PrivatedatabaseUserGrantStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider PrivatedatabaseUserGrantObservation `json:"atProvider,omitempty"`
}
PrivatedatabaseUserGrantStatus defines the observed state of PrivatedatabaseUserGrant.
func (*PrivatedatabaseUserGrantStatus) DeepCopy ¶
func (in *PrivatedatabaseUserGrantStatus) DeepCopy() *PrivatedatabaseUserGrantStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseUserGrantStatus.
func (*PrivatedatabaseUserGrantStatus) DeepCopyInto ¶
func (in *PrivatedatabaseUserGrantStatus) DeepCopyInto(out *PrivatedatabaseUserGrantStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.