Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=hostingprivatedatabasewhitelist.crossplane.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type PrivatedatabaseWhitelist
- func (in *PrivatedatabaseWhitelist) DeepCopy() *PrivatedatabaseWhitelist
- func (in *PrivatedatabaseWhitelist) DeepCopyInto(out *PrivatedatabaseWhitelist)
- func (in *PrivatedatabaseWhitelist) DeepCopyObject() runtime.Object
- func (mg *PrivatedatabaseWhitelist) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *PrivatedatabaseWhitelist) GetConnectionDetailsMapping() map[string]string
- func (mg *PrivatedatabaseWhitelist) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *PrivatedatabaseWhitelist) GetID() string
- func (tr *PrivatedatabaseWhitelist) GetInitParameters() (map[string]any, error)
- func (mg *PrivatedatabaseWhitelist) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *PrivatedatabaseWhitelist) GetObservation() (map[string]any, error)
- func (tr *PrivatedatabaseWhitelist) GetParameters() (map[string]any, error)
- func (mg *PrivatedatabaseWhitelist) GetProviderConfigReference() *xpv1.Reference
- func (mg *PrivatedatabaseWhitelist) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *PrivatedatabaseWhitelist) GetTerraformResourceType() string
- func (tr *PrivatedatabaseWhitelist) GetTerraformSchemaVersion() int
- func (mg *PrivatedatabaseWhitelist) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *PrivatedatabaseWhitelist) LateInitialize(attrs []byte) (bool, error)
- func (mg *PrivatedatabaseWhitelist) SetConditions(c ...xpv1.Condition)
- func (mg *PrivatedatabaseWhitelist) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *PrivatedatabaseWhitelist) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *PrivatedatabaseWhitelist) SetObservation(obs map[string]any) error
- func (tr *PrivatedatabaseWhitelist) SetParameters(params map[string]any) error
- func (mg *PrivatedatabaseWhitelist) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *PrivatedatabaseWhitelist) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *PrivatedatabaseWhitelist) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type PrivatedatabaseWhitelistInitParameters
- type PrivatedatabaseWhitelistList
- func (in *PrivatedatabaseWhitelistList) DeepCopy() *PrivatedatabaseWhitelistList
- func (in *PrivatedatabaseWhitelistList) DeepCopyInto(out *PrivatedatabaseWhitelistList)
- func (in *PrivatedatabaseWhitelistList) DeepCopyObject() runtime.Object
- func (l *PrivatedatabaseWhitelistList) GetItems() []resource.Managed
- type PrivatedatabaseWhitelistObservation
- type PrivatedatabaseWhitelistParameters
- type PrivatedatabaseWhitelistSpec
- type PrivatedatabaseWhitelistStatus
Constants ¶
const ( CRDGroup = "hostingprivatedatabasewhitelist.crossplane.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( PrivatedatabaseWhitelist_Kind = "PrivatedatabaseWhitelist" PrivatedatabaseWhitelist_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: PrivatedatabaseWhitelist_Kind}.String() PrivatedatabaseWhitelist_KindAPIVersion = PrivatedatabaseWhitelist_Kind + "." + CRDGroupVersion.String() PrivatedatabaseWhitelist_GroupVersionKind = CRDGroupVersion.WithKind(PrivatedatabaseWhitelist_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type PrivatedatabaseWhitelist ¶
type PrivatedatabaseWhitelist struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.ip) || (has(self.initProvider) && has(self.initProvider.ip))",message="spec.forProvider.ip is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.name) || (has(self.initProvider) && has(self.initProvider.name))",message="spec.forProvider.name is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.service) || (has(self.initProvider) && has(self.initProvider.service))",message="spec.forProvider.service is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.sftp) || (has(self.initProvider) && has(self.initProvider.sftp))",message="spec.forProvider.sftp is a required parameter"
Spec PrivatedatabaseWhitelistSpec `json:"spec"`
Status PrivatedatabaseWhitelistStatus `json:"status,omitempty"`
}
PrivatedatabaseWhitelist is the Schema for the PrivatedatabaseWhitelists API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}
func (*PrivatedatabaseWhitelist) DeepCopy ¶
func (in *PrivatedatabaseWhitelist) DeepCopy() *PrivatedatabaseWhitelist
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseWhitelist.
func (*PrivatedatabaseWhitelist) DeepCopyInto ¶
func (in *PrivatedatabaseWhitelist) DeepCopyInto(out *PrivatedatabaseWhitelist)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PrivatedatabaseWhitelist) DeepCopyObject ¶
func (in *PrivatedatabaseWhitelist) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*PrivatedatabaseWhitelist) GetCondition ¶
func (mg *PrivatedatabaseWhitelist) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this PrivatedatabaseWhitelist.
func (*PrivatedatabaseWhitelist) GetConnectionDetailsMapping ¶
func (tr *PrivatedatabaseWhitelist) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this PrivatedatabaseWhitelist
func (*PrivatedatabaseWhitelist) GetDeletionPolicy ¶
func (mg *PrivatedatabaseWhitelist) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this PrivatedatabaseWhitelist.
func (*PrivatedatabaseWhitelist) GetID ¶
func (tr *PrivatedatabaseWhitelist) GetID() string
GetID returns ID of underlying Terraform resource of this PrivatedatabaseWhitelist
func (*PrivatedatabaseWhitelist) GetInitParameters ¶
func (tr *PrivatedatabaseWhitelist) GetInitParameters() (map[string]any, error)
GetInitParameters of this PrivatedatabaseWhitelist
func (*PrivatedatabaseWhitelist) GetManagementPolicies ¶
func (mg *PrivatedatabaseWhitelist) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this PrivatedatabaseWhitelist.
func (*PrivatedatabaseWhitelist) GetObservation ¶
func (tr *PrivatedatabaseWhitelist) GetObservation() (map[string]any, error)
GetObservation of this PrivatedatabaseWhitelist
func (*PrivatedatabaseWhitelist) GetParameters ¶
func (tr *PrivatedatabaseWhitelist) GetParameters() (map[string]any, error)
GetParameters of this PrivatedatabaseWhitelist
func (*PrivatedatabaseWhitelist) GetProviderConfigReference ¶
func (mg *PrivatedatabaseWhitelist) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this PrivatedatabaseWhitelist.
func (*PrivatedatabaseWhitelist) GetPublishConnectionDetailsTo ¶
func (mg *PrivatedatabaseWhitelist) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this PrivatedatabaseWhitelist.
func (*PrivatedatabaseWhitelist) GetTerraformResourceType ¶
func (mg *PrivatedatabaseWhitelist) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this PrivatedatabaseWhitelist
func (*PrivatedatabaseWhitelist) GetTerraformSchemaVersion ¶
func (tr *PrivatedatabaseWhitelist) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*PrivatedatabaseWhitelist) GetWriteConnectionSecretToReference ¶
func (mg *PrivatedatabaseWhitelist) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this PrivatedatabaseWhitelist.
func (*PrivatedatabaseWhitelist) LateInitialize ¶
func (tr *PrivatedatabaseWhitelist) LateInitialize(attrs []byte) (bool, error)
LateInitialize this PrivatedatabaseWhitelist using its observed tfState. returns True if there are any spec changes for the resource.
func (*PrivatedatabaseWhitelist) SetConditions ¶
func (mg *PrivatedatabaseWhitelist) SetConditions(c ...xpv1.Condition)
SetConditions of this PrivatedatabaseWhitelist.
func (*PrivatedatabaseWhitelist) SetDeletionPolicy ¶
func (mg *PrivatedatabaseWhitelist) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this PrivatedatabaseWhitelist.
func (*PrivatedatabaseWhitelist) SetManagementPolicies ¶
func (mg *PrivatedatabaseWhitelist) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this PrivatedatabaseWhitelist.
func (*PrivatedatabaseWhitelist) SetObservation ¶
func (tr *PrivatedatabaseWhitelist) SetObservation(obs map[string]any) error
SetObservation for this PrivatedatabaseWhitelist
func (*PrivatedatabaseWhitelist) SetParameters ¶
func (tr *PrivatedatabaseWhitelist) SetParameters(params map[string]any) error
SetParameters for this PrivatedatabaseWhitelist
func (*PrivatedatabaseWhitelist) SetProviderConfigReference ¶
func (mg *PrivatedatabaseWhitelist) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this PrivatedatabaseWhitelist.
func (*PrivatedatabaseWhitelist) SetPublishConnectionDetailsTo ¶
func (mg *PrivatedatabaseWhitelist) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this PrivatedatabaseWhitelist.
func (*PrivatedatabaseWhitelist) SetWriteConnectionSecretToReference ¶
func (mg *PrivatedatabaseWhitelist) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this PrivatedatabaseWhitelist.
type PrivatedatabaseWhitelistInitParameters ¶
type PrivatedatabaseWhitelistInitParameters struct {
// The whitelisted IP in your instance
IP *string `json:"ip,omitempty" tf:"ip,omitempty"`
// Custom name for your Whitelisted IP
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Authorize this IP to access service port
Service *bool `json:"service,omitempty" tf:"service,omitempty"`
// The internal name of your private database
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Authorize this IP to access SFTP port
Sftp *bool `json:"sftp,omitempty" tf:"sftp,omitempty"`
}
func (*PrivatedatabaseWhitelistInitParameters) DeepCopy ¶
func (in *PrivatedatabaseWhitelistInitParameters) DeepCopy() *PrivatedatabaseWhitelistInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseWhitelistInitParameters.
func (*PrivatedatabaseWhitelistInitParameters) DeepCopyInto ¶
func (in *PrivatedatabaseWhitelistInitParameters) DeepCopyInto(out *PrivatedatabaseWhitelistInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrivatedatabaseWhitelistList ¶
type PrivatedatabaseWhitelistList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []PrivatedatabaseWhitelist `json:"items"`
}
PrivatedatabaseWhitelistList contains a list of PrivatedatabaseWhitelists
func (*PrivatedatabaseWhitelistList) DeepCopy ¶
func (in *PrivatedatabaseWhitelistList) DeepCopy() *PrivatedatabaseWhitelistList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseWhitelistList.
func (*PrivatedatabaseWhitelistList) DeepCopyInto ¶
func (in *PrivatedatabaseWhitelistList) DeepCopyInto(out *PrivatedatabaseWhitelistList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PrivatedatabaseWhitelistList) DeepCopyObject ¶
func (in *PrivatedatabaseWhitelistList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*PrivatedatabaseWhitelistList) GetItems ¶
func (l *PrivatedatabaseWhitelistList) GetItems() []resource.Managed
GetItems of this PrivatedatabaseWhitelistList.
type PrivatedatabaseWhitelistObservation ¶
type PrivatedatabaseWhitelistObservation struct {
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// The whitelisted IP in your instance
IP *string `json:"ip,omitempty" tf:"ip,omitempty"`
// Custom name for your Whitelisted IP
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Authorize this IP to access service port
Service *bool `json:"service,omitempty" tf:"service,omitempty"`
// The internal name of your private database
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Authorize this IP to access SFTP port
Sftp *bool `json:"sftp,omitempty" tf:"sftp,omitempty"`
}
func (*PrivatedatabaseWhitelistObservation) DeepCopy ¶
func (in *PrivatedatabaseWhitelistObservation) DeepCopy() *PrivatedatabaseWhitelistObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseWhitelistObservation.
func (*PrivatedatabaseWhitelistObservation) DeepCopyInto ¶
func (in *PrivatedatabaseWhitelistObservation) DeepCopyInto(out *PrivatedatabaseWhitelistObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrivatedatabaseWhitelistParameters ¶
type PrivatedatabaseWhitelistParameters struct {
// The whitelisted IP in your instance
// +kubebuilder:validation:Optional
IP *string `json:"ip,omitempty" tf:"ip,omitempty"`
// Custom name for your Whitelisted IP
// +kubebuilder:validation:Optional
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Authorize this IP to access service port
// +kubebuilder:validation:Optional
Service *bool `json:"service,omitempty" tf:"service,omitempty"`
// The internal name of your private database
// +kubebuilder:validation:Optional
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Authorize this IP to access SFTP port
// +kubebuilder:validation:Optional
Sftp *bool `json:"sftp,omitempty" tf:"sftp,omitempty"`
}
func (*PrivatedatabaseWhitelistParameters) DeepCopy ¶
func (in *PrivatedatabaseWhitelistParameters) DeepCopy() *PrivatedatabaseWhitelistParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseWhitelistParameters.
func (*PrivatedatabaseWhitelistParameters) DeepCopyInto ¶
func (in *PrivatedatabaseWhitelistParameters) DeepCopyInto(out *PrivatedatabaseWhitelistParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrivatedatabaseWhitelistSpec ¶
type PrivatedatabaseWhitelistSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider PrivatedatabaseWhitelistParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider PrivatedatabaseWhitelistInitParameters `json:"initProvider,omitempty"`
}
PrivatedatabaseWhitelistSpec defines the desired state of PrivatedatabaseWhitelist
func (*PrivatedatabaseWhitelistSpec) DeepCopy ¶
func (in *PrivatedatabaseWhitelistSpec) DeepCopy() *PrivatedatabaseWhitelistSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseWhitelistSpec.
func (*PrivatedatabaseWhitelistSpec) DeepCopyInto ¶
func (in *PrivatedatabaseWhitelistSpec) DeepCopyInto(out *PrivatedatabaseWhitelistSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrivatedatabaseWhitelistStatus ¶
type PrivatedatabaseWhitelistStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider PrivatedatabaseWhitelistObservation `json:"atProvider,omitempty"`
}
PrivatedatabaseWhitelistStatus defines the observed state of PrivatedatabaseWhitelist.
func (*PrivatedatabaseWhitelistStatus) DeepCopy ¶
func (in *PrivatedatabaseWhitelistStatus) DeepCopy() *PrivatedatabaseWhitelistStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivatedatabaseWhitelistStatus.
func (*PrivatedatabaseWhitelistStatus) DeepCopyInto ¶
func (in *PrivatedatabaseWhitelistStatus) DeepCopyInto(out *PrivatedatabaseWhitelistStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.