Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=iploadbalancinghttpfrontend.crossplane.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type HTTPFrontend
- func (in *HTTPFrontend) DeepCopy() *HTTPFrontend
- func (in *HTTPFrontend) DeepCopyInto(out *HTTPFrontend)
- func (in *HTTPFrontend) DeepCopyObject() runtime.Object
- func (mg *HTTPFrontend) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *HTTPFrontend) GetConnectionDetailsMapping() map[string]string
- func (mg *HTTPFrontend) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *HTTPFrontend) GetID() string
- func (tr *HTTPFrontend) GetInitParameters() (map[string]any, error)
- func (mg *HTTPFrontend) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *HTTPFrontend) GetObservation() (map[string]any, error)
- func (tr *HTTPFrontend) GetParameters() (map[string]any, error)
- func (mg *HTTPFrontend) GetProviderConfigReference() *xpv1.Reference
- func (mg *HTTPFrontend) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *HTTPFrontend) GetTerraformResourceType() string
- func (tr *HTTPFrontend) GetTerraformSchemaVersion() int
- func (mg *HTTPFrontend) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *HTTPFrontend) LateInitialize(attrs []byte) (bool, error)
- func (mg *HTTPFrontend) SetConditions(c ...xpv1.Condition)
- func (mg *HTTPFrontend) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *HTTPFrontend) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *HTTPFrontend) SetObservation(obs map[string]any) error
- func (tr *HTTPFrontend) SetParameters(params map[string]any) error
- func (mg *HTTPFrontend) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *HTTPFrontend) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *HTTPFrontend) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type HTTPFrontendInitParameters
- type HTTPFrontendList
- type HTTPFrontendObservation
- type HTTPFrontendParameters
- type HTTPFrontendSpec
- type HTTPFrontendStatus
Constants ¶
const ( CRDGroup = "iploadbalancinghttpfrontend.crossplane.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( HTTPFrontend_Kind = "HTTPFrontend" HTTPFrontend_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: HTTPFrontend_Kind}.String() HTTPFrontend_KindAPIVersion = HTTPFrontend_Kind + "." + CRDGroupVersion.String() HTTPFrontend_GroupVersionKind = CRDGroupVersion.WithKind(HTTPFrontend_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type HTTPFrontend ¶
type HTTPFrontend struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.port) || (has(self.initProvider) && has(self.initProvider.port))",message="spec.forProvider.port is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.zone) || (has(self.initProvider) && has(self.initProvider.zone))",message="spec.forProvider.zone is a required parameter"
Spec HTTPFrontendSpec `json:"spec"`
Status HTTPFrontendStatus `json:"status,omitempty"`
}
HTTPFrontend is the Schema for the HTTPFrontends API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}
func (*HTTPFrontend) DeepCopy ¶
func (in *HTTPFrontend) DeepCopy() *HTTPFrontend
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPFrontend.
func (*HTTPFrontend) DeepCopyInto ¶
func (in *HTTPFrontend) DeepCopyInto(out *HTTPFrontend)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*HTTPFrontend) DeepCopyObject ¶
func (in *HTTPFrontend) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*HTTPFrontend) GetCondition ¶
func (mg *HTTPFrontend) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this HTTPFrontend.
func (*HTTPFrontend) GetConnectionDetailsMapping ¶
func (tr *HTTPFrontend) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this HTTPFrontend
func (*HTTPFrontend) GetDeletionPolicy ¶
func (mg *HTTPFrontend) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this HTTPFrontend.
func (*HTTPFrontend) GetID ¶
func (tr *HTTPFrontend) GetID() string
GetID returns ID of underlying Terraform resource of this HTTPFrontend
func (*HTTPFrontend) GetInitParameters ¶
func (tr *HTTPFrontend) GetInitParameters() (map[string]any, error)
GetInitParameters of this HTTPFrontend
func (*HTTPFrontend) GetManagementPolicies ¶
func (mg *HTTPFrontend) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this HTTPFrontend.
func (*HTTPFrontend) GetObservation ¶
func (tr *HTTPFrontend) GetObservation() (map[string]any, error)
GetObservation of this HTTPFrontend
func (*HTTPFrontend) GetParameters ¶
func (tr *HTTPFrontend) GetParameters() (map[string]any, error)
GetParameters of this HTTPFrontend
func (*HTTPFrontend) GetProviderConfigReference ¶
func (mg *HTTPFrontend) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this HTTPFrontend.
func (*HTTPFrontend) GetPublishConnectionDetailsTo ¶
func (mg *HTTPFrontend) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this HTTPFrontend.
func (*HTTPFrontend) GetTerraformResourceType ¶
func (mg *HTTPFrontend) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this HTTPFrontend
func (*HTTPFrontend) GetTerraformSchemaVersion ¶
func (tr *HTTPFrontend) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*HTTPFrontend) GetWriteConnectionSecretToReference ¶
func (mg *HTTPFrontend) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this HTTPFrontend.
func (*HTTPFrontend) LateInitialize ¶
func (tr *HTTPFrontend) LateInitialize(attrs []byte) (bool, error)
LateInitialize this HTTPFrontend using its observed tfState. returns True if there are any spec changes for the resource.
func (*HTTPFrontend) SetConditions ¶
func (mg *HTTPFrontend) SetConditions(c ...xpv1.Condition)
SetConditions of this HTTPFrontend.
func (*HTTPFrontend) SetDeletionPolicy ¶
func (mg *HTTPFrontend) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this HTTPFrontend.
func (*HTTPFrontend) SetManagementPolicies ¶
func (mg *HTTPFrontend) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this HTTPFrontend.
func (*HTTPFrontend) SetObservation ¶
func (tr *HTTPFrontend) SetObservation(obs map[string]any) error
SetObservation for this HTTPFrontend
func (*HTTPFrontend) SetParameters ¶
func (tr *HTTPFrontend) SetParameters(params map[string]any) error
SetParameters for this HTTPFrontend
func (*HTTPFrontend) SetProviderConfigReference ¶
func (mg *HTTPFrontend) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this HTTPFrontend.
func (*HTTPFrontend) SetPublishConnectionDetailsTo ¶
func (mg *HTTPFrontend) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this HTTPFrontend.
func (*HTTPFrontend) SetWriteConnectionSecretToReference ¶
func (mg *HTTPFrontend) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this HTTPFrontend.
type HTTPFrontendInitParameters ¶
type HTTPFrontendInitParameters struct {
AllowedSource []*string `json:"allowedSource,omitempty" tf:"allowed_source,omitempty"`
DedicatedIpfo []*string `json:"dedicatedIpfo,omitempty" tf:"dedicated_ipfo,omitempty"`
DefaultFarmID *float64 `json:"defaultFarmId,omitempty" tf:"default_farm_id,omitempty"`
DefaultSSLID *float64 `json:"defaultSslId,omitempty" tf:"default_ssl_id,omitempty"`
Disabled *bool `json:"disabled,omitempty" tf:"disabled,omitempty"`
DisplayName *string `json:"displayName,omitempty" tf:"display_name,omitempty"`
HTTPHeader []*string `json:"httpHeader,omitempty" tf:"http_header,omitempty"`
Hsts *bool `json:"hsts,omitempty" tf:"hsts,omitempty"`
Port *string `json:"port,omitempty" tf:"port,omitempty"`
RedirectLocation *string `json:"redirectLocation,omitempty" tf:"redirect_location,omitempty"`
SSL *bool `json:"ssl,omitempty" tf:"ssl,omitempty"`
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
Zone *string `json:"zone,omitempty" tf:"zone,omitempty"`
}
func (*HTTPFrontendInitParameters) DeepCopy ¶
func (in *HTTPFrontendInitParameters) DeepCopy() *HTTPFrontendInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPFrontendInitParameters.
func (*HTTPFrontendInitParameters) DeepCopyInto ¶
func (in *HTTPFrontendInitParameters) DeepCopyInto(out *HTTPFrontendInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type HTTPFrontendList ¶
type HTTPFrontendList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []HTTPFrontend `json:"items"`
}
HTTPFrontendList contains a list of HTTPFrontends
func (*HTTPFrontendList) DeepCopy ¶
func (in *HTTPFrontendList) DeepCopy() *HTTPFrontendList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPFrontendList.
func (*HTTPFrontendList) DeepCopyInto ¶
func (in *HTTPFrontendList) DeepCopyInto(out *HTTPFrontendList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*HTTPFrontendList) DeepCopyObject ¶
func (in *HTTPFrontendList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*HTTPFrontendList) GetItems ¶
func (l *HTTPFrontendList) GetItems() []resource.Managed
GetItems of this HTTPFrontendList.
type HTTPFrontendObservation ¶
type HTTPFrontendObservation struct {
AllowedSource []*string `json:"allowedSource,omitempty" tf:"allowed_source,omitempty"`
DedicatedIpfo []*string `json:"dedicatedIpfo,omitempty" tf:"dedicated_ipfo,omitempty"`
DefaultFarmID *float64 `json:"defaultFarmId,omitempty" tf:"default_farm_id,omitempty"`
DefaultSSLID *float64 `json:"defaultSslId,omitempty" tf:"default_ssl_id,omitempty"`
Disabled *bool `json:"disabled,omitempty" tf:"disabled,omitempty"`
DisplayName *string `json:"displayName,omitempty" tf:"display_name,omitempty"`
HTTPHeader []*string `json:"httpHeader,omitempty" tf:"http_header,omitempty"`
Hsts *bool `json:"hsts,omitempty" tf:"hsts,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
Port *string `json:"port,omitempty" tf:"port,omitempty"`
RedirectLocation *string `json:"redirectLocation,omitempty" tf:"redirect_location,omitempty"`
SSL *bool `json:"ssl,omitempty" tf:"ssl,omitempty"`
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
Zone *string `json:"zone,omitempty" tf:"zone,omitempty"`
}
func (*HTTPFrontendObservation) DeepCopy ¶
func (in *HTTPFrontendObservation) DeepCopy() *HTTPFrontendObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPFrontendObservation.
func (*HTTPFrontendObservation) DeepCopyInto ¶
func (in *HTTPFrontendObservation) DeepCopyInto(out *HTTPFrontendObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type HTTPFrontendParameters ¶
type HTTPFrontendParameters struct {
// +kubebuilder:validation:Optional
AllowedSource []*string `json:"allowedSource,omitempty" tf:"allowed_source,omitempty"`
// +kubebuilder:validation:Optional
DedicatedIpfo []*string `json:"dedicatedIpfo,omitempty" tf:"dedicated_ipfo,omitempty"`
// +kubebuilder:validation:Optional
DefaultFarmID *float64 `json:"defaultFarmId,omitempty" tf:"default_farm_id,omitempty"`
// +kubebuilder:validation:Optional
DefaultSSLID *float64 `json:"defaultSslId,omitempty" tf:"default_ssl_id,omitempty"`
// +kubebuilder:validation:Optional
Disabled *bool `json:"disabled,omitempty" tf:"disabled,omitempty"`
// +kubebuilder:validation:Optional
DisplayName *string `json:"displayName,omitempty" tf:"display_name,omitempty"`
// +kubebuilder:validation:Optional
HTTPHeader []*string `json:"httpHeader,omitempty" tf:"http_header,omitempty"`
// +kubebuilder:validation:Optional
Hsts *bool `json:"hsts,omitempty" tf:"hsts,omitempty"`
// +kubebuilder:validation:Optional
Port *string `json:"port,omitempty" tf:"port,omitempty"`
// +kubebuilder:validation:Optional
RedirectLocation *string `json:"redirectLocation,omitempty" tf:"redirect_location,omitempty"`
// +kubebuilder:validation:Optional
SSL *bool `json:"ssl,omitempty" tf:"ssl,omitempty"`
// +kubebuilder:validation:Optional
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// +kubebuilder:validation:Optional
Zone *string `json:"zone,omitempty" tf:"zone,omitempty"`
}
func (*HTTPFrontendParameters) DeepCopy ¶
func (in *HTTPFrontendParameters) DeepCopy() *HTTPFrontendParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPFrontendParameters.
func (*HTTPFrontendParameters) DeepCopyInto ¶
func (in *HTTPFrontendParameters) DeepCopyInto(out *HTTPFrontendParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type HTTPFrontendSpec ¶
type HTTPFrontendSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider HTTPFrontendParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider HTTPFrontendInitParameters `json:"initProvider,omitempty"`
}
HTTPFrontendSpec defines the desired state of HTTPFrontend
func (*HTTPFrontendSpec) DeepCopy ¶
func (in *HTTPFrontendSpec) DeepCopy() *HTTPFrontendSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPFrontendSpec.
func (*HTTPFrontendSpec) DeepCopyInto ¶
func (in *HTTPFrontendSpec) DeepCopyInto(out *HTTPFrontendSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type HTTPFrontendStatus ¶
type HTTPFrontendStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider HTTPFrontendObservation `json:"atProvider,omitempty"`
}
HTTPFrontendStatus defines the observed state of HTTPFrontend.
func (*HTTPFrontendStatus) DeepCopy ¶
func (in *HTTPFrontendStatus) DeepCopy() *HTTPFrontendStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPFrontendStatus.
func (*HTTPFrontendStatus) DeepCopyInto ¶
func (in *HTTPFrontendStatus) DeepCopyInto(out *HTTPFrontendStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.