v1alpha1

package
v0.0.0-...-73c97c3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 17, 2024 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

+kubebuilder:object:generate=true +groupName=iploadbalancinghttproute.crossplane.io +versionName=v1alpha1

Index

Constants

const (
	CRDGroup   = "iploadbalancinghttproute.crossplane.io"
	CRDVersion = "v1alpha1"
)

Package type metadata.

Variables

var (
	// CRDGroupVersion is the API Group Version used to register the objects
	CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)
var (
	HTTPRoute_Kind             = "HTTPRoute"
	HTTPRoute_GroupKind        = schema.GroupKind{Group: CRDGroup, Kind: HTTPRoute_Kind}.String()
	HTTPRoute_KindAPIVersion   = HTTPRoute_Kind + "." + CRDGroupVersion.String()
	HTTPRoute_GroupVersionKind = CRDGroupVersion.WithKind(HTTPRoute_Kind)
)

Repository type metadata.

Functions

This section is empty.

Types

type ActionInitParameters

type ActionInitParameters struct {

	// HTTP status code for "redirect" and "reject" actions
	Status *float64 `json:"status,omitempty" tf:"status,omitempty"`

	// Farm ID for "farm" action type or URL template for "redirect" action. You may use ${uri}, ${protocol}, ${host}, ${port} and ${path} variables in redirect target
	Target *string `json:"target,omitempty" tf:"target,omitempty"`

	// Action to trigger if all the rules of this route matches
	Type *string `json:"type,omitempty" tf:"type,omitempty"`
}

func (*ActionInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ActionInitParameters.

func (*ActionInitParameters) DeepCopyInto

func (in *ActionInitParameters) DeepCopyInto(out *ActionInitParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ActionObservation

type ActionObservation struct {

	// HTTP status code for "redirect" and "reject" actions
	Status *float64 `json:"status,omitempty" tf:"status,omitempty"`

	// Farm ID for "farm" action type or URL template for "redirect" action. You may use ${uri}, ${protocol}, ${host}, ${port} and ${path} variables in redirect target
	Target *string `json:"target,omitempty" tf:"target,omitempty"`

	// Action to trigger if all the rules of this route matches
	Type *string `json:"type,omitempty" tf:"type,omitempty"`
}

func (*ActionObservation) DeepCopy

func (in *ActionObservation) DeepCopy() *ActionObservation

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ActionObservation.

func (*ActionObservation) DeepCopyInto

func (in *ActionObservation) DeepCopyInto(out *ActionObservation)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ActionParameters

type ActionParameters struct {

	// HTTP status code for "redirect" and "reject" actions
	// +kubebuilder:validation:Optional
	Status *float64 `json:"status,omitempty" tf:"status,omitempty"`

	// Farm ID for "farm" action type or URL template for "redirect" action. You may use ${uri}, ${protocol}, ${host}, ${port} and ${path} variables in redirect target
	// +kubebuilder:validation:Optional
	Target *string `json:"target,omitempty" tf:"target,omitempty"`

	// Action to trigger if all the rules of this route matches
	// +kubebuilder:validation:Optional
	Type *string `json:"type" tf:"type,omitempty"`
}

func (*ActionParameters) DeepCopy

func (in *ActionParameters) DeepCopy() *ActionParameters

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ActionParameters.

func (*ActionParameters) DeepCopyInto

func (in *ActionParameters) DeepCopyInto(out *ActionParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type HTTPRoute

type HTTPRoute struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.action) || (has(self.initProvider) && has(self.initProvider.action))",message="spec.forProvider.action is a required parameter"
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
	Spec   HTTPRouteSpec   `json:"spec"`
	Status HTTPRouteStatus `json:"status,omitempty"`
}

HTTPRoute is the Schema for the HTTPRoutes API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}

func (*HTTPRoute) DeepCopy

func (in *HTTPRoute) DeepCopy() *HTTPRoute

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPRoute.

func (*HTTPRoute) DeepCopyInto

func (in *HTTPRoute) DeepCopyInto(out *HTTPRoute)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*HTTPRoute) DeepCopyObject

func (in *HTTPRoute) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*HTTPRoute) GetCondition

func (mg *HTTPRoute) GetCondition(ct xpv1.ConditionType) xpv1.Condition

GetCondition of this HTTPRoute.

func (*HTTPRoute) GetConnectionDetailsMapping

func (tr *HTTPRoute) GetConnectionDetailsMapping() map[string]string

GetConnectionDetailsMapping for this HTTPRoute

func (*HTTPRoute) GetDeletionPolicy

func (mg *HTTPRoute) GetDeletionPolicy() xpv1.DeletionPolicy

GetDeletionPolicy of this HTTPRoute.

func (*HTTPRoute) GetID

func (tr *HTTPRoute) GetID() string

GetID returns ID of underlying Terraform resource of this HTTPRoute

func (*HTTPRoute) GetInitParameters

func (tr *HTTPRoute) GetInitParameters() (map[string]any, error)

GetInitParameters of this HTTPRoute

func (*HTTPRoute) GetManagementPolicies

func (mg *HTTPRoute) GetManagementPolicies() xpv1.ManagementPolicies

GetManagementPolicies of this HTTPRoute.

func (*HTTPRoute) GetObservation

func (tr *HTTPRoute) GetObservation() (map[string]any, error)

GetObservation of this HTTPRoute

func (*HTTPRoute) GetParameters

func (tr *HTTPRoute) GetParameters() (map[string]any, error)

GetParameters of this HTTPRoute

func (*HTTPRoute) GetProviderConfigReference

func (mg *HTTPRoute) GetProviderConfigReference() *xpv1.Reference

GetProviderConfigReference of this HTTPRoute.

func (*HTTPRoute) GetPublishConnectionDetailsTo

func (mg *HTTPRoute) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo

GetPublishConnectionDetailsTo of this HTTPRoute.

func (*HTTPRoute) GetTerraformResourceType

func (mg *HTTPRoute) GetTerraformResourceType() string

GetTerraformResourceType returns Terraform resource type for this HTTPRoute

func (*HTTPRoute) GetTerraformSchemaVersion

func (tr *HTTPRoute) GetTerraformSchemaVersion() int

GetTerraformSchemaVersion returns the associated Terraform schema version

func (*HTTPRoute) GetWriteConnectionSecretToReference

func (mg *HTTPRoute) GetWriteConnectionSecretToReference() *xpv1.SecretReference

GetWriteConnectionSecretToReference of this HTTPRoute.

func (*HTTPRoute) LateInitialize

func (tr *HTTPRoute) LateInitialize(attrs []byte) (bool, error)

LateInitialize this HTTPRoute using its observed tfState. returns True if there are any spec changes for the resource.

func (*HTTPRoute) SetConditions

func (mg *HTTPRoute) SetConditions(c ...xpv1.Condition)

SetConditions of this HTTPRoute.

func (*HTTPRoute) SetDeletionPolicy

func (mg *HTTPRoute) SetDeletionPolicy(r xpv1.DeletionPolicy)

SetDeletionPolicy of this HTTPRoute.

func (*HTTPRoute) SetManagementPolicies

func (mg *HTTPRoute) SetManagementPolicies(r xpv1.ManagementPolicies)

SetManagementPolicies of this HTTPRoute.

func (*HTTPRoute) SetObservation

func (tr *HTTPRoute) SetObservation(obs map[string]any) error

SetObservation for this HTTPRoute

func (*HTTPRoute) SetParameters

func (tr *HTTPRoute) SetParameters(params map[string]any) error

SetParameters for this HTTPRoute

func (*HTTPRoute) SetProviderConfigReference

func (mg *HTTPRoute) SetProviderConfigReference(r *xpv1.Reference)

SetProviderConfigReference of this HTTPRoute.

func (*HTTPRoute) SetPublishConnectionDetailsTo

func (mg *HTTPRoute) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)

SetPublishConnectionDetailsTo of this HTTPRoute.

func (*HTTPRoute) SetWriteConnectionSecretToReference

func (mg *HTTPRoute) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)

SetWriteConnectionSecretToReference of this HTTPRoute.

type HTTPRouteInitParameters

type HTTPRouteInitParameters struct {

	// Action triggered when all rules match
	Action []ActionInitParameters `json:"action,omitempty" tf:"action,omitempty"`

	// Human readable name for your route, this field is for you
	DisplayName *string `json:"displayName,omitempty" tf:"display_name,omitempty"`

	// Route traffic for this frontend
	FrontendID *float64 `json:"frontendId,omitempty" tf:"frontend_id,omitempty"`

	// The internal name of your IP load balancing
	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	// Route priority ([0..255]). 0 if null. Highest priority routes are evaluated last. Only the first matching route will trigger an action
	Weight *float64 `json:"weight,omitempty" tf:"weight,omitempty"`
}

func (*HTTPRouteInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPRouteInitParameters.

func (*HTTPRouteInitParameters) DeepCopyInto

func (in *HTTPRouteInitParameters) DeepCopyInto(out *HTTPRouteInitParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type HTTPRouteList

type HTTPRouteList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []HTTPRoute `json:"items"`
}

HTTPRouteList contains a list of HTTPRoutes

func (*HTTPRouteList) DeepCopy

func (in *HTTPRouteList) DeepCopy() *HTTPRouteList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPRouteList.

func (*HTTPRouteList) DeepCopyInto

func (in *HTTPRouteList) DeepCopyInto(out *HTTPRouteList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*HTTPRouteList) DeepCopyObject

func (in *HTTPRouteList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*HTTPRouteList) GetItems

func (l *HTTPRouteList) GetItems() []resource.Managed

GetItems of this HTTPRouteList.

type HTTPRouteObservation

type HTTPRouteObservation struct {

	// Action triggered when all rules match
	Action []ActionObservation `json:"action,omitempty" tf:"action,omitempty"`

	// Human readable name for your route, this field is for you
	DisplayName *string `json:"displayName,omitempty" tf:"display_name,omitempty"`

	// Route traffic for this frontend
	FrontendID *float64 `json:"frontendId,omitempty" tf:"frontend_id,omitempty"`

	ID *string `json:"id,omitempty" tf:"id,omitempty"`

	// List of rules to match to trigger action
	Rules []RulesObservation `json:"rules,omitempty" tf:"rules,omitempty"`

	// The internal name of your IP load balancing
	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	// Route status. Routes in "ok" state are ready to operate
	Status *string `json:"status,omitempty" tf:"status,omitempty"`

	// Route priority ([0..255]). 0 if null. Highest priority routes are evaluated last. Only the first matching route will trigger an action
	Weight *float64 `json:"weight,omitempty" tf:"weight,omitempty"`
}

func (*HTTPRouteObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPRouteObservation.

func (*HTTPRouteObservation) DeepCopyInto

func (in *HTTPRouteObservation) DeepCopyInto(out *HTTPRouteObservation)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type HTTPRouteParameters

type HTTPRouteParameters struct {

	// Action triggered when all rules match
	// +kubebuilder:validation:Optional
	Action []ActionParameters `json:"action,omitempty" tf:"action,omitempty"`

	// Human readable name for your route, this field is for you
	// +kubebuilder:validation:Optional
	DisplayName *string `json:"displayName,omitempty" tf:"display_name,omitempty"`

	// Route traffic for this frontend
	// +kubebuilder:validation:Optional
	FrontendID *float64 `json:"frontendId,omitempty" tf:"frontend_id,omitempty"`

	// The internal name of your IP load balancing
	// +kubebuilder:validation:Optional
	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	// Route priority ([0..255]). 0 if null. Highest priority routes are evaluated last. Only the first matching route will trigger an action
	// +kubebuilder:validation:Optional
	Weight *float64 `json:"weight,omitempty" tf:"weight,omitempty"`
}

func (*HTTPRouteParameters) DeepCopy

func (in *HTTPRouteParameters) DeepCopy() *HTTPRouteParameters

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPRouteParameters.

func (*HTTPRouteParameters) DeepCopyInto

func (in *HTTPRouteParameters) DeepCopyInto(out *HTTPRouteParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type HTTPRouteSpec

type HTTPRouteSpec struct {
	v1.ResourceSpec `json:",inline"`
	ForProvider     HTTPRouteParameters `json:"forProvider"`
	// THIS IS A BETA FIELD. It will be honored
	// unless the Management Policies feature flag is disabled.
	// InitProvider holds the same fields as ForProvider, with the exception
	// of Identifier and other resource reference fields. The fields that are
	// in InitProvider are merged into ForProvider when the resource is created.
	// The same fields are also added to the terraform ignore_changes hook, to
	// avoid updating them after creation. This is useful for fields that are
	// required on creation, but we do not desire to update them after creation,
	// for example because of an external controller is managing them, like an
	// autoscaler.
	InitProvider HTTPRouteInitParameters `json:"initProvider,omitempty"`
}

HTTPRouteSpec defines the desired state of HTTPRoute

func (*HTTPRouteSpec) DeepCopy

func (in *HTTPRouteSpec) DeepCopy() *HTTPRouteSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPRouteSpec.

func (*HTTPRouteSpec) DeepCopyInto

func (in *HTTPRouteSpec) DeepCopyInto(out *HTTPRouteSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type HTTPRouteStatus

type HTTPRouteStatus struct {
	v1.ResourceStatus `json:",inline"`
	AtProvider        HTTPRouteObservation `json:"atProvider,omitempty"`
}

HTTPRouteStatus defines the observed state of HTTPRoute.

func (*HTTPRouteStatus) DeepCopy

func (in *HTTPRouteStatus) DeepCopy() *HTTPRouteStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPRouteStatus.

func (*HTTPRouteStatus) DeepCopyInto

func (in *HTTPRouteStatus) DeepCopyInto(out *HTTPRouteStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type RulesInitParameters

type RulesInitParameters struct {
}

func (*RulesInitParameters) DeepCopy

func (in *RulesInitParameters) DeepCopy() *RulesInitParameters

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RulesInitParameters.

func (*RulesInitParameters) DeepCopyInto

func (in *RulesInitParameters) DeepCopyInto(out *RulesInitParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type RulesObservation

type RulesObservation struct {
	Field *string `json:"field,omitempty" tf:"field,omitempty"`

	Match *string `json:"match,omitempty" tf:"match,omitempty"`

	Negate *bool `json:"negate,omitempty" tf:"negate,omitempty"`

	Pattern *string `json:"pattern,omitempty" tf:"pattern,omitempty"`

	RuleID *float64 `json:"ruleId,omitempty" tf:"rule_id,omitempty"`

	SubField *string `json:"subField,omitempty" tf:"sub_field,omitempty"`
}

func (*RulesObservation) DeepCopy

func (in *RulesObservation) DeepCopy() *RulesObservation

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RulesObservation.

func (*RulesObservation) DeepCopyInto

func (in *RulesObservation) DeepCopyInto(out *RulesObservation)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type RulesParameters

type RulesParameters struct {
}

func (*RulesParameters) DeepCopy

func (in *RulesParameters) DeepCopy() *RulesParameters

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RulesParameters.

func (*RulesParameters) DeepCopyInto

func (in *RulesParameters) DeepCopyInto(out *RulesParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to