v1alpha1

package
v0.0.0-...-73c97c3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 17, 2024 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

+kubebuilder:object:generate=true +groupName=iploadbalancingtcpfarmserver.crossplane.io +versionName=v1alpha1

Index

Constants

const (
	CRDGroup   = "iploadbalancingtcpfarmserver.crossplane.io"
	CRDVersion = "v1alpha1"
)

Package type metadata.

Variables

var (
	// CRDGroupVersion is the API Group Version used to register the objects
	CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)
var (
	TCPFarmServer_Kind             = "TCPFarmServer"
	TCPFarmServer_GroupKind        = schema.GroupKind{Group: CRDGroup, Kind: TCPFarmServer_Kind}.String()
	TCPFarmServer_KindAPIVersion   = TCPFarmServer_Kind + "." + CRDGroupVersion.String()
	TCPFarmServer_GroupVersionKind = CRDGroupVersion.WithKind(TCPFarmServer_Kind)
)

Repository type metadata.

Functions

This section is empty.

Types

type TCPFarmServer

type TCPFarmServer struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.address) || (has(self.initProvider) && has(self.initProvider.address))",message="spec.forProvider.address is a required parameter"
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.farmId) || (has(self.initProvider) && has(self.initProvider.farmId))",message="spec.forProvider.farmId is a required parameter"
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.status) || (has(self.initProvider) && has(self.initProvider.status))",message="spec.forProvider.status is a required parameter"
	Spec   TCPFarmServerSpec   `json:"spec"`
	Status TCPFarmServerStatus `json:"status,omitempty"`
}

TCPFarmServer is the Schema for the TCPFarmServers API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}

func (*TCPFarmServer) DeepCopy

func (in *TCPFarmServer) DeepCopy() *TCPFarmServer

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPFarmServer.

func (*TCPFarmServer) DeepCopyInto

func (in *TCPFarmServer) DeepCopyInto(out *TCPFarmServer)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*TCPFarmServer) DeepCopyObject

func (in *TCPFarmServer) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*TCPFarmServer) GetCondition

func (mg *TCPFarmServer) GetCondition(ct xpv1.ConditionType) xpv1.Condition

GetCondition of this TCPFarmServer.

func (*TCPFarmServer) GetConnectionDetailsMapping

func (tr *TCPFarmServer) GetConnectionDetailsMapping() map[string]string

GetConnectionDetailsMapping for this TCPFarmServer

func (*TCPFarmServer) GetDeletionPolicy

func (mg *TCPFarmServer) GetDeletionPolicy() xpv1.DeletionPolicy

GetDeletionPolicy of this TCPFarmServer.

func (*TCPFarmServer) GetID

func (tr *TCPFarmServer) GetID() string

GetID returns ID of underlying Terraform resource of this TCPFarmServer

func (*TCPFarmServer) GetInitParameters

func (tr *TCPFarmServer) GetInitParameters() (map[string]any, error)

GetInitParameters of this TCPFarmServer

func (*TCPFarmServer) GetManagementPolicies

func (mg *TCPFarmServer) GetManagementPolicies() xpv1.ManagementPolicies

GetManagementPolicies of this TCPFarmServer.

func (*TCPFarmServer) GetObservation

func (tr *TCPFarmServer) GetObservation() (map[string]any, error)

GetObservation of this TCPFarmServer

func (*TCPFarmServer) GetParameters

func (tr *TCPFarmServer) GetParameters() (map[string]any, error)

GetParameters of this TCPFarmServer

func (*TCPFarmServer) GetProviderConfigReference

func (mg *TCPFarmServer) GetProviderConfigReference() *xpv1.Reference

GetProviderConfigReference of this TCPFarmServer.

func (*TCPFarmServer) GetPublishConnectionDetailsTo

func (mg *TCPFarmServer) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo

GetPublishConnectionDetailsTo of this TCPFarmServer.

func (*TCPFarmServer) GetTerraformResourceType

func (mg *TCPFarmServer) GetTerraformResourceType() string

GetTerraformResourceType returns Terraform resource type for this TCPFarmServer

func (*TCPFarmServer) GetTerraformSchemaVersion

func (tr *TCPFarmServer) GetTerraformSchemaVersion() int

GetTerraformSchemaVersion returns the associated Terraform schema version

func (*TCPFarmServer) GetWriteConnectionSecretToReference

func (mg *TCPFarmServer) GetWriteConnectionSecretToReference() *xpv1.SecretReference

GetWriteConnectionSecretToReference of this TCPFarmServer.

func (*TCPFarmServer) LateInitialize

func (tr *TCPFarmServer) LateInitialize(attrs []byte) (bool, error)

LateInitialize this TCPFarmServer using its observed tfState. returns True if there are any spec changes for the resource.

func (*TCPFarmServer) SetConditions

func (mg *TCPFarmServer) SetConditions(c ...xpv1.Condition)

SetConditions of this TCPFarmServer.

func (*TCPFarmServer) SetDeletionPolicy

func (mg *TCPFarmServer) SetDeletionPolicy(r xpv1.DeletionPolicy)

SetDeletionPolicy of this TCPFarmServer.

func (*TCPFarmServer) SetManagementPolicies

func (mg *TCPFarmServer) SetManagementPolicies(r xpv1.ManagementPolicies)

SetManagementPolicies of this TCPFarmServer.

func (*TCPFarmServer) SetObservation

func (tr *TCPFarmServer) SetObservation(obs map[string]any) error

SetObservation for this TCPFarmServer

func (*TCPFarmServer) SetParameters

func (tr *TCPFarmServer) SetParameters(params map[string]any) error

SetParameters for this TCPFarmServer

func (*TCPFarmServer) SetProviderConfigReference

func (mg *TCPFarmServer) SetProviderConfigReference(r *xpv1.Reference)

SetProviderConfigReference of this TCPFarmServer.

func (*TCPFarmServer) SetPublishConnectionDetailsTo

func (mg *TCPFarmServer) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)

SetPublishConnectionDetailsTo of this TCPFarmServer.

func (*TCPFarmServer) SetWriteConnectionSecretToReference

func (mg *TCPFarmServer) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)

SetWriteConnectionSecretToReference of this TCPFarmServer.

type TCPFarmServerInitParameters

type TCPFarmServerInitParameters struct {
	Address *string `json:"address,omitempty" tf:"address,omitempty"`

	Backup *bool `json:"backup,omitempty" tf:"backup,omitempty"`

	Chain *string `json:"chain,omitempty" tf:"chain,omitempty"`

	DisplayName *string `json:"displayName,omitempty" tf:"display_name,omitempty"`

	FarmID *float64 `json:"farmId,omitempty" tf:"farm_id,omitempty"`

	OnMarkedDown *string `json:"onMarkedDown,omitempty" tf:"on_marked_down,omitempty"`

	Port *float64 `json:"port,omitempty" tf:"port,omitempty"`

	Probe *bool `json:"probe,omitempty" tf:"probe,omitempty"`

	ProxyProtocolVersion *string `json:"proxyProtocolVersion,omitempty" tf:"proxy_protocol_version,omitempty"`

	SSL *bool `json:"ssl,omitempty" tf:"ssl,omitempty"`

	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	Status *string `json:"status,omitempty" tf:"status,omitempty"`

	Weight *float64 `json:"weight,omitempty" tf:"weight,omitempty"`
}

func (*TCPFarmServerInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPFarmServerInitParameters.

func (*TCPFarmServerInitParameters) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type TCPFarmServerList

type TCPFarmServerList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []TCPFarmServer `json:"items"`
}

TCPFarmServerList contains a list of TCPFarmServers

func (*TCPFarmServerList) DeepCopy

func (in *TCPFarmServerList) DeepCopy() *TCPFarmServerList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPFarmServerList.

func (*TCPFarmServerList) DeepCopyInto

func (in *TCPFarmServerList) DeepCopyInto(out *TCPFarmServerList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*TCPFarmServerList) DeepCopyObject

func (in *TCPFarmServerList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*TCPFarmServerList) GetItems

func (l *TCPFarmServerList) GetItems() []resource.Managed

GetItems of this TCPFarmServerList.

type TCPFarmServerObservation

type TCPFarmServerObservation struct {
	Address *string `json:"address,omitempty" tf:"address,omitempty"`

	Backup *bool `json:"backup,omitempty" tf:"backup,omitempty"`

	Chain *string `json:"chain,omitempty" tf:"chain,omitempty"`

	DisplayName *string `json:"displayName,omitempty" tf:"display_name,omitempty"`

	FarmID *float64 `json:"farmId,omitempty" tf:"farm_id,omitempty"`

	ID *string `json:"id,omitempty" tf:"id,omitempty"`

	OnMarkedDown *string `json:"onMarkedDown,omitempty" tf:"on_marked_down,omitempty"`

	Port *float64 `json:"port,omitempty" tf:"port,omitempty"`

	Probe *bool `json:"probe,omitempty" tf:"probe,omitempty"`

	ProxyProtocolVersion *string `json:"proxyProtocolVersion,omitempty" tf:"proxy_protocol_version,omitempty"`

	SSL *bool `json:"ssl,omitempty" tf:"ssl,omitempty"`

	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	Status *string `json:"status,omitempty" tf:"status,omitempty"`

	Weight *float64 `json:"weight,omitempty" tf:"weight,omitempty"`
}

func (*TCPFarmServerObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPFarmServerObservation.

func (*TCPFarmServerObservation) DeepCopyInto

func (in *TCPFarmServerObservation) DeepCopyInto(out *TCPFarmServerObservation)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type TCPFarmServerParameters

type TCPFarmServerParameters struct {

	// +kubebuilder:validation:Optional
	Address *string `json:"address,omitempty" tf:"address,omitempty"`

	// +kubebuilder:validation:Optional
	Backup *bool `json:"backup,omitempty" tf:"backup,omitempty"`

	// +kubebuilder:validation:Optional
	Chain *string `json:"chain,omitempty" tf:"chain,omitempty"`

	// +kubebuilder:validation:Optional
	DisplayName *string `json:"displayName,omitempty" tf:"display_name,omitempty"`

	// +kubebuilder:validation:Optional
	FarmID *float64 `json:"farmId,omitempty" tf:"farm_id,omitempty"`

	// +kubebuilder:validation:Optional
	OnMarkedDown *string `json:"onMarkedDown,omitempty" tf:"on_marked_down,omitempty"`

	// +kubebuilder:validation:Optional
	Port *float64 `json:"port,omitempty" tf:"port,omitempty"`

	// +kubebuilder:validation:Optional
	Probe *bool `json:"probe,omitempty" tf:"probe,omitempty"`

	// +kubebuilder:validation:Optional
	ProxyProtocolVersion *string `json:"proxyProtocolVersion,omitempty" tf:"proxy_protocol_version,omitempty"`

	// +kubebuilder:validation:Optional
	SSL *bool `json:"ssl,omitempty" tf:"ssl,omitempty"`

	// +kubebuilder:validation:Optional
	ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`

	// +kubebuilder:validation:Optional
	Status *string `json:"status,omitempty" tf:"status,omitempty"`

	// +kubebuilder:validation:Optional
	Weight *float64 `json:"weight,omitempty" tf:"weight,omitempty"`
}

func (*TCPFarmServerParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPFarmServerParameters.

func (*TCPFarmServerParameters) DeepCopyInto

func (in *TCPFarmServerParameters) DeepCopyInto(out *TCPFarmServerParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type TCPFarmServerSpec

type TCPFarmServerSpec struct {
	v1.ResourceSpec `json:",inline"`
	ForProvider     TCPFarmServerParameters `json:"forProvider"`
	// THIS IS A BETA FIELD. It will be honored
	// unless the Management Policies feature flag is disabled.
	// InitProvider holds the same fields as ForProvider, with the exception
	// of Identifier and other resource reference fields. The fields that are
	// in InitProvider are merged into ForProvider when the resource is created.
	// The same fields are also added to the terraform ignore_changes hook, to
	// avoid updating them after creation. This is useful for fields that are
	// required on creation, but we do not desire to update them after creation,
	// for example because of an external controller is managing them, like an
	// autoscaler.
	InitProvider TCPFarmServerInitParameters `json:"initProvider,omitempty"`
}

TCPFarmServerSpec defines the desired state of TCPFarmServer

func (*TCPFarmServerSpec) DeepCopy

func (in *TCPFarmServerSpec) DeepCopy() *TCPFarmServerSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPFarmServerSpec.

func (*TCPFarmServerSpec) DeepCopyInto

func (in *TCPFarmServerSpec) DeepCopyInto(out *TCPFarmServerSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type TCPFarmServerStatus

type TCPFarmServerStatus struct {
	v1.ResourceStatus `json:",inline"`
	AtProvider        TCPFarmServerObservation `json:"atProvider,omitempty"`
}

TCPFarmServerStatus defines the observed state of TCPFarmServer.

func (*TCPFarmServerStatus) DeepCopy

func (in *TCPFarmServerStatus) DeepCopy() *TCPFarmServerStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPFarmServerStatus.

func (*TCPFarmServerStatus) DeepCopyInto

func (in *TCPFarmServerStatus) DeepCopyInto(out *TCPFarmServerStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to