Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=iploadbalancingtcproute.crossplane.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type ActionInitParameters
- type ActionObservation
- type ActionParameters
- type RulesInitParameters
- type RulesObservation
- type RulesParameters
- type TCPRoute
- func (in *TCPRoute) DeepCopy() *TCPRoute
- func (in *TCPRoute) DeepCopyInto(out *TCPRoute)
- func (in *TCPRoute) DeepCopyObject() runtime.Object
- func (mg *TCPRoute) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *TCPRoute) GetConnectionDetailsMapping() map[string]string
- func (mg *TCPRoute) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *TCPRoute) GetID() string
- func (tr *TCPRoute) GetInitParameters() (map[string]any, error)
- func (mg *TCPRoute) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *TCPRoute) GetObservation() (map[string]any, error)
- func (tr *TCPRoute) GetParameters() (map[string]any, error)
- func (mg *TCPRoute) GetProviderConfigReference() *xpv1.Reference
- func (mg *TCPRoute) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *TCPRoute) GetTerraformResourceType() string
- func (tr *TCPRoute) GetTerraformSchemaVersion() int
- func (mg *TCPRoute) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *TCPRoute) LateInitialize(attrs []byte) (bool, error)
- func (mg *TCPRoute) SetConditions(c ...xpv1.Condition)
- func (mg *TCPRoute) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *TCPRoute) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *TCPRoute) SetObservation(obs map[string]any) error
- func (tr *TCPRoute) SetParameters(params map[string]any) error
- func (mg *TCPRoute) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *TCPRoute) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *TCPRoute) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type TCPRouteInitParameters
- type TCPRouteList
- type TCPRouteObservation
- type TCPRouteParameters
- type TCPRouteSpec
- type TCPRouteStatus
Constants ¶
const ( CRDGroup = "iploadbalancingtcproute.crossplane.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( TCPRoute_Kind = "TCPRoute" TCPRoute_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: TCPRoute_Kind}.String() TCPRoute_KindAPIVersion = TCPRoute_Kind + "." + CRDGroupVersion.String() TCPRoute_GroupVersionKind = CRDGroupVersion.WithKind(TCPRoute_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type ActionInitParameters ¶
type ActionInitParameters struct {
// Farm ID for "farm" action type, empty for others
Target *string `json:"target,omitempty" tf:"target,omitempty"`
// Action to trigger if all the rules of this route matches
Type *string `json:"type,omitempty" tf:"type,omitempty"`
}
func (*ActionInitParameters) DeepCopy ¶
func (in *ActionInitParameters) DeepCopy() *ActionInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ActionInitParameters.
func (*ActionInitParameters) DeepCopyInto ¶
func (in *ActionInitParameters) DeepCopyInto(out *ActionInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ActionObservation ¶
type ActionObservation struct {
// Farm ID for "farm" action type, empty for others
Target *string `json:"target,omitempty" tf:"target,omitempty"`
// Action to trigger if all the rules of this route matches
Type *string `json:"type,omitempty" tf:"type,omitempty"`
}
func (*ActionObservation) DeepCopy ¶
func (in *ActionObservation) DeepCopy() *ActionObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ActionObservation.
func (*ActionObservation) DeepCopyInto ¶
func (in *ActionObservation) DeepCopyInto(out *ActionObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ActionParameters ¶
type ActionParameters struct {
// Farm ID for "farm" action type, empty for others
// +kubebuilder:validation:Optional
Target *string `json:"target,omitempty" tf:"target,omitempty"`
// Action to trigger if all the rules of this route matches
// +kubebuilder:validation:Optional
Type *string `json:"type" tf:"type,omitempty"`
}
func (*ActionParameters) DeepCopy ¶
func (in *ActionParameters) DeepCopy() *ActionParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ActionParameters.
func (*ActionParameters) DeepCopyInto ¶
func (in *ActionParameters) DeepCopyInto(out *ActionParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RulesInitParameters ¶
type RulesInitParameters struct {
}
func (*RulesInitParameters) DeepCopy ¶
func (in *RulesInitParameters) DeepCopy() *RulesInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RulesInitParameters.
func (*RulesInitParameters) DeepCopyInto ¶
func (in *RulesInitParameters) DeepCopyInto(out *RulesInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RulesObservation ¶
type RulesObservation struct {
Field *string `json:"field,omitempty" tf:"field,omitempty"`
Match *string `json:"match,omitempty" tf:"match,omitempty"`
Negate *bool `json:"negate,omitempty" tf:"negate,omitempty"`
Pattern *string `json:"pattern,omitempty" tf:"pattern,omitempty"`
RuleID *float64 `json:"ruleId,omitempty" tf:"rule_id,omitempty"`
SubField *string `json:"subField,omitempty" tf:"sub_field,omitempty"`
}
func (*RulesObservation) DeepCopy ¶
func (in *RulesObservation) DeepCopy() *RulesObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RulesObservation.
func (*RulesObservation) DeepCopyInto ¶
func (in *RulesObservation) DeepCopyInto(out *RulesObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RulesParameters ¶
type RulesParameters struct {
}
func (*RulesParameters) DeepCopy ¶
func (in *RulesParameters) DeepCopy() *RulesParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RulesParameters.
func (*RulesParameters) DeepCopyInto ¶
func (in *RulesParameters) DeepCopyInto(out *RulesParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TCPRoute ¶
type TCPRoute struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.action) || (has(self.initProvider) && has(self.initProvider.action))",message="spec.forProvider.action is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
Spec TCPRouteSpec `json:"spec"`
Status TCPRouteStatus `json:"status,omitempty"`
}
TCPRoute is the Schema for the TCPRoutes API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}
func (*TCPRoute) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPRoute.
func (*TCPRoute) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TCPRoute) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*TCPRoute) GetCondition ¶
func (mg *TCPRoute) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this TCPRoute.
func (*TCPRoute) GetConnectionDetailsMapping ¶
GetConnectionDetailsMapping for this TCPRoute
func (*TCPRoute) GetDeletionPolicy ¶
func (mg *TCPRoute) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this TCPRoute.
func (*TCPRoute) GetInitParameters ¶
GetInitParameters of this TCPRoute
func (*TCPRoute) GetManagementPolicies ¶
func (mg *TCPRoute) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this TCPRoute.
func (*TCPRoute) GetObservation ¶
GetObservation of this TCPRoute
func (*TCPRoute) GetParameters ¶
GetParameters of this TCPRoute
func (*TCPRoute) GetProviderConfigReference ¶
GetProviderConfigReference of this TCPRoute.
func (*TCPRoute) GetPublishConnectionDetailsTo ¶
func (mg *TCPRoute) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this TCPRoute.
func (*TCPRoute) GetTerraformResourceType ¶
GetTerraformResourceType returns Terraform resource type for this TCPRoute
func (*TCPRoute) GetTerraformSchemaVersion ¶
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*TCPRoute) GetWriteConnectionSecretToReference ¶
func (mg *TCPRoute) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this TCPRoute.
func (*TCPRoute) LateInitialize ¶
LateInitialize this TCPRoute using its observed tfState. returns True if there are any spec changes for the resource.
func (*TCPRoute) SetConditions ¶
SetConditions of this TCPRoute.
func (*TCPRoute) SetDeletionPolicy ¶
func (mg *TCPRoute) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this TCPRoute.
func (*TCPRoute) SetManagementPolicies ¶
func (mg *TCPRoute) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this TCPRoute.
func (*TCPRoute) SetObservation ¶
SetObservation for this TCPRoute
func (*TCPRoute) SetParameters ¶
SetParameters for this TCPRoute
func (*TCPRoute) SetProviderConfigReference ¶
SetProviderConfigReference of this TCPRoute.
func (*TCPRoute) SetPublishConnectionDetailsTo ¶
func (mg *TCPRoute) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this TCPRoute.
func (*TCPRoute) SetWriteConnectionSecretToReference ¶
func (mg *TCPRoute) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this TCPRoute.
type TCPRouteInitParameters ¶
type TCPRouteInitParameters struct {
// Action triggered when all rules match
Action []ActionInitParameters `json:"action,omitempty" tf:"action,omitempty"`
// Human readable name for your route, this field is for you
DisplayName *string `json:"displayName,omitempty" tf:"display_name,omitempty"`
// Route traffic for this frontend
FrontendID *float64 `json:"frontendId,omitempty" tf:"frontend_id,omitempty"`
// The internal name of your IP load balancing
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Route priority ([0..255]). 0 if null. Highest priority routes are evaluated last. Only the first matching route will trigger an action
Weight *float64 `json:"weight,omitempty" tf:"weight,omitempty"`
}
func (*TCPRouteInitParameters) DeepCopy ¶
func (in *TCPRouteInitParameters) DeepCopy() *TCPRouteInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPRouteInitParameters.
func (*TCPRouteInitParameters) DeepCopyInto ¶
func (in *TCPRouteInitParameters) DeepCopyInto(out *TCPRouteInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TCPRouteList ¶
type TCPRouteList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []TCPRoute `json:"items"`
}
TCPRouteList contains a list of TCPRoutes
func (*TCPRouteList) DeepCopy ¶
func (in *TCPRouteList) DeepCopy() *TCPRouteList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPRouteList.
func (*TCPRouteList) DeepCopyInto ¶
func (in *TCPRouteList) DeepCopyInto(out *TCPRouteList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TCPRouteList) DeepCopyObject ¶
func (in *TCPRouteList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*TCPRouteList) GetItems ¶
func (l *TCPRouteList) GetItems() []resource.Managed
GetItems of this TCPRouteList.
type TCPRouteObservation ¶
type TCPRouteObservation struct {
// Action triggered when all rules match
Action []ActionObservation `json:"action,omitempty" tf:"action,omitempty"`
// Human readable name for your route, this field is for you
DisplayName *string `json:"displayName,omitempty" tf:"display_name,omitempty"`
// Route traffic for this frontend
FrontendID *float64 `json:"frontendId,omitempty" tf:"frontend_id,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// List of rules to match to trigger action
Rules []RulesObservation `json:"rules,omitempty" tf:"rules,omitempty"`
// The internal name of your IP load balancing
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Route status. Routes in "ok" state are ready to operate
Status *string `json:"status,omitempty" tf:"status,omitempty"`
// Route priority ([0..255]). 0 if null. Highest priority routes are evaluated last. Only the first matching route will trigger an action
Weight *float64 `json:"weight,omitempty" tf:"weight,omitempty"`
}
func (*TCPRouteObservation) DeepCopy ¶
func (in *TCPRouteObservation) DeepCopy() *TCPRouteObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPRouteObservation.
func (*TCPRouteObservation) DeepCopyInto ¶
func (in *TCPRouteObservation) DeepCopyInto(out *TCPRouteObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TCPRouteParameters ¶
type TCPRouteParameters struct {
// Action triggered when all rules match
// +kubebuilder:validation:Optional
Action []ActionParameters `json:"action,omitempty" tf:"action,omitempty"`
// Human readable name for your route, this field is for you
// +kubebuilder:validation:Optional
DisplayName *string `json:"displayName,omitempty" tf:"display_name,omitempty"`
// Route traffic for this frontend
// +kubebuilder:validation:Optional
FrontendID *float64 `json:"frontendId,omitempty" tf:"frontend_id,omitempty"`
// The internal name of your IP load balancing
// +kubebuilder:validation:Optional
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// Route priority ([0..255]). 0 if null. Highest priority routes are evaluated last. Only the first matching route will trigger an action
// +kubebuilder:validation:Optional
Weight *float64 `json:"weight,omitempty" tf:"weight,omitempty"`
}
func (*TCPRouteParameters) DeepCopy ¶
func (in *TCPRouteParameters) DeepCopy() *TCPRouteParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPRouteParameters.
func (*TCPRouteParameters) DeepCopyInto ¶
func (in *TCPRouteParameters) DeepCopyInto(out *TCPRouteParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TCPRouteSpec ¶
type TCPRouteSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider TCPRouteParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider TCPRouteInitParameters `json:"initProvider,omitempty"`
}
TCPRouteSpec defines the desired state of TCPRoute
func (*TCPRouteSpec) DeepCopy ¶
func (in *TCPRouteSpec) DeepCopy() *TCPRouteSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPRouteSpec.
func (*TCPRouteSpec) DeepCopyInto ¶
func (in *TCPRouteSpec) DeepCopyInto(out *TCPRouteSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TCPRouteStatus ¶
type TCPRouteStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider TCPRouteObservation `json:"atProvider,omitempty"`
}
TCPRouteStatus defines the observed state of TCPRoute.
func (*TCPRouteStatus) DeepCopy ¶
func (in *TCPRouteStatus) DeepCopy() *TCPRouteStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPRouteStatus.
func (*TCPRouteStatus) DeepCopyInto ¶
func (in *TCPRouteStatus) DeepCopyInto(out *TCPRouteStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.