Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=iploadbalancingtcprouterule.crossplane.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type TCPRouteRule
- func (in *TCPRouteRule) DeepCopy() *TCPRouteRule
- func (in *TCPRouteRule) DeepCopyInto(out *TCPRouteRule)
- func (in *TCPRouteRule) DeepCopyObject() runtime.Object
- func (mg *TCPRouteRule) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *TCPRouteRule) GetConnectionDetailsMapping() map[string]string
- func (mg *TCPRouteRule) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *TCPRouteRule) GetID() string
- func (tr *TCPRouteRule) GetInitParameters() (map[string]any, error)
- func (mg *TCPRouteRule) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *TCPRouteRule) GetObservation() (map[string]any, error)
- func (tr *TCPRouteRule) GetParameters() (map[string]any, error)
- func (mg *TCPRouteRule) GetProviderConfigReference() *xpv1.Reference
- func (mg *TCPRouteRule) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *TCPRouteRule) GetTerraformResourceType() string
- func (tr *TCPRouteRule) GetTerraformSchemaVersion() int
- func (mg *TCPRouteRule) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *TCPRouteRule) LateInitialize(attrs []byte) (bool, error)
- func (mg *TCPRouteRule) SetConditions(c ...xpv1.Condition)
- func (mg *TCPRouteRule) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *TCPRouteRule) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *TCPRouteRule) SetObservation(obs map[string]any) error
- func (tr *TCPRouteRule) SetParameters(params map[string]any) error
- func (mg *TCPRouteRule) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *TCPRouteRule) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *TCPRouteRule) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type TCPRouteRuleInitParameters
- type TCPRouteRuleList
- type TCPRouteRuleObservation
- type TCPRouteRuleParameters
- type TCPRouteRuleSpec
- type TCPRouteRuleStatus
Constants ¶
const ( CRDGroup = "iploadbalancingtcprouterule.crossplane.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( TCPRouteRule_Kind = "TCPRouteRule" TCPRouteRule_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: TCPRouteRule_Kind}.String() TCPRouteRule_KindAPIVersion = TCPRouteRule_Kind + "." + CRDGroupVersion.String() TCPRouteRule_GroupVersionKind = CRDGroupVersion.WithKind(TCPRouteRule_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type TCPRouteRule ¶
type TCPRouteRule struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.field) || (has(self.initProvider) && has(self.initProvider.field))",message="spec.forProvider.field is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.match) || (has(self.initProvider) && has(self.initProvider.match))",message="spec.forProvider.match is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.routeId) || (has(self.initProvider) && has(self.initProvider.routeId))",message="spec.forProvider.routeId is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.serviceName) || (has(self.initProvider) && has(self.initProvider.serviceName))",message="spec.forProvider.serviceName is a required parameter"
Spec TCPRouteRuleSpec `json:"spec"`
Status TCPRouteRuleStatus `json:"status,omitempty"`
}
TCPRouteRule is the Schema for the TCPRouteRules API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}
func (*TCPRouteRule) DeepCopy ¶
func (in *TCPRouteRule) DeepCopy() *TCPRouteRule
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPRouteRule.
func (*TCPRouteRule) DeepCopyInto ¶
func (in *TCPRouteRule) DeepCopyInto(out *TCPRouteRule)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TCPRouteRule) DeepCopyObject ¶
func (in *TCPRouteRule) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*TCPRouteRule) GetCondition ¶
func (mg *TCPRouteRule) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this TCPRouteRule.
func (*TCPRouteRule) GetConnectionDetailsMapping ¶
func (tr *TCPRouteRule) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this TCPRouteRule
func (*TCPRouteRule) GetDeletionPolicy ¶
func (mg *TCPRouteRule) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this TCPRouteRule.
func (*TCPRouteRule) GetID ¶
func (tr *TCPRouteRule) GetID() string
GetID returns ID of underlying Terraform resource of this TCPRouteRule
func (*TCPRouteRule) GetInitParameters ¶
func (tr *TCPRouteRule) GetInitParameters() (map[string]any, error)
GetInitParameters of this TCPRouteRule
func (*TCPRouteRule) GetManagementPolicies ¶
func (mg *TCPRouteRule) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this TCPRouteRule.
func (*TCPRouteRule) GetObservation ¶
func (tr *TCPRouteRule) GetObservation() (map[string]any, error)
GetObservation of this TCPRouteRule
func (*TCPRouteRule) GetParameters ¶
func (tr *TCPRouteRule) GetParameters() (map[string]any, error)
GetParameters of this TCPRouteRule
func (*TCPRouteRule) GetProviderConfigReference ¶
func (mg *TCPRouteRule) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this TCPRouteRule.
func (*TCPRouteRule) GetPublishConnectionDetailsTo ¶
func (mg *TCPRouteRule) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this TCPRouteRule.
func (*TCPRouteRule) GetTerraformResourceType ¶
func (mg *TCPRouteRule) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this TCPRouteRule
func (*TCPRouteRule) GetTerraformSchemaVersion ¶
func (tr *TCPRouteRule) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*TCPRouteRule) GetWriteConnectionSecretToReference ¶
func (mg *TCPRouteRule) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this TCPRouteRule.
func (*TCPRouteRule) LateInitialize ¶
func (tr *TCPRouteRule) LateInitialize(attrs []byte) (bool, error)
LateInitialize this TCPRouteRule using its observed tfState. returns True if there are any spec changes for the resource.
func (*TCPRouteRule) SetConditions ¶
func (mg *TCPRouteRule) SetConditions(c ...xpv1.Condition)
SetConditions of this TCPRouteRule.
func (*TCPRouteRule) SetDeletionPolicy ¶
func (mg *TCPRouteRule) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this TCPRouteRule.
func (*TCPRouteRule) SetManagementPolicies ¶
func (mg *TCPRouteRule) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this TCPRouteRule.
func (*TCPRouteRule) SetObservation ¶
func (tr *TCPRouteRule) SetObservation(obs map[string]any) error
SetObservation for this TCPRouteRule
func (*TCPRouteRule) SetParameters ¶
func (tr *TCPRouteRule) SetParameters(params map[string]any) error
SetParameters for this TCPRouteRule
func (*TCPRouteRule) SetProviderConfigReference ¶
func (mg *TCPRouteRule) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this TCPRouteRule.
func (*TCPRouteRule) SetPublishConnectionDetailsTo ¶
func (mg *TCPRouteRule) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this TCPRouteRule.
func (*TCPRouteRule) SetWriteConnectionSecretToReference ¶
func (mg *TCPRouteRule) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this TCPRouteRule.
type TCPRouteRuleInitParameters ¶
type TCPRouteRuleInitParameters struct {
DisplayName *string `json:"displayName,omitempty" tf:"display_name,omitempty"`
Field *string `json:"field,omitempty" tf:"field,omitempty"`
Match *string `json:"match,omitempty" tf:"match,omitempty"`
Negate *bool `json:"negate,omitempty" tf:"negate,omitempty"`
Pattern *string `json:"pattern,omitempty" tf:"pattern,omitempty"`
RouteID *string `json:"routeId,omitempty" tf:"route_id,omitempty"`
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
SubField *string `json:"subField,omitempty" tf:"sub_field,omitempty"`
}
func (*TCPRouteRuleInitParameters) DeepCopy ¶
func (in *TCPRouteRuleInitParameters) DeepCopy() *TCPRouteRuleInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPRouteRuleInitParameters.
func (*TCPRouteRuleInitParameters) DeepCopyInto ¶
func (in *TCPRouteRuleInitParameters) DeepCopyInto(out *TCPRouteRuleInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TCPRouteRuleList ¶
type TCPRouteRuleList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []TCPRouteRule `json:"items"`
}
TCPRouteRuleList contains a list of TCPRouteRules
func (*TCPRouteRuleList) DeepCopy ¶
func (in *TCPRouteRuleList) DeepCopy() *TCPRouteRuleList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPRouteRuleList.
func (*TCPRouteRuleList) DeepCopyInto ¶
func (in *TCPRouteRuleList) DeepCopyInto(out *TCPRouteRuleList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TCPRouteRuleList) DeepCopyObject ¶
func (in *TCPRouteRuleList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*TCPRouteRuleList) GetItems ¶
func (l *TCPRouteRuleList) GetItems() []resource.Managed
GetItems of this TCPRouteRuleList.
type TCPRouteRuleObservation ¶
type TCPRouteRuleObservation struct {
DisplayName *string `json:"displayName,omitempty" tf:"display_name,omitempty"`
Field *string `json:"field,omitempty" tf:"field,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
Match *string `json:"match,omitempty" tf:"match,omitempty"`
Negate *bool `json:"negate,omitempty" tf:"negate,omitempty"`
Pattern *string `json:"pattern,omitempty" tf:"pattern,omitempty"`
RouteID *string `json:"routeId,omitempty" tf:"route_id,omitempty"`
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
SubField *string `json:"subField,omitempty" tf:"sub_field,omitempty"`
}
func (*TCPRouteRuleObservation) DeepCopy ¶
func (in *TCPRouteRuleObservation) DeepCopy() *TCPRouteRuleObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPRouteRuleObservation.
func (*TCPRouteRuleObservation) DeepCopyInto ¶
func (in *TCPRouteRuleObservation) DeepCopyInto(out *TCPRouteRuleObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TCPRouteRuleParameters ¶
type TCPRouteRuleParameters struct {
// +kubebuilder:validation:Optional
DisplayName *string `json:"displayName,omitempty" tf:"display_name,omitempty"`
// +kubebuilder:validation:Optional
Field *string `json:"field,omitempty" tf:"field,omitempty"`
// +kubebuilder:validation:Optional
Match *string `json:"match,omitempty" tf:"match,omitempty"`
// +kubebuilder:validation:Optional
Negate *bool `json:"negate,omitempty" tf:"negate,omitempty"`
// +kubebuilder:validation:Optional
Pattern *string `json:"pattern,omitempty" tf:"pattern,omitempty"`
// +kubebuilder:validation:Optional
RouteID *string `json:"routeId,omitempty" tf:"route_id,omitempty"`
// +kubebuilder:validation:Optional
ServiceName *string `json:"serviceName,omitempty" tf:"service_name,omitempty"`
// +kubebuilder:validation:Optional
SubField *string `json:"subField,omitempty" tf:"sub_field,omitempty"`
}
func (*TCPRouteRuleParameters) DeepCopy ¶
func (in *TCPRouteRuleParameters) DeepCopy() *TCPRouteRuleParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPRouteRuleParameters.
func (*TCPRouteRuleParameters) DeepCopyInto ¶
func (in *TCPRouteRuleParameters) DeepCopyInto(out *TCPRouteRuleParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TCPRouteRuleSpec ¶
type TCPRouteRuleSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider TCPRouteRuleParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider TCPRouteRuleInitParameters `json:"initProvider,omitempty"`
}
TCPRouteRuleSpec defines the desired state of TCPRouteRule
func (*TCPRouteRuleSpec) DeepCopy ¶
func (in *TCPRouteRuleSpec) DeepCopy() *TCPRouteRuleSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPRouteRuleSpec.
func (*TCPRouteRuleSpec) DeepCopyInto ¶
func (in *TCPRouteRuleSpec) DeepCopyInto(out *TCPRouteRuleSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TCPRouteRuleStatus ¶
type TCPRouteRuleStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider TCPRouteRuleObservation `json:"atProvider,omitempty"`
}
TCPRouteRuleStatus defines the observed state of TCPRouteRule.
func (*TCPRouteRuleStatus) DeepCopy ¶
func (in *TCPRouteRuleStatus) DeepCopy() *TCPRouteRuleStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TCPRouteRuleStatus.
func (*TCPRouteRuleStatus) DeepCopyInto ¶
func (in *TCPRouteRuleStatus) DeepCopyInto(out *TCPRouteRuleStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.