Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=meinstallationtemplate.crossplane.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type CustomizationInitParameters
- type CustomizationObservation
- type CustomizationParameters
- type InstallationTemplate
- func (in *InstallationTemplate) DeepCopy() *InstallationTemplate
- func (in *InstallationTemplate) DeepCopyInto(out *InstallationTemplate)
- func (in *InstallationTemplate) DeepCopyObject() runtime.Object
- func (mg *InstallationTemplate) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *InstallationTemplate) GetConnectionDetailsMapping() map[string]string
- func (mg *InstallationTemplate) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *InstallationTemplate) GetID() string
- func (tr *InstallationTemplate) GetInitParameters() (map[string]any, error)
- func (mg *InstallationTemplate) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *InstallationTemplate) GetObservation() (map[string]any, error)
- func (tr *InstallationTemplate) GetParameters() (map[string]any, error)
- func (mg *InstallationTemplate) GetProviderConfigReference() *xpv1.Reference
- func (mg *InstallationTemplate) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *InstallationTemplate) GetTerraformResourceType() string
- func (tr *InstallationTemplate) GetTerraformSchemaVersion() int
- func (mg *InstallationTemplate) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *InstallationTemplate) LateInitialize(attrs []byte) (bool, error)
- func (mg *InstallationTemplate) SetConditions(c ...xpv1.Condition)
- func (mg *InstallationTemplate) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *InstallationTemplate) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *InstallationTemplate) SetObservation(obs map[string]any) error
- func (tr *InstallationTemplate) SetParameters(params map[string]any) error
- func (mg *InstallationTemplate) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *InstallationTemplate) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *InstallationTemplate) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type InstallationTemplateInitParameters
- type InstallationTemplateList
- type InstallationTemplateObservation
- type InstallationTemplateParameters
- type InstallationTemplateSpec
- type InstallationTemplateStatus
Constants ¶
const ( CRDGroup = "meinstallationtemplate.crossplane.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( InstallationTemplate_Kind = "InstallationTemplate" InstallationTemplate_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: InstallationTemplate_Kind}.String() InstallationTemplate_KindAPIVersion = InstallationTemplate_Kind + "." + CRDGroupVersion.String() InstallationTemplate_GroupVersionKind = CRDGroupVersion.WithKind(InstallationTemplate_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type CustomizationInitParameters ¶
type CustomizationInitParameters struct {
// Template change log details
ChangeLog *string `json:"changeLog,omitempty" tf:"change_log,omitempty"`
// Set up the server using the provided hostname instead of the default hostname
CustomHostname *string `json:"customHostname,omitempty" tf:"custom_hostname,omitempty"`
// Indicate the URL where your postinstall customisation script is located
PostInstallationScriptLink *string `json:"postInstallationScriptLink,omitempty" tf:"post_installation_script_link,omitempty"`
// indicate the string returned by your postinstall customisation script on successful execution. Advice: your script should return a unique validation string in case of succes. A good example is 'loh1Xee7eo OK OK OK UGh8Ang1Gu'
PostInstallationScriptReturn *string `json:"postInstallationScriptReturn,omitempty" tf:"post_installation_script_return,omitempty"`
Rating *float64 `json:"rating,omitempty" tf:"rating,omitempty"`
// Name of the ssh key that should be installed. Password login will be disabled
SSHKeyName *string `json:"sshKeyName,omitempty" tf:"ssh_key_name,omitempty"`
// Use the distribution's native kernel instead of the recommended OVH Kernel
UseDistributionKernel *bool `json:"useDistributionKernel,omitempty" tf:"use_distribution_kernel,omitempty"`
}
func (*CustomizationInitParameters) DeepCopy ¶
func (in *CustomizationInitParameters) DeepCopy() *CustomizationInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomizationInitParameters.
func (*CustomizationInitParameters) DeepCopyInto ¶
func (in *CustomizationInitParameters) DeepCopyInto(out *CustomizationInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CustomizationObservation ¶
type CustomizationObservation struct {
// Template change log details
ChangeLog *string `json:"changeLog,omitempty" tf:"change_log,omitempty"`
// Set up the server using the provided hostname instead of the default hostname
CustomHostname *string `json:"customHostname,omitempty" tf:"custom_hostname,omitempty"`
// Indicate the URL where your postinstall customisation script is located
PostInstallationScriptLink *string `json:"postInstallationScriptLink,omitempty" tf:"post_installation_script_link,omitempty"`
// indicate the string returned by your postinstall customisation script on successful execution. Advice: your script should return a unique validation string in case of succes. A good example is 'loh1Xee7eo OK OK OK UGh8Ang1Gu'
PostInstallationScriptReturn *string `json:"postInstallationScriptReturn,omitempty" tf:"post_installation_script_return,omitempty"`
Rating *float64 `json:"rating,omitempty" tf:"rating,omitempty"`
// Name of the ssh key that should be installed. Password login will be disabled
SSHKeyName *string `json:"sshKeyName,omitempty" tf:"ssh_key_name,omitempty"`
// Use the distribution's native kernel instead of the recommended OVH Kernel
UseDistributionKernel *bool `json:"useDistributionKernel,omitempty" tf:"use_distribution_kernel,omitempty"`
}
func (*CustomizationObservation) DeepCopy ¶
func (in *CustomizationObservation) DeepCopy() *CustomizationObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomizationObservation.
func (*CustomizationObservation) DeepCopyInto ¶
func (in *CustomizationObservation) DeepCopyInto(out *CustomizationObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CustomizationParameters ¶
type CustomizationParameters struct {
// Template change log details
// +kubebuilder:validation:Optional
ChangeLog *string `json:"changeLog,omitempty" tf:"change_log,omitempty"`
// Set up the server using the provided hostname instead of the default hostname
// +kubebuilder:validation:Optional
CustomHostname *string `json:"customHostname,omitempty" tf:"custom_hostname,omitempty"`
// Indicate the URL where your postinstall customisation script is located
// +kubebuilder:validation:Optional
PostInstallationScriptLink *string `json:"postInstallationScriptLink,omitempty" tf:"post_installation_script_link,omitempty"`
// indicate the string returned by your postinstall customisation script on successful execution. Advice: your script should return a unique validation string in case of succes. A good example is 'loh1Xee7eo OK OK OK UGh8Ang1Gu'
// +kubebuilder:validation:Optional
PostInstallationScriptReturn *string `json:"postInstallationScriptReturn,omitempty" tf:"post_installation_script_return,omitempty"`
// +kubebuilder:validation:Optional
Rating *float64 `json:"rating,omitempty" tf:"rating,omitempty"`
// Name of the ssh key that should be installed. Password login will be disabled
// +kubebuilder:validation:Optional
SSHKeyName *string `json:"sshKeyName,omitempty" tf:"ssh_key_name,omitempty"`
// Use the distribution's native kernel instead of the recommended OVH Kernel
// +kubebuilder:validation:Optional
UseDistributionKernel *bool `json:"useDistributionKernel,omitempty" tf:"use_distribution_kernel,omitempty"`
}
func (*CustomizationParameters) DeepCopy ¶
func (in *CustomizationParameters) DeepCopy() *CustomizationParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomizationParameters.
func (*CustomizationParameters) DeepCopyInto ¶
func (in *CustomizationParameters) DeepCopyInto(out *CustomizationParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type InstallationTemplate ¶
type InstallationTemplate struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.baseTemplateName) || (has(self.initProvider) && has(self.initProvider.baseTemplateName))",message="spec.forProvider.baseTemplateName is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.defaultLanguage) || (has(self.initProvider) && has(self.initProvider.defaultLanguage))",message="spec.forProvider.defaultLanguage is a required parameter"
Spec InstallationTemplateSpec `json:"spec"`
Status InstallationTemplateStatus `json:"status,omitempty"`
}
InstallationTemplate is the Schema for the InstallationTemplates API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}
func (*InstallationTemplate) DeepCopy ¶
func (in *InstallationTemplate) DeepCopy() *InstallationTemplate
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InstallationTemplate.
func (*InstallationTemplate) DeepCopyInto ¶
func (in *InstallationTemplate) DeepCopyInto(out *InstallationTemplate)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*InstallationTemplate) DeepCopyObject ¶
func (in *InstallationTemplate) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*InstallationTemplate) GetCondition ¶
func (mg *InstallationTemplate) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this InstallationTemplate.
func (*InstallationTemplate) GetConnectionDetailsMapping ¶
func (tr *InstallationTemplate) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this InstallationTemplate
func (*InstallationTemplate) GetDeletionPolicy ¶
func (mg *InstallationTemplate) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this InstallationTemplate.
func (*InstallationTemplate) GetID ¶
func (tr *InstallationTemplate) GetID() string
GetID returns ID of underlying Terraform resource of this InstallationTemplate
func (*InstallationTemplate) GetInitParameters ¶
func (tr *InstallationTemplate) GetInitParameters() (map[string]any, error)
GetInitParameters of this InstallationTemplate
func (*InstallationTemplate) GetManagementPolicies ¶
func (mg *InstallationTemplate) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this InstallationTemplate.
func (*InstallationTemplate) GetObservation ¶
func (tr *InstallationTemplate) GetObservation() (map[string]any, error)
GetObservation of this InstallationTemplate
func (*InstallationTemplate) GetParameters ¶
func (tr *InstallationTemplate) GetParameters() (map[string]any, error)
GetParameters of this InstallationTemplate
func (*InstallationTemplate) GetProviderConfigReference ¶
func (mg *InstallationTemplate) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this InstallationTemplate.
func (*InstallationTemplate) GetPublishConnectionDetailsTo ¶
func (mg *InstallationTemplate) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this InstallationTemplate.
func (*InstallationTemplate) GetTerraformResourceType ¶
func (mg *InstallationTemplate) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this InstallationTemplate
func (*InstallationTemplate) GetTerraformSchemaVersion ¶
func (tr *InstallationTemplate) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*InstallationTemplate) GetWriteConnectionSecretToReference ¶
func (mg *InstallationTemplate) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this InstallationTemplate.
func (*InstallationTemplate) LateInitialize ¶
func (tr *InstallationTemplate) LateInitialize(attrs []byte) (bool, error)
LateInitialize this InstallationTemplate using its observed tfState. returns True if there are any spec changes for the resource.
func (*InstallationTemplate) SetConditions ¶
func (mg *InstallationTemplate) SetConditions(c ...xpv1.Condition)
SetConditions of this InstallationTemplate.
func (*InstallationTemplate) SetDeletionPolicy ¶
func (mg *InstallationTemplate) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this InstallationTemplate.
func (*InstallationTemplate) SetManagementPolicies ¶
func (mg *InstallationTemplate) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this InstallationTemplate.
func (*InstallationTemplate) SetObservation ¶
func (tr *InstallationTemplate) SetObservation(obs map[string]any) error
SetObservation for this InstallationTemplate
func (*InstallationTemplate) SetParameters ¶
func (tr *InstallationTemplate) SetParameters(params map[string]any) error
SetParameters for this InstallationTemplate
func (*InstallationTemplate) SetProviderConfigReference ¶
func (mg *InstallationTemplate) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this InstallationTemplate.
func (*InstallationTemplate) SetPublishConnectionDetailsTo ¶
func (mg *InstallationTemplate) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this InstallationTemplate.
func (*InstallationTemplate) SetWriteConnectionSecretToReference ¶
func (mg *InstallationTemplate) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this InstallationTemplate.
type InstallationTemplateInitParameters ¶
type InstallationTemplateInitParameters struct {
// OVH template name yours will be based on, choose one among the list given by compatibleTemplates function
BaseTemplateName *string `json:"baseTemplateName,omitempty" tf:"base_template_name,omitempty"`
Customization []CustomizationInitParameters `json:"customization,omitempty" tf:"customization,omitempty"`
// The default language of this template
DefaultLanguage *string `json:"defaultLanguage,omitempty" tf:"default_language,omitempty"`
// Remove default partition schemes at creation
RemoveDefaultPartitionSchemes *bool `json:"removeDefaultPartitionSchemes,omitempty" tf:"remove_default_partition_schemes,omitempty"`
}
func (*InstallationTemplateInitParameters) DeepCopy ¶
func (in *InstallationTemplateInitParameters) DeepCopy() *InstallationTemplateInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InstallationTemplateInitParameters.
func (*InstallationTemplateInitParameters) DeepCopyInto ¶
func (in *InstallationTemplateInitParameters) DeepCopyInto(out *InstallationTemplateInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type InstallationTemplateList ¶
type InstallationTemplateList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []InstallationTemplate `json:"items"`
}
InstallationTemplateList contains a list of InstallationTemplates
func (*InstallationTemplateList) DeepCopy ¶
func (in *InstallationTemplateList) DeepCopy() *InstallationTemplateList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InstallationTemplateList.
func (*InstallationTemplateList) DeepCopyInto ¶
func (in *InstallationTemplateList) DeepCopyInto(out *InstallationTemplateList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*InstallationTemplateList) DeepCopyObject ¶
func (in *InstallationTemplateList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*InstallationTemplateList) GetItems ¶
func (l *InstallationTemplateList) GetItems() []resource.Managed
GetItems of this InstallationTemplateList.
type InstallationTemplateObservation ¶
type InstallationTemplateObservation struct {
// List of all language available for this template
AvailableLanguages []*string `json:"availableLanguages,omitempty" tf:"available_languages,omitempty"`
// OVH template name yours will be based on, choose one among the list given by compatibleTemplates function
BaseTemplateName *string `json:"baseTemplateName,omitempty" tf:"base_template_name,omitempty"`
// This distribution is new and, although tested and functional, may still display odd behaviour
Beta *bool `json:"beta,omitempty" tf:"beta,omitempty"`
// This template bit format (32 or 64)
BitFormat *float64 `json:"bitFormat,omitempty" tf:"bit_format,omitempty"`
// Category of this template (informative only). (basic, customer, hosting, other, readyToUse, virtualisation)
Category *string `json:"category,omitempty" tf:"category,omitempty"`
Customization []CustomizationObservation `json:"customization,omitempty" tf:"customization,omitempty"`
// The default language of this template
DefaultLanguage *string `json:"defaultLanguage,omitempty" tf:"default_language,omitempty"`
// is this distribution deprecated
Deprecated *bool `json:"deprecated,omitempty" tf:"deprecated,omitempty"`
// information about this template
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// the distribution this template is based on
Distribution *string `json:"distribution,omitempty" tf:"distribution,omitempty"`
// this template family type (bsd,linux,solaris,windows)
Family *string `json:"family,omitempty" tf:"family,omitempty"`
// Filesystems available (btrfs,ext3,ext4,ntfs,reiserfs,swap,ufs,xfs,zfs)
Filesystems []*string `json:"filesystems,omitempty" tf:"filesystems,omitempty"`
// This distribution supports hardware raid configuration through the OVH API
HardRaidConfiguration *bool `json:"hardRaidConfiguration,omitempty" tf:"hard_raid_configuration,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// Date of last modification of the base image
LastModification *string `json:"lastModification,omitempty" tf:"last_modification,omitempty"`
// This distribution supports Logical Volumes (Linux LVM)
LvmReady *bool `json:"lvmReady,omitempty" tf:"lvm_ready,omitempty"`
// Remove default partition schemes at creation
RemoveDefaultPartitionSchemes *bool `json:"removeDefaultPartitionSchemes,omitempty" tf:"remove_default_partition_schemes,omitempty"`
// This distribution supports installation using the distribution's native kernel instead of the recommended OVH kernel
SupportsDistributionKernel *bool `json:"supportsDistributionKernel,omitempty" tf:"supports_distribution_kernel,omitempty"`
// This distribution supports RTM software
SupportsRtm *bool `json:"supportsRtm,omitempty" tf:"supports_rtm,omitempty"`
// This distribution supports the microsoft SQL server
SupportsSQLServer *bool `json:"supportsSqlServer,omitempty" tf:"supports_sql_server,omitempty"`
}
func (*InstallationTemplateObservation) DeepCopy ¶
func (in *InstallationTemplateObservation) DeepCopy() *InstallationTemplateObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InstallationTemplateObservation.
func (*InstallationTemplateObservation) DeepCopyInto ¶
func (in *InstallationTemplateObservation) DeepCopyInto(out *InstallationTemplateObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type InstallationTemplateParameters ¶
type InstallationTemplateParameters struct {
// OVH template name yours will be based on, choose one among the list given by compatibleTemplates function
// +kubebuilder:validation:Optional
BaseTemplateName *string `json:"baseTemplateName,omitempty" tf:"base_template_name,omitempty"`
// +kubebuilder:validation:Optional
Customization []CustomizationParameters `json:"customization,omitempty" tf:"customization,omitempty"`
// The default language of this template
// +kubebuilder:validation:Optional
DefaultLanguage *string `json:"defaultLanguage,omitempty" tf:"default_language,omitempty"`
// Remove default partition schemes at creation
// +kubebuilder:validation:Optional
RemoveDefaultPartitionSchemes *bool `json:"removeDefaultPartitionSchemes,omitempty" tf:"remove_default_partition_schemes,omitempty"`
}
func (*InstallationTemplateParameters) DeepCopy ¶
func (in *InstallationTemplateParameters) DeepCopy() *InstallationTemplateParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InstallationTemplateParameters.
func (*InstallationTemplateParameters) DeepCopyInto ¶
func (in *InstallationTemplateParameters) DeepCopyInto(out *InstallationTemplateParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type InstallationTemplateSpec ¶
type InstallationTemplateSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider InstallationTemplateParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider InstallationTemplateInitParameters `json:"initProvider,omitempty"`
}
InstallationTemplateSpec defines the desired state of InstallationTemplate
func (*InstallationTemplateSpec) DeepCopy ¶
func (in *InstallationTemplateSpec) DeepCopy() *InstallationTemplateSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InstallationTemplateSpec.
func (*InstallationTemplateSpec) DeepCopyInto ¶
func (in *InstallationTemplateSpec) DeepCopyInto(out *InstallationTemplateSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type InstallationTemplateStatus ¶
type InstallationTemplateStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider InstallationTemplateObservation `json:"atProvider,omitempty"`
}
InstallationTemplateStatus defines the observed state of InstallationTemplate.
func (*InstallationTemplateStatus) DeepCopy ¶
func (in *InstallationTemplateStatus) DeepCopy() *InstallationTemplateStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InstallationTemplateStatus.
func (*InstallationTemplateStatus) DeepCopyInto ¶
func (in *InstallationTemplateStatus) DeepCopyInto(out *InstallationTemplateStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.