v1alpha1

package
v0.0.0-...-73c97c3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 17, 2024 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

+kubebuilder:object:generate=true +groupName=meipxescript.crossplane.io +versionName=v1alpha1

Index

Constants

const (
	CRDGroup   = "meipxescript.crossplane.io"
	CRDVersion = "v1alpha1"
)

Package type metadata.

Variables

var (
	// CRDGroupVersion is the API Group Version used to register the objects
	CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)
var (
	IpxeScript_Kind             = "IpxeScript"
	IpxeScript_GroupKind        = schema.GroupKind{Group: CRDGroup, Kind: IpxeScript_Kind}.String()
	IpxeScript_KindAPIVersion   = IpxeScript_Kind + "." + CRDGroupVersion.String()
	IpxeScript_GroupVersionKind = CRDGroupVersion.WithKind(IpxeScript_Kind)
)

Repository type metadata.

Functions

This section is empty.

Types

type IpxeScript

type IpxeScript struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.name) || (has(self.initProvider) && has(self.initProvider.name))",message="spec.forProvider.name is a required parameter"
	// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.script) || (has(self.initProvider) && has(self.initProvider.script))",message="spec.forProvider.script is a required parameter"
	Spec   IpxeScriptSpec   `json:"spec"`
	Status IpxeScriptStatus `json:"status,omitempty"`
}

IpxeScript is the Schema for the IpxeScripts API. <no value> +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,ovh}

func (*IpxeScript) DeepCopy

func (in *IpxeScript) DeepCopy() *IpxeScript

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IpxeScript.

func (*IpxeScript) DeepCopyInto

func (in *IpxeScript) DeepCopyInto(out *IpxeScript)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*IpxeScript) DeepCopyObject

func (in *IpxeScript) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*IpxeScript) GetCondition

func (mg *IpxeScript) GetCondition(ct xpv1.ConditionType) xpv1.Condition

GetCondition of this IpxeScript.

func (*IpxeScript) GetConnectionDetailsMapping

func (tr *IpxeScript) GetConnectionDetailsMapping() map[string]string

GetConnectionDetailsMapping for this IpxeScript

func (*IpxeScript) GetDeletionPolicy

func (mg *IpxeScript) GetDeletionPolicy() xpv1.DeletionPolicy

GetDeletionPolicy of this IpxeScript.

func (*IpxeScript) GetID

func (tr *IpxeScript) GetID() string

GetID returns ID of underlying Terraform resource of this IpxeScript

func (*IpxeScript) GetInitParameters

func (tr *IpxeScript) GetInitParameters() (map[string]any, error)

GetInitParameters of this IpxeScript

func (*IpxeScript) GetManagementPolicies

func (mg *IpxeScript) GetManagementPolicies() xpv1.ManagementPolicies

GetManagementPolicies of this IpxeScript.

func (*IpxeScript) GetObservation

func (tr *IpxeScript) GetObservation() (map[string]any, error)

GetObservation of this IpxeScript

func (*IpxeScript) GetParameters

func (tr *IpxeScript) GetParameters() (map[string]any, error)

GetParameters of this IpxeScript

func (*IpxeScript) GetProviderConfigReference

func (mg *IpxeScript) GetProviderConfigReference() *xpv1.Reference

GetProviderConfigReference of this IpxeScript.

func (*IpxeScript) GetPublishConnectionDetailsTo

func (mg *IpxeScript) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo

GetPublishConnectionDetailsTo of this IpxeScript.

func (*IpxeScript) GetTerraformResourceType

func (mg *IpxeScript) GetTerraformResourceType() string

GetTerraformResourceType returns Terraform resource type for this IpxeScript

func (*IpxeScript) GetTerraformSchemaVersion

func (tr *IpxeScript) GetTerraformSchemaVersion() int

GetTerraformSchemaVersion returns the associated Terraform schema version

func (*IpxeScript) GetWriteConnectionSecretToReference

func (mg *IpxeScript) GetWriteConnectionSecretToReference() *xpv1.SecretReference

GetWriteConnectionSecretToReference of this IpxeScript.

func (*IpxeScript) LateInitialize

func (tr *IpxeScript) LateInitialize(attrs []byte) (bool, error)

LateInitialize this IpxeScript using its observed tfState. returns True if there are any spec changes for the resource.

func (*IpxeScript) SetConditions

func (mg *IpxeScript) SetConditions(c ...xpv1.Condition)

SetConditions of this IpxeScript.

func (*IpxeScript) SetDeletionPolicy

func (mg *IpxeScript) SetDeletionPolicy(r xpv1.DeletionPolicy)

SetDeletionPolicy of this IpxeScript.

func (*IpxeScript) SetManagementPolicies

func (mg *IpxeScript) SetManagementPolicies(r xpv1.ManagementPolicies)

SetManagementPolicies of this IpxeScript.

func (*IpxeScript) SetObservation

func (tr *IpxeScript) SetObservation(obs map[string]any) error

SetObservation for this IpxeScript

func (*IpxeScript) SetParameters

func (tr *IpxeScript) SetParameters(params map[string]any) error

SetParameters for this IpxeScript

func (*IpxeScript) SetProviderConfigReference

func (mg *IpxeScript) SetProviderConfigReference(r *xpv1.Reference)

SetProviderConfigReference of this IpxeScript.

func (*IpxeScript) SetPublishConnectionDetailsTo

func (mg *IpxeScript) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)

SetPublishConnectionDetailsTo of this IpxeScript.

func (*IpxeScript) SetWriteConnectionSecretToReference

func (mg *IpxeScript) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)

SetWriteConnectionSecretToReference of this IpxeScript.

type IpxeScriptInitParameters

type IpxeScriptInitParameters struct {

	// For documentation purpose only. This attribute is not passed to the OVH API as it cannot be retrieved back. Instead a fake description ('$name auto description') is passed at creation time.
	Description *string `json:"description,omitempty" tf:"description,omitempty"`

	// Name of your script
	Name *string `json:"name,omitempty" tf:"name,omitempty"`

	// Content of your IPXE script
	Script *string `json:"script,omitempty" tf:"script,omitempty"`
}

func (*IpxeScriptInitParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IpxeScriptInitParameters.

func (*IpxeScriptInitParameters) DeepCopyInto

func (in *IpxeScriptInitParameters) DeepCopyInto(out *IpxeScriptInitParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type IpxeScriptList

type IpxeScriptList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []IpxeScript `json:"items"`
}

IpxeScriptList contains a list of IpxeScripts

func (*IpxeScriptList) DeepCopy

func (in *IpxeScriptList) DeepCopy() *IpxeScriptList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IpxeScriptList.

func (*IpxeScriptList) DeepCopyInto

func (in *IpxeScriptList) DeepCopyInto(out *IpxeScriptList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*IpxeScriptList) DeepCopyObject

func (in *IpxeScriptList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*IpxeScriptList) GetItems

func (l *IpxeScriptList) GetItems() []resource.Managed

GetItems of this IpxeScriptList.

type IpxeScriptObservation

type IpxeScriptObservation struct {

	// For documentation purpose only. This attribute is not passed to the OVH API as it cannot be retrieved back. Instead a fake description ('$name auto description') is passed at creation time.
	Description *string `json:"description,omitempty" tf:"description,omitempty"`

	ID *string `json:"id,omitempty" tf:"id,omitempty"`

	// Name of your script
	Name *string `json:"name,omitempty" tf:"name,omitempty"`

	// Content of your IPXE script
	Script *string `json:"script,omitempty" tf:"script,omitempty"`
}

func (*IpxeScriptObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IpxeScriptObservation.

func (*IpxeScriptObservation) DeepCopyInto

func (in *IpxeScriptObservation) DeepCopyInto(out *IpxeScriptObservation)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type IpxeScriptParameters

type IpxeScriptParameters struct {

	// For documentation purpose only. This attribute is not passed to the OVH API as it cannot be retrieved back. Instead a fake description ('$name auto description') is passed at creation time.
	// +kubebuilder:validation:Optional
	Description *string `json:"description,omitempty" tf:"description,omitempty"`

	// Name of your script
	// +kubebuilder:validation:Optional
	Name *string `json:"name,omitempty" tf:"name,omitempty"`

	// Content of your IPXE script
	// +kubebuilder:validation:Optional
	Script *string `json:"script,omitempty" tf:"script,omitempty"`
}

func (*IpxeScriptParameters) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IpxeScriptParameters.

func (*IpxeScriptParameters) DeepCopyInto

func (in *IpxeScriptParameters) DeepCopyInto(out *IpxeScriptParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type IpxeScriptSpec

type IpxeScriptSpec struct {
	v1.ResourceSpec `json:",inline"`
	ForProvider     IpxeScriptParameters `json:"forProvider"`
	// THIS IS A BETA FIELD. It will be honored
	// unless the Management Policies feature flag is disabled.
	// InitProvider holds the same fields as ForProvider, with the exception
	// of Identifier and other resource reference fields. The fields that are
	// in InitProvider are merged into ForProvider when the resource is created.
	// The same fields are also added to the terraform ignore_changes hook, to
	// avoid updating them after creation. This is useful for fields that are
	// required on creation, but we do not desire to update them after creation,
	// for example because of an external controller is managing them, like an
	// autoscaler.
	InitProvider IpxeScriptInitParameters `json:"initProvider,omitempty"`
}

IpxeScriptSpec defines the desired state of IpxeScript

func (*IpxeScriptSpec) DeepCopy

func (in *IpxeScriptSpec) DeepCopy() *IpxeScriptSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IpxeScriptSpec.

func (*IpxeScriptSpec) DeepCopyInto

func (in *IpxeScriptSpec) DeepCopyInto(out *IpxeScriptSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type IpxeScriptStatus

type IpxeScriptStatus struct {
	v1.ResourceStatus `json:",inline"`
	AtProvider        IpxeScriptObservation `json:"atProvider,omitempty"`
}

IpxeScriptStatus defines the observed state of IpxeScript.

func (*IpxeScriptStatus) DeepCopy

func (in *IpxeScriptStatus) DeepCopy() *IpxeScriptStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IpxeScriptStatus.

func (*IpxeScriptStatus) DeepCopyInto

func (in *IpxeScriptStatus) DeepCopyInto(out *IpxeScriptStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to